@@ -64,8 +64,8 @@ slurm_ctl_conf_to_hv(slurm_ctl_conf_t *conf, HV *hv)
 	if (conf->checkpoint_type)
 		STORE_FIELD(hv, conf, checkpoint_type, charp);
 
-	if (conf->core_spec_plugin)
-		STORE_FIELD(hv, conf, core_spec_plugin, charp);
+	if (conf->cli_filter_plugins)
+		STORE_FIELD(hv, conf, cli_filter_plugins, charp);
 
 	if (conf->cluster_name)
 		STORE_FIELD(hv, conf, cluster_name, charp);
@@ -82,10 +82,13 @@ slurm_ctl_conf_to_hv(slurm_ctl_conf_t *conf, HV *hv)
 		av_store(av, i, newSVpv(conf->control_machine[i], 0));
 	hv_store_sv(hv, "control_machine", newRV_noinc((SV*)av));
 
+	if (conf->core_spec_plugin)
+		STORE_FIELD(hv, conf, core_spec_plugin, charp);
+
 	STORE_FIELD(hv, conf, cpu_freq_def, uint32_t);
 
-	if (conf->crypto_type)
-		STORE_FIELD(hv, conf, crypto_type, charp);
+	if (conf->cred_type)
+		STORE_FIELD(hv, conf, cred_type, charp);
 
 	STORE_FIELD(hv, conf, debug_flags, uint64_t);
 
@@ -204,9 +207,6 @@ slurm_ctl_conf_to_hv(slurm_ctl_conf_t *conf, HV *hv)
 
 	STORE_FIELD(hv, conf, max_tasks_per_node, uint16_t);
 
-	if (conf->mem_limit_enforce)
-		STORE_FIELD(hv, conf, mem_limit_enforce, uint16_t);
-
 	STORE_FIELD(hv, conf, min_job_age, uint16_t);
 
 	if (conf->mpi_default)
@@ -317,6 +317,11 @@ slurm_ctl_conf_to_hv(slurm_ctl_conf_t *conf, HV *hv)
 		STORE_FIELD(hv, conf, select_type, charp);
 	STORE_FIELD(hv, conf, select_type_param, uint16_t);
 
+	if (conf->site_factor_params)
+		STORE_FIELD(hv, conf, site_factor_params, charp);
+	if (conf->site_factor_plugin)
+		STORE_FIELD(hv, conf, site_factor_plugin, charp);
+
 	if (conf->slurm_conf)
 		STORE_FIELD(hv, conf, slurm_conf, charp);
 
@@ -433,7 +438,7 @@ hv_to_slurm_ctl_conf(HV *hv, slurm_ctl_conf_t *conf)
 	FETCH_FIELD(hv, conf, bb_type, charp, FALSE);
 	FETCH_FIELD(hv, conf, boot_time, time_t, TRUE);
 	FETCH_FIELD(hv, conf, checkpoint_type, charp, FALSE);
-	FETCH_FIELD(hv, conf, core_spec_plugin, charp, FALSE);
+	FETCH_FIELD(hv, conf, cli_filter_plugins, charp, FALSE);
 	FETCH_FIELD(hv, conf, cluster_name, charp, FALSE);
 	FETCH_FIELD(hv, conf, complete_wait, uint16_t, TRUE);
 
@@ -468,8 +473,9 @@ hv_to_slurm_ctl_conf(HV *hv, slurm_ctl_conf_t *conf)
 	FETCH_FIELD(hv, conf, control_addr[1], charp, FALSE);
 	FETCH_FIELD(hv, conf, control_machine[1], charp, FALSE);
 
+	FETCH_FIELD(hv, conf, core_spec_plugin, charp, FALSE);
 	FETCH_FIELD(hv, conf, cpu_freq_def, uint32_t, FALSE);
-	FETCH_FIELD(hv, conf, crypto_type, charp, FALSE);
+	FETCH_FIELD(hv, conf, cred_type, charp, FALSE);
 	FETCH_FIELD(hv, conf, debug_flags, uint64_t, TRUE);
 	FETCH_FIELD(hv, conf, def_mem_per_cpu, uint64_t, TRUE);
 	FETCH_FIELD(hv, conf, disable_root_jobs, uint16_t, TRUE);
@@ -527,7 +533,6 @@ hv_to_slurm_ctl_conf(HV *hv, slurm_ctl_conf_t *conf)
 	FETCH_FIELD(hv, conf, max_mem_per_cpu, uint64_t, TRUE);
 	FETCH_FIELD(hv, conf, max_step_cnt, uint32_t, FALSE);
 	FETCH_FIELD(hv, conf, max_tasks_per_node, uint16_t, TRUE);
-	FETCH_FIELD(hv, conf, mem_limit_enforce, uint16_t, FALSE);
 	FETCH_FIELD(hv, conf, min_job_age, uint16_t, TRUE);
 	FETCH_FIELD(hv, conf, mpi_default, charp, FALSE);
 	FETCH_FIELD(hv, conf, mpi_params, charp, FALSE);
