@@ -11,11 +11,11 @@
 #  Written by Danny Auble <da@schedmd.com>.
 #  CODE-OCEC-09-009. All rights reserved.
 #
-#  This file is part of SLURM, a resource management program.
+#  This file is part of Slurm, a resource management program.
 #  For details, see <https://slurm.schedmd.com/>.
 #  Please also read the included file: DISCLAIMER.
 #
-#  SLURM is free software; you can redistribute it and/or modify it under
+#  Slurm is free software; you can redistribute it and/or modify it under
 #  the terms of the GNU General Public License as published by the Free
 #  Software Foundation; either version 2 of the License, or (at your option)
 #  any later version.
@@ -31,13 +31,13 @@
 #  version.  If you delete this exception statement from all source files in
 #  the program, then also delete it here.
 #
-#  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+#  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
 #  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 #  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
 #  details.
 #
 #  You should have received a copy of the GNU General Public License along
-#  with SLURM; if not, write to the Free Software Foundation, Inc.,
+#  with Slurm; if not, write to the Free Software Foundation, Inc.,
 #  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 #
 ###############################################################################
@@ -408,7 +408,7 @@ if ($interactive) {
 		$job_id= $spcommand_output[$#spcommand_output];
 		print "$job_id\n";
 	} else {
-		print("There was an error running the SLURM sbatch command.\n" .
+		print("There was an error running the Slurm sbatch command.\n" .
 		      "The command was:\n" .
 		      "'$command'\n" .
 		      "and the output was:\n" .
@@ -490,7 +490,7 @@ sub parse_resource_list {
 #	If needed, un-protect the walltime string.
 	if ($opt{walltime}) {
 		$opt{walltime} =~ s/(\d{1,2})h(\d{2})m(\d{2})s/$1:$2:$3/;
-#		Convert to minutes for SLURM.
+#		Convert to minutes for Slurm.
 		$opt{walltime} = get_minutes($opt{walltime});
 	}
 
