@@ -6,11 +6,11 @@
  *  Written by Danny Auble da@llnl.gov, et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 #ifndef _SLURMDB_H
@@ -135,6 +135,7 @@ typedef enum {
 #define	QOS_FLAG_DENY_LIMIT          0x00000040
 #define	QOS_FLAG_OVER_PART_QOS       0x00000080
 #define	QOS_FLAG_NO_DECAY            0x00000100
+#define	QOS_FLAG_USAGE_FACTOR_SAFE   0x00000200
 
 /* Define Server Resource flags */
 #define	SLURMDB_RES_FLAG_BASE        0x0fffffff /* apply to get real flags */
@@ -148,6 +149,7 @@ typedef enum {
 #define	FEDERATION_FLAG_ADD            0x20000000
 #define	FEDERATION_FLAG_REMOVE         0x40000000
 
+#define SLURMDB_MODIFY_NO_WAIT       0x00000001
 
 /* SLURM CLUSTER FEDERATION STATES */
 enum cluster_fed_states {
@@ -167,6 +169,32 @@ enum cluster_fed_states {
 /* flags and types of resources */
 /* when we come up with some */
 
+/*
+ * Translation of db_flags in the struct job_record and flag
+ * slurmdb_job_[rec|cond]_t
+ */
+#define SLURMDB_JOB_FLAG_NONE     0x00000000 /* No flags */
+#define SLURMDB_JOB_CLEAR_SCHED   0x0000000f /* clear scheduling bits */
+#define SLURMDB_JOB_FLAG_NOTSET   0x00000001 /* Not set */
+#define SLURMDB_JOB_FLAG_SUBMIT   0x00000002 /* Job was started on submit */
+#define SLURMDB_JOB_FLAG_SCHED    0x00000004 /* Job was started from main
+					      * scheduler */
+#define SLURMDB_JOB_FLAG_BACKFILL 0x00000008 /* Job was started from backfill */
+
+/* Slurm job condition flags */
+#define JOBCOND_FLAG_DUP      0x00000001 /* Report duplicate job entries */
+#define JOBCOND_FLAG_NO_STEP  0x00000002 /* Don't report job step info */
+#define JOBCOND_FLAG_NO_TRUNC 0x00000004 /* Report info. without truncating
+					  * the time to the usage_start and
+					  * usage_end */
+#define JOBCOND_FLAG_RUNAWAY  0x00000008 /* Report runaway jobs only */
+#define JOBCOND_FLAG_WHOLE_HETJOB    0x00000010 /* Report info about all hetjob
+						 * components
+						 */
+#define JOBCOND_FLAG_NO_WHOLE_HETJOB 0x00000020 /* Only report info about
+						 * requested hetjob components
+						 */
+
 /* Archive / Purge time flags */
 #define SLURMDB_PURGE_BASE    0x0000ffff   /* Apply to get the number
 					    * of units */
@@ -185,11 +213,13 @@ enum cluster_fed_states {
 
 /* Cluster flags */
 #define CLUSTER_FLAG_BG     0x00000001 /* This is a bluegene cluster */
+				       /* Removed v18.08 */
 #define CLUSTER_FLAG_BGL    0x00000002 /* This is a bluegene/l cluster */
 				       /* Removed v17.02 */
 #define CLUSTER_FLAG_BGP    0x00000004 /* This is a bluegene/p cluster */
 				       /* Removed v17.02 */
 #define CLUSTER_FLAG_BGQ    0x00000008 /* This is a bluegene/q cluster */
+				       /* Removed v18.08 */
 #define CLUSTER_FLAG_SC     0x00000010 /* This is a sun constellation cluster */
 				       /* Removed v16.05 */
 #define CLUSTER_FLAG_XCPU   0x00000020 /* This has xcpu, removed v15.08 */
@@ -197,8 +227,9 @@ enum cluster_fed_states {
 				       /* Removed v17.02 */
 #define CLUSTER_FLAG_MULTSD 0x00000080 /* This cluster is multiple slurmd */
 #define CLUSTER_FLAG_CRAYXT 0x00000100 /* This cluster is a ALPS cray
-					* (deprecated) Same as CRAY_A */
-#define CLUSTER_FLAG_CRAY_A 0x00000100 /* This cluster is a ALPS cray */
+					* Removed v19.05 */
+#define CLUSTER_FLAG_CRAY_A 0x00000100 /* This cluster is a ALPS cray
+					* Removed v19.05 */
 #define CLUSTER_FLAG_FE     0x00000200 /* This cluster is a front end system */
 #define CLUSTER_FLAG_CRAY_N 0x00000400 /* This cluster is a Native cray */
 #define CLUSTER_FLAG_FED    0x00000800 /* This cluster is in a federation. */
@@ -219,12 +250,13 @@ typedef struct {
 	uint64_t alloc_secs; /* total amount of secs allocated if used in an
 				accounting_list */
 	uint32_t rec_count;  /* number of records alloc_secs is, DON'T PACK */
-	uint64_t count; /* Count of tres on a given cluster, 0 if
-			   listed generically. */
-	uint32_t id;    /* Database ID for the tres */
-	char *name;     /* Name of tres if type is generic like GRES
-			   or License. */
-	char *type;     /* Type of tres (CPU, MEM, etc) */
+	uint64_t count; /* Count of TRES on a given cluster, 0 if
+			 * listed generically. */
+	uint32_t id;    /* Database ID for the TRES */
+	char *name;     /* Name of TRES if type is generic like GRES
+			 * or License. Make include optional GRES type
+			 * (e.g. "gpu" or "gpu:tesla") */
+	char *type;     /* Type of TRES (CPU, MEM, etc) */
 } slurmdb_tres_rec_t;
 
 /* slurmdb_assoc_cond_t is used in other structures below so
@@ -267,10 +299,12 @@ typedef struct {
 	List acct_list;		/* list of char * */
 	List associd_list;	/* list of char */
 	List cluster_list;	/* list of char * */
+	List constraint_list; 	/* list of char * */
 	uint32_t cpus_max;      /* number of cpus high range */
 	uint32_t cpus_min;      /* number of cpus low range */
-	uint16_t duplicates;    /* report duplicate job entries */
+	uint32_t db_flags;      /* flags sent from the slurmctld on the job */
 	int32_t exitcode;       /* exit code of job */
+	uint32_t flags;         /* Reporting flags*/
 	List format_list; 	/* list of char * */
 	List groupid_list;	/* list of char * */
 	List jobname_list;	/* list of char * */
@@ -278,6 +312,7 @@ typedef struct {
 	uint32_t nodes_min;     /* number of nodes low range */
 	List partition_list;	/* list of char * */
 	List qos_list;  	/* list of char * */
+	List reason_list;	/* list of char * */
 	List resv_list;		/* list of char * */
 	List resvid_list;	/* list of char * */
 	List state_list;        /* list of char * */
@@ -289,11 +324,6 @@ typedef struct {
 	char *used_nodes;       /* a ranged node string where jobs ran */
 	List userid_list;	/* list of char * */
 	List wckey_list;	/* list of char * */
-	uint16_t without_steps; /* don't give me step info */
-	uint16_t without_usage_truncation; /* give me the information
-					    * without truncating the
-					    * time to the usage_start
-					    * and usage_end */
 } slurmdb_job_cond_t;
 
 /* slurmdb_stats_t needs to be defined before slurmdb_job_rec_t and
@@ -301,31 +331,23 @@ typedef struct {
  */
 typedef struct {
 	double act_cpufreq;	/* contains actual average cpu frequency */
-	double cpu_ave;
 	uint64_t consumed_energy; /* contains energy consumption in joules */
-	uint32_t cpu_min;
-	uint32_t cpu_min_nodeid; /* contains which node number it was on */
-	uint32_t cpu_min_taskid; /* contains which task number it was on */
-	double disk_read_ave; /* average amount of disk read data, in mb */
-	double disk_read_max; /* maximum amount of disk read data, in mb */
-	uint32_t disk_read_max_nodeid; /* contains  node number max was on */
-	uint32_t disk_read_max_taskid;/* contains task number max was on */
-	double disk_write_ave; /* average amount of disk write data, in mb */
-	double disk_write_max; /* maximum amount of disk write data, in mb */
-	uint32_t disk_write_max_nodeid; /* contains  node number max was on */
-	uint32_t disk_write_max_taskid;/* contains task number max was on */
-	double pages_ave;
-	uint64_t pages_max;
-	uint32_t pages_max_nodeid; /* contains which node number it was on */
-	uint32_t pages_max_taskid; /* contains which task number it was on */
-	double rss_ave;
-	uint64_t rss_max;
-	uint32_t rss_max_nodeid; /* contains which node number it was on */
-	uint32_t rss_max_taskid; /* contains which task number it was on */
-	double vsize_ave;
-	uint64_t vsize_max;
-	uint32_t vsize_max_nodeid; /* contains which node number it was on */
-	uint32_t vsize_max_taskid; /* contains which task number it was on */
+	char *tres_usage_in_ave; /* average amount of usage in data */
+	char *tres_usage_in_max; /* contains max amount of usage in data */
+	char *tres_usage_in_max_nodeid; /* contains node number max was on */
+	char *tres_usage_in_max_taskid; /* contains task number max was on */
+	char *tres_usage_in_min; /* contains min amount of usage in data */
+	char *tres_usage_in_min_nodeid; /* contains node number min was on */
+	char *tres_usage_in_min_taskid; /* contains task number min was on */
+	char *tres_usage_in_tot; /* total amount of usage in data */
+	char *tres_usage_out_ave; /* average amount of usage out data */
+	char *tres_usage_out_max; /* contains amount of max usage out data */
+	char *tres_usage_out_max_nodeid; /* contains node number max was on */
+	char *tres_usage_out_max_taskid; /* contains task number max was on */
+	char *tres_usage_out_min; /* contains amount of min usage out data */
+	char *tres_usage_out_min_nodeid; /* contains node number min was on */
+	char *tres_usage_out_min_taskid; /* contains task number min was on */
+	char *tres_usage_out_tot; /* total amount of usage out data */
 } slurmdb_stats_t;
 
 /************** alphabetical order of structures **************/
@@ -414,6 +436,8 @@ typedef struct {
 
 /* This has slurmdb_assoc_rec_t's in it so we define the struct afterwards. */
 typedef struct slurmdb_assoc_usage slurmdb_assoc_usage_t;
+typedef struct slurmdb_bf_usage slurmdb_bf_usage_t;
+typedef struct slurmdb_user_rec slurmdb_user_rec_t;
 
 typedef struct slurmdb_assoc_rec {
 	List accounting_list; /* list of slurmdb_accounting_rec_t *'s */
@@ -427,6 +451,8 @@ typedef struct slurmdb_assoc_rec {
 	struct slurmdb_assoc_rec *assoc_next_id; /* next assoc with
 							* same hash index
 							* DOESN'T GET PACKED */
+	slurmdb_bf_usage_t *bf_usage; /* data for backfill scheduler,
+				       * (DON'T PACK) */
 	char *cluster;		   /* cluster associated to association */
 
 	uint32_t def_qos_id;       /* Which QOS id is this
@@ -435,6 +461,9 @@ typedef struct slurmdb_assoc_rec {
 	uint32_t grp_jobs;	   /* max number of jobs the
 				    * underlying group of associations can run
 				    * at one time */
+	uint32_t grp_jobs_accrue;  /* max number of jobs the
+				    * underlying group of associations can have
+				    * accruing priority at one time */
 	uint32_t grp_submit_jobs;  /* max number of jobs the
 				    * underlying group of
 				    * associations can submit at
@@ -478,6 +507,9 @@ typedef struct slurmdb_assoc_rec {
 
 	uint32_t max_jobs;	   /* max number of jobs this
 				    * association can run at one time */
+	uint32_t max_jobs_accrue;  /* max number of jobs this association can
+				    * have accruing priority time.
+				    */
 	uint32_t max_submit_jobs;  /* max number of jobs that can be
 				      submitted by association */
 	char *max_tres_mins_pj;    /* max number of cpu seconds this
@@ -510,11 +542,14 @@ typedef struct slurmdb_assoc_rec {
 	uint32_t max_wall_pj;      /* longest time this
 				    * association can run a job */
 
+	uint32_t min_prio_thresh;  /* Don't reserve resources for pending jobs
+				    * unless they have a priority equal to or
+				    * higher than this. */
 	char *parent_acct;	   /* name of parent account */
 	uint32_t parent_id;	   /* id of parent account */
 	char *partition;	   /* optional partition in a cluster
 				    * associated to association */
-
+	uint32_t priority;	   /* association priority */
 	List qos_list;             /* list of char * */
 
 	uint32_t rgt;		   /* rgt used for grouping sub
@@ -527,12 +562,23 @@ typedef struct slurmdb_assoc_rec {
 	uint32_t uid;		   /* user ID */
 	slurmdb_assoc_usage_t *usage;
 	char *user;		   /* user associated to assoc */
+	slurmdb_user_rec_t *user_rec; /* Cache of user record
+				       * soft ref - mem not managed here
+				       * (DON'T PACK)
+				       */
 } slurmdb_assoc_rec_t;
 
 struct slurmdb_assoc_usage {
+	uint32_t accrue_cnt;    /* Count of how many jobs I have accuring prio
+				 * (DON'T PACK for state file) */
 	List children_list;     /* list of children associations
 				 * (DON'T PACK) */
-	uint64_t *grp_used_tres; /* array of active tres counts */
+	bitstr_t *grp_node_bitmap;	/* Bitmap of allocated nodes
+					 * (DON'T PACK) */
+	uint16_t *grp_node_job_cnt;	/* Count of jobs allocated on each node
+					 * (DON'T PACK) */
+	uint64_t *grp_used_tres; /* array of active tres counts
+				  * (DON'T PACK for state file) */
 	uint64_t *grp_used_tres_run_secs; /* array of running tres secs
 					   * (DON'T PACK for state file) */
 
@@ -547,6 +593,9 @@ struct slurmdb_assoc_usage {
 						* set in slurmctld
 						* (DON'T PACK) */
 
+	double priority_norm;   /* normalized priority (DON'T PACK for
+				 * state file) */
+
 	slurmdb_assoc_rec_t *fs_assoc_ptr;    /* ptr to fairshare parent
 					       * assoc if fairshare
 					       * == SLURMDB_FS_USE_PARENT
@@ -585,6 +634,11 @@ struct slurmdb_assoc_usage {
 				 * (DON'T PACK for state file) */
 };
 
+struct slurmdb_bf_usage {
+	uint64_t count;
+	time_t last_sched;
+};
+
 typedef struct {
 	uint16_t classification; /* how this machine is classified */
 	List cluster_list; /* list of char * */
@@ -715,7 +769,9 @@ typedef struct {
 
 typedef struct {
 	char *cluster;
+	uint32_t flags;
 	uint32_t job_id;
+	time_t submit_time;
 } slurmdb_job_modify_cond_t;
 
 typedef struct {
@@ -735,12 +791,14 @@ typedef struct {
 	uint32_t associd;
 	char	*blockid;
 	char    *cluster;
+	char    *constraints;
 	uint32_t derived_ec;
 	char	*derived_es; /* aka "comment" */
 	uint32_t elapsed;
 	time_t eligible;
 	time_t end;
 	uint32_t exitcode;
+	uint32_t flags;
 	void *first_step_ptr;
 	uint32_t gid;
 	uint32_t jobid;
@@ -762,10 +820,12 @@ typedef struct {
 	uint32_t show_full;
 	time_t start;
 	uint32_t state;
+	uint32_t state_reason_prev;
 	slurmdb_stats_t stats;
 	List    steps; /* list of slurmdb_step_rec_t *'s */
 	time_t submit;
 	uint32_t suspended;
+	char	*system_comment;
 	uint32_t sys_cpu_sec;
 	uint32_t sys_cpu_usec;
 	uint32_t timelimit;
@@ -785,10 +845,16 @@ typedef struct {
 } slurmdb_job_rec_t;
 
 typedef struct {
+	uint32_t accrue_cnt;    /* Count of how many jobs I have accuring prio
+				 * (DON'T PACK for state file) */
 	List acct_limit_list; /* slurmdb_used_limits_t's (DON'T PACK
 			       * for state file) */
 	List job_list; /* list of job pointers to submitted/running
 			  jobs (DON'T PACK) */
+	bitstr_t *grp_node_bitmap;	/* Bitmap of allocated nodes
+					 * (DON'T PACK) */
+	uint16_t *grp_node_job_cnt;	/* Count of jobs allocated on each node
+					 * (DON'T PACK) */
 	uint32_t grp_used_jobs;	/* count of active jobs (DON'T PACK
 				 * for state file) */
 	uint32_t grp_used_submit_jobs; /* count of jobs pending or running
@@ -798,16 +864,14 @@ typedef struct {
 	uint64_t *grp_used_tres_run_secs; /* count of running tres secs
 					 * (DON'T PACK for state file) */
 	double grp_used_wall;   /* group count of time (minutes) used in
-				 * running jobs (DON'T PACK for state file) */
+				 * running jobs */
 	double norm_priority;/* normalized priority (DON'T PACK for
 			      * state file) */
 	uint32_t tres_cnt; /* size of the tres arrays,
 			    * (DON'T PACK for state file) */
-	long double usage_raw;	/* measure of resource usage (DON'T
-				 * PACK for state file) */
+	long double usage_raw;	/* measure of resource usage */
 
-	long double *usage_tres_raw; /* measure of each TRES usage (DON'T
-				      * PACK for state file)*/
+	long double *usage_tres_raw; /* measure of each TRES usage */
 	List user_limit_list; /* slurmdb_used_limits_t's (DON'T PACK
 			       * for state file) */
 } slurmdb_qos_usage_t;
@@ -818,6 +882,9 @@ typedef struct {
 	uint32_t flags; /* flags for various things to enforce or
 			   override other limits */
 	uint32_t grace_time; /* preemption grace time */
+	uint32_t grp_jobs_accrue; /* max number of jobs this qos can
+				   * have accruing priority time
+				   */
 	uint32_t grp_jobs;	/* max number of jobs this qos can run
 				 * at one time */
 	uint32_t grp_submit_jobs; /* max number of jobs this qos can submit at
@@ -848,6 +915,12 @@ typedef struct {
 				 * run with this qos at one time */
 	uint32_t max_jobs_pu;	/* max number of jobs a user can
 				 * run with this qos at one time */
+	uint32_t max_jobs_accrue_pa; /* max number of jobs an account can
+				      * have accruing priority time
+				      */
+	uint32_t max_jobs_accrue_pu; /* max number of jobs a user can
+				      * have accruing priority time
+				      */
 	uint32_t max_submit_jobs_pa; /* max number of jobs an account can
 					submit with this qos at once */
 	uint32_t max_submit_jobs_pu; /* max number of jobs a user can
@@ -908,6 +981,9 @@ typedef struct {
 					      * (DON'T PACK) */
 	uint32_t max_wall_pj; /* longest time this
 			       * qos can run a job */
+	uint32_t min_prio_thresh;  /* Don't reserve resources for pending jobs
+				    * unless they have a priority equal to or
+				    * higher than this. */
 	char *min_tres_pj; /* min number of tres a job can
 			    * allocate with this qos */
 	uint64_t *min_tres_pj_ctld;   /* min_tres_pj broken out in an array
@@ -921,6 +997,8 @@ typedef struct {
 			    * change the other qos' this can preempt,
 			    * when doing a get use the preempt_bitstr */
 	uint16_t preempt_mode;	/* See PREEMPT_MODE_* in slurm/slurm.h */
+	uint32_t preempt_exempt_time; /* Job run time before becoming
+					 eligible for preemption */
 	uint32_t priority;  /* ranged int needs to be a unint for
 			     * heterogeneous systems */
 	slurmdb_qos_usage_t *usage; /* For internal use only, DON'T PACK */
@@ -1071,6 +1149,7 @@ typedef struct {
 /* Right now this is used in the slurmdb_qos_rec_t structure.  In the
  * user_limit_list and acct_limit_list. */
 typedef struct {
+	uint32_t accrue_cnt; /* count of jobs accruing prio */
 	char *acct; /* If limits for an account this is the accounts name */
 	uint32_t jobs;	/* count of active jobs */
 	uint32_t submit_jobs; /* count of jobs pending or running */
@@ -1078,6 +1157,8 @@ typedef struct {
 	uint64_t *tres_run_mins; /* array of how many TRES mins are
 				  * allocated currently, currently this doesn't
 				  * do anything and isn't set up. */
+	bitstr_t *node_bitmap;	/* Bitmap of allocated nodes */
+	uint16_t *node_job_cnt;	/* Count of jobs allocated on each node */
 	uint32_t uid; /* If limits for a user this is the users uid */
 } slurmdb_used_limits_t;
 
@@ -1101,10 +1182,12 @@ typedef struct {
 	uint16_t without_defaults;
 } slurmdb_user_cond_t;
 
-typedef struct {
+struct slurmdb_user_rec {
 	uint16_t admin_level; /* really slurmdb_admin_level_t but for
 				 packing purposes needs to be uint16_t */
 	List assoc_list; /* list of slurmdb_association_rec_t *'s */
+	slurmdb_bf_usage_t *bf_usage; /* data for backfill scheduler,
+				       * (DON'T PACK) */
 	List coord_accts; /* list of slurmdb_coord_rec_t *'s */
 	char *default_acct;
 	char *default_wckey;
@@ -1112,7 +1195,7 @@ typedef struct {
 	char *old_name;
 	uint32_t uid;
 	List wckey_list; /* list of slurmdb_wckey_rec_t *'s */
-} slurmdb_user_rec_t;
+};
 
 typedef struct {
 	List objects; /* depending on type */
@@ -1415,20 +1498,23 @@ extern List slurmdb_report_cluster_user_by_wckey(void *db_conn,
 						 slurmdb_wckey_cond_t *wckey_cond);
 
 
-extern List slurmdb_report_job_sizes_grouped_by_top_account(void *db_conn,
-							    slurmdb_job_cond_t *job_cond,
-							    List grouping_list,
-							    bool flat_view);
+extern List slurmdb_report_job_sizes_grouped_by_account(
+	void *db_conn,
+	slurmdb_job_cond_t *job_cond,
+	List grouping_list,
+	bool flat_view,
+	bool acct_as_parent);
 
 extern List slurmdb_report_job_sizes_grouped_by_wckey(void *db_conn,
 						      slurmdb_job_cond_t *job_cond,
 						      List grouping_list);
 
-extern List slurmdb_report_job_sizes_grouped_by_top_account_then_wckey(
+extern List slurmdb_report_job_sizes_grouped_by_account_then_wckey(
 	void *db_conn,
 	slurmdb_job_cond_t *job_cond,
 	List grouping_list,
-	bool flat_view);
+	bool flat_view,
+	bool acct_as_parent);
 
 
 /* report on users with top usage
@@ -1450,6 +1536,13 @@ extern List slurmdb_report_user_top_usage(void *db_conn,
  * RET: pointer used to access db
  */
 extern void *slurmdb_connection_get();
+/*
+ * get a new connection to the slurmdb
+ * OUT: persist_conn_flags - Flags returned from connection if any see
+ *                           slurm_persist_conn.h.
+ * RET: pointer used to access db
+ */
+extern void *slurmdb_connection_get2(uint16_t *persist_conn_flags);
 /*
  * release connection to the storage unit
  * IN/OUT: void ** pointer returned from
@@ -1678,6 +1771,8 @@ extern int slurmdb_get_first_pack_cluster(List job_req_list,
 
 /************** helper functions **************/
 extern void slurmdb_destroy_assoc_usage(void *object);
+extern void slurmdb_destroy_bf_usage(void *object);
+extern void slurmdb_destroy_bf_usage_members(void *object);
 extern void slurmdb_destroy_qos_usage(void *object);
 extern void slurmdb_destroy_user_rec(void *object);
 extern void slurmdb_destroy_account_rec(void *object);
@@ -1734,6 +1829,9 @@ extern void slurmdb_destroy_report_acct_grouping(void *object);
 extern void slurmdb_destroy_report_cluster_grouping(void *object);
 extern void slurmdb_destroy_stats_rec(void *object);
 
+extern void slurmdb_free_slurmdb_stats_members(slurmdb_stats_t *stats);
+extern void slurmdb_destroy_slurmdb_stats(slurmdb_stats_t *stats);
+
 extern void slurmdb_init_assoc_rec(slurmdb_assoc_rec_t *assoc,
 				   bool free_it);
 extern void slurmdb_init_clus_res_rec(slurmdb_clus_res_rec_t *clus_res,
