@@ -51,7 +51,7 @@
  * IN job_id     - the job's id
  * IN signal     - signal number
  * IN flags      - see KILL_JOB_* flags in slurm.h
- * RET 0 on success, otherwise return -1 and set errno to indicate the error
+ * RET SLURM_SUCCESS on success, otherwise return SLURM_ERROR with errno set
  */
 extern int
 slurm_kill_job (uint32_t job_id, uint16_t signal, uint16_t flags)
@@ -73,7 +73,7 @@ slurm_kill_job (uint32_t job_id, uint16_t signal, uint16_t flags)
 	msg.msg_type    = REQUEST_CANCEL_JOB_STEP;
 	msg.data        = &req;
 	if (slurm_send_recv_controller_rc_msg(&msg, &rc, working_cluster_rec)<0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 
 	if (rc)
 		slurm_seterrno_ret(rc);
@@ -87,7 +87,7 @@ slurm_kill_job (uint32_t job_id, uint16_t signal, uint16_t flags)
  * IN job_id     - the job's id
  * IN step_id    - the job step's id
  * IN signal     - signal number
- * RET 0 on success, otherwise return -1 and set errno to indicate the error
+ * RET SLURM_SUCCESS on success, otherwise return SLURM_ERROR with errno set
  */
 extern int
 slurm_kill_job_step (uint32_t job_id, uint32_t step_id, uint16_t signal)
@@ -110,7 +110,7 @@ slurm_kill_job_step (uint32_t job_id, uint32_t step_id, uint16_t signal)
 	msg.data        = &req;
 
 	if (slurm_send_recv_controller_rc_msg(&msg, &rc, working_cluster_rec)<0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 
 	if (rc)
 		slurm_seterrno_ret(rc);
@@ -129,7 +129,7 @@ slurm_kill_job2(const char *job_id, uint16_t signal, uint16_t flags)
 
 	if (job_id == NULL) {
 		errno = EINVAL;
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 
 	slurm_msg_t_init(&msg);
@@ -144,7 +144,7 @@ slurm_kill_job2(const char *job_id, uint16_t signal, uint16_t flags)
         msg.data        = &req;
 
 	if (slurm_send_recv_controller_rc_msg(&msg, &cc, working_cluster_rec)<0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 
 	if (cc)
 		slurm_seterrno_ret(cc);
@@ -157,7 +157,7 @@ slurm_kill_job2(const char *job_id, uint16_t signal, uint16_t flags)
  *
  * IN msg_type - msg_type to send
  * IN kill_msg - job_step_kill_msg_t parameters.
- * RET 0 on success, otherwise return -1 and set errno to indicate the error
+ * RET SLURM_SUCCESS on success, otherwise return SLURM_ERROR with errno set
  */
 extern int slurm_kill_job_msg(uint16_t msg_type, job_step_kill_msg_t *kill_msg)
 {
@@ -169,7 +169,7 @@ extern int slurm_kill_job_msg(uint16_t msg_type, job_step_kill_msg_t *kill_msg)
         msg.data     = kill_msg;
 
 	if (slurm_send_recv_controller_rc_msg(&msg, &cc, working_cluster_rec)<0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 
 	if (cc)
 		slurm_seterrno_ret(cc);
