@@ -7,11 +7,11 @@
  *  Written by Morris Jette <jette1@llnl.gov>, et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -162,139 +162,75 @@ slurm_sprint_job_step_info ( job_step_info_t * job_step_ptr,
 	char limit_str[32];
 	char tmp_line[128];
 	char *out = NULL;
-	uint32_t cluster_flags = slurmdb_setup_cluster_flags();
+	char *line_end = (one_liner) ? " " : "\n   ";
 
 	/****** Line 1 ******/
 	slurm_make_time_str ((time_t *)&job_step_ptr->start_time, time_str,
 		sizeof(time_str));
 	if (job_step_ptr->time_limit == INFINITE)
-		sprintf(limit_str, "UNLIMITED");
+		snprintf(limit_str, sizeof(limit_str), "UNLIMITED");
 	else
 		secs2time_str ((time_t)job_step_ptr->time_limit * 60,
 				limit_str, sizeof(limit_str));
 	if (job_step_ptr->array_job_id) {
 		if (job_step_ptr->step_id == SLURM_PENDING_STEP) {
-			snprintf(tmp_line, sizeof(tmp_line),
-				 "StepId=%u_%u.TBD ",
-				 job_step_ptr->array_job_id,
-				 job_step_ptr->array_task_id);
+			xstrfmtcat(out, "StepId=%u_%u.TBD ",
+				   job_step_ptr->array_job_id,
+				   job_step_ptr->array_task_id);
 		} else if (job_step_ptr->step_id == SLURM_EXTERN_CONT) {
-			snprintf(tmp_line, sizeof(tmp_line),
-				 "StepId=%u_%u.extern ",
-				 job_step_ptr->array_job_id,
-				 job_step_ptr->array_task_id);
+			xstrfmtcat(out, "StepId=%u_%u.extern ",
+				   job_step_ptr->array_job_id,
+				   job_step_ptr->array_task_id);
 		} else {
-			snprintf(tmp_line, sizeof(tmp_line), "StepId=%u_%u.%u ",
-				 job_step_ptr->array_job_id,
-				 job_step_ptr->array_task_id,
-				 job_step_ptr->step_id);
+			xstrfmtcat(out, "StepId=%u_%u.%u ",
+				   job_step_ptr->array_job_id,
+				   job_step_ptr->array_task_id,
+				   job_step_ptr->step_id);
 		}
-		out = xstrdup(tmp_line);
 	} else {
 		if (job_step_ptr->step_id == SLURM_PENDING_STEP) {
-			snprintf(tmp_line, sizeof(tmp_line),
-				 "StepId=%u.TBD ",
-				 job_step_ptr->job_id);
+			xstrfmtcat(out, "StepId=%u.TBD ",
+				   job_step_ptr->job_id);
 		} else if (job_step_ptr->step_id == SLURM_EXTERN_CONT) {
-			snprintf(tmp_line, sizeof(tmp_line),
-				 "StepId=%u.extern ",
-				 job_step_ptr->job_id);
+			xstrfmtcat(out, "StepId=%u.extern ",
+				   job_step_ptr->job_id);
 		} else {
-			snprintf(tmp_line, sizeof(tmp_line), "StepId=%u.%u ",
-				 job_step_ptr->job_id, job_step_ptr->step_id);
+			xstrfmtcat(out, "StepId=%u.%u ",
+				   job_step_ptr->job_id,
+				   job_step_ptr->step_id);
 		}
-		out = xstrdup(tmp_line);
 	}
-	snprintf(tmp_line, sizeof(tmp_line),
-		 "UserId=%u StartTime=%s TimeLimit=%s",
-		 job_step_ptr->user_id, time_str, limit_str);
-	xstrcat(out, tmp_line);
-	if (one_liner)
-		xstrcat(out, " ");
-	else
-		xstrcat(out, "\n   ");
+	xstrfmtcat(out, "UserId=%u StartTime=%s TimeLimit=%s",
+		   job_step_ptr->user_id, time_str, limit_str);
 
 	/****** Line 2 ******/
-	snprintf(tmp_line, sizeof(tmp_line),
-		 "State=%s ",
-		 job_state_string(job_step_ptr->state));
-	xstrcat(out, tmp_line);
-	if (cluster_flags & CLUSTER_FLAG_BG) {
-		char *io_nodes = NULL;
-		select_g_select_jobinfo_get(job_step_ptr->select_jobinfo,
-					    SELECT_JOBDATA_IONODES,
-					    &io_nodes);
-		if (io_nodes) {
-			snprintf(tmp_line, sizeof(tmp_line),
-				 "Partition=%s MidplaneList=%s[%s] Gres=%s",
-				 job_step_ptr->partition,
-				 job_step_ptr->nodes, io_nodes,
-				 job_step_ptr->gres);
-			xfree(io_nodes);
-		} else
-			snprintf(tmp_line, sizeof(tmp_line),
-				 "Partition=%s MidplaneList=%s Gres=%s",
-				 job_step_ptr->partition,
-				 job_step_ptr->nodes,
-				 job_step_ptr->gres);
-	} else {
-		snprintf(tmp_line, sizeof(tmp_line),
-			"Partition=%s NodeList=%s Gres=%s",
-			job_step_ptr->partition, job_step_ptr->nodes,
-			job_step_ptr->gres);
-	}
-	xstrcat(out, tmp_line);
-	if (one_liner)
-		xstrcat(out, " ");
-	else
-		xstrcat(out, "\n   ");
+	xstrcat(out, line_end);
+	xstrfmtcat(out, "State=%s Partition=%s NodeList=%s",
+		   job_state_string(job_step_ptr->state),
+		   job_step_ptr->partition, job_step_ptr->nodes);
 
 	/****** Line 3 ******/
-	if (cluster_flags & CLUSTER_FLAG_BGQ) {
-		uint32_t nodes = 0;
-		select_g_select_jobinfo_get(job_step_ptr->select_jobinfo,
-					    SELECT_JOBDATA_NODE_CNT,
-					    &nodes);
-		convert_num_unit((float)nodes, tmp_node_cnt,
-				 sizeof(tmp_node_cnt), UNIT_NONE, NO_VAL,
-				 CONVERT_NUM_UNIT_EXACT);
-	} else {
-		convert_num_unit((float)_nodes_in_list(job_step_ptr->nodes),
-				 tmp_node_cnt, sizeof(tmp_node_cnt), UNIT_NONE,
-				 NO_VAL, CONVERT_NUM_UNIT_EXACT);
-	}
-
-	snprintf(tmp_line, sizeof(tmp_line),
-		"Nodes=%s CPUs=%u Tasks=%u Name=%s Network=%s",
-		 tmp_node_cnt, job_step_ptr->num_cpus, job_step_ptr->num_tasks,
-		 job_step_ptr->name, job_step_ptr->network);
-	xstrcat(out, tmp_line);
-	if (one_liner)
-		xstrcat(out, " ");
-	else
-		xstrcat(out, "\n   ");
+	convert_num_unit((float)_nodes_in_list(job_step_ptr->nodes),
+			 tmp_node_cnt, sizeof(tmp_node_cnt), UNIT_NONE,
+			 NO_VAL, CONVERT_NUM_UNIT_EXACT);
+	xstrcat(out, line_end);
+	xstrfmtcat(out, "Nodes=%s CPUs=%u Tasks=%u Name=%s Network=%s",
+		   tmp_node_cnt, job_step_ptr->num_cpus,
+		   job_step_ptr->num_tasks, job_step_ptr->name,
+		   job_step_ptr->network);
 
 	/****** Line 4 ******/
-	snprintf(tmp_line, sizeof(tmp_line), "TRES=%s",
-		 job_step_ptr->tres_alloc_str);
-	xstrcat(out, tmp_line);
-	if (one_liner)
-		xstrcat(out, " ");
-	else
-		xstrcat(out, "\n   ");
+	xstrcat(out, line_end);
+	xstrfmtcat(out, "TRES=%s", job_step_ptr->tres_alloc_str);
 
 	/****** Line 5 ******/
-	snprintf(tmp_line, sizeof(tmp_line),
-		"ResvPorts=%s Checkpoint=%u CheckpointDir=%s",
-		 job_step_ptr->resv_ports,
-		 job_step_ptr->ckpt_interval, job_step_ptr->ckpt_dir);
-	xstrcat(out, tmp_line);
-	if (one_liner)
-		xstrcat(out, " ");
-	else
-		xstrcat(out, "\n   ");
+	xstrcat(out, line_end);
+	xstrfmtcat(out, "ResvPorts=%s Checkpoint=%u CheckpointDir=%s",
+		   job_step_ptr->resv_ports, job_step_ptr->ckpt_interval,
+		   job_step_ptr->ckpt_dir);
 
 	/****** Line 6 ******/
+	xstrcat(out, line_end);
 	if (cpu_freq_debug(NULL, NULL, tmp_line, sizeof(tmp_line),
 			   job_step_ptr->cpu_freq_gov,
 			   job_step_ptr->cpu_freq_min,
@@ -305,16 +241,66 @@ slurm_sprint_job_step_info ( job_step_info_t * job_step_ptr,
 	}
 	xstrfmtcat(out, " Dist=%s",
 		   slurm_step_layout_type_name(job_step_ptr->task_dist));
-	if (one_liner)
-		xstrcat(out, " ");
-	else
-		xstrcat(out, "\n   ");
 
 	/****** Line 7 ******/
+	xstrcat(out, line_end);
 	xstrfmtcat(out, "SrunHost:Pid=%s:%u",
 		   job_step_ptr->srun_host, job_step_ptr->srun_pid);
-	xstrcat(out, "\n\n");
 
+	/****** Line (optional) ******/
+	if (job_step_ptr->cpus_per_tres) {
+		xstrcat(out, line_end);
+		xstrfmtcat(out, "CpusPerTres=%s", job_step_ptr->cpus_per_tres);
+	}
+
+	/****** Line (optional) ******/
+	if (job_step_ptr->mem_per_tres) {
+		xstrcat(out, line_end);
+		xstrfmtcat(out, "MemPerTres=%s", job_step_ptr->mem_per_tres);
+	}
+
+	/****** Line (optional) ******/
+	if (job_step_ptr->tres_bind) {
+		xstrcat(out, line_end);
+		xstrfmtcat(out, "TresBind=%s", job_step_ptr->tres_bind);
+	}
+
+	/****** Line (optional) ******/
+	if (job_step_ptr->tres_freq) {
+		xstrcat(out, line_end);
+		xstrfmtcat(out, "TresFreq=%s", job_step_ptr->tres_freq);
+	}
+
+	/****** Line (optional) ******/
+	if (job_step_ptr->tres_per_step) {
+		xstrcat(out, line_end);
+		xstrfmtcat(out, "TresPerStep=%s", job_step_ptr->tres_per_step);
+	}
+
+	/****** Line (optional) ******/
+	if (job_step_ptr->tres_per_node) {
+		xstrcat(out, line_end);
+		xstrfmtcat(out, "TresPerNode=%s", job_step_ptr->tres_per_node);
+	}
+
+	/****** Line (optional) ******/
+	if (job_step_ptr->tres_per_socket) {
+		xstrcat(out, line_end);
+		xstrfmtcat(out, "TresPerSocket=%s",
+			   job_step_ptr->tres_per_socket);
+	}
+
+	/****** Line (optional) ******/
+	if (job_step_ptr->tres_per_task) {
+		xstrcat(out, line_end);
+		xstrfmtcat(out, "TresPerTask=%s", job_step_ptr->tres_per_task);
+	}
+
+	/****** END OF JOB RECORD ******/
+	if (one_liner)
+		xstrcat(out, "\n");
+	else
+		xstrcat(out, "\n\n");
 	return out;
 }
 
@@ -463,7 +449,7 @@ _load_fed_steps(slurm_msg_t *req_msg, job_step_info_response_msg_t **resp,
 	if (!orig_msg)
 		slurm_seterrno_ret(ESLURM_INVALID_JOB_ID);
 
-	return SLURM_PROTOCOL_SUCCESS;
+	return SLURM_SUCCESS;
 }
 
 /*
@@ -477,7 +463,7 @@ _load_fed_steps(slurm_msg_t *req_msg, job_step_info_response_msg_t **resp,
  *	job steps
  * IN job_info_msg_pptr - place to store a job configuration pointer
  * IN show_flags - job step filtering options
- * RET 0 on success, otherwise return -1 and set errno to indicate the error
+ * RET SLURM_SUCCESS on success, otherwise return SLURM_ERROR with errno set
  * NOTE: free the response using slurm_free_job_step_info_response_msg
  */
 int
@@ -486,7 +472,7 @@ slurm_get_job_steps (time_t update_time, uint32_t job_id, uint32_t step_id,
 {
 	int rc;
 	slurm_msg_t req_msg;
-	job_step_info_request_msg_t req = {0};
+	job_step_info_request_msg_t req;
 	slurmdb_federation_rec_t *fed;
 	char *cluster_name = NULL;
 	void *ptr = NULL;
@@ -504,6 +490,7 @@ slurm_get_job_steps (time_t update_time, uint32_t job_id, uint32_t step_id,
 	}
 
 	slurm_msg_t_init(&req_msg);
+	memset(&req, 0, sizeof(req));
 	req.last_update  = update_time;
 	req.job_id       = job_id;
 	req.step_id      = step_id;
@@ -540,6 +527,7 @@ slurm_job_step_layout_get(uint32_t job_id, uint32_t step_id)
 
 	req.msg_type = REQUEST_STEP_LAYOUT;
 	req.data = &data;
+	memset(&data, 0, sizeof(data));
 	data.job_id = job_id;
 	data.step_id = step_id;
 
@@ -597,7 +585,8 @@ extern int slurm_job_step_stat(uint32_t job_id, uint32_t step_id,
 			return rc;
 		}
 		node_list = step_layout->node_list;
-		use_protocol_ver = step_layout->start_protocol_ver;
+		use_protocol_ver = MIN(SLURM_PROTOCOL_VERSION,
+				       step_layout->start_protocol_ver);
 	}
 
  	if (!*resp) {
@@ -613,7 +602,7 @@ extern int slurm_job_step_stat(uint32_t job_id, uint32_t step_id,
 
 	slurm_msg_t_init(&req_msg);
 
-	memset(&req, 0, sizeof(job_step_id_msg_t));
+	memset(&req, 0, sizeof(req));
 	resp_out->job_id = req.job_id = job_id;
 	resp_out->step_id = req.step_id = step_id;
 
@@ -729,7 +718,7 @@ extern int slurm_job_step_get_pids(uint32_t job_id, uint32_t step_id,
 
 	slurm_msg_t_init(&req_msg);
 
-	memset(&req, 0, sizeof(job_step_id_msg_t));
+	memset(&req, 0, sizeof(req));
         resp_out->job_id = req.job_id = job_id;
 	resp_out->step_id = req.step_id = step_id;
 
@@ -820,4 +809,3 @@ extern void slurm_job_step_stat_response_msg_free(void *object)
 		xfree(step_stat_msg);
 	}
 }
-
