@@ -6,11 +6,11 @@
  *  Written by Morris Jette <jette1@llnl.gov> et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -105,8 +105,6 @@ char *slurm_sprint_reservation_info ( reserve_info_t * resv_ptr,
 	char *out = NULL, *watts_str = NULL;
 	uint32_t duration;
 	time_t now = time(NULL);
-	uint32_t cluster_flags = slurmdb_setup_cluster_flags();
-	bool is_bluegene = cluster_flags & CLUSTER_FLAG_BG;
 	char *line_end = (one_liner) ? " " : "\n   ";
 	int i;
 
@@ -127,13 +125,12 @@ char *slurm_sprint_reservation_info ( reserve_info_t * resv_ptr,
 	/****** Line ******/
 	flag_str = reservation_flags_string(resv_ptr->flags);
 
-	xstrfmtcat(out, "%s=%s %sCnt=%u %sCnt=%u Features=%s "
+	xstrfmtcat(out, "Nodes=%s NodeCnt=%u CoreCnt=%u Features=%s "
 		   "PartitionName=%s Flags=%s",
-		   is_bluegene ? "Midplanes" : "Nodes", resv_ptr->node_list,
-		   is_bluegene ? "Midplane" : "Node",
+		   resv_ptr->node_list,
 		   (resv_ptr->node_cnt == NO_VAL) ? 0 : resv_ptr->node_cnt,
-		   is_bluegene ? "Cnode" : "Core", resv_ptr->core_cnt,
-		   resv_ptr->features,  resv_ptr->partition, flag_str);
+		   resv_ptr->core_cnt, resv_ptr->features, resv_ptr->partition,
+		   flag_str);
 	xfree(flag_str);
 	xstrcat(out, line_end);
 
@@ -191,6 +188,7 @@ extern int slurm_load_reservations (time_t update_time,
 	slurm_msg_t_init(&req_msg);
 	slurm_msg_t_init(&resp_msg);
 
+	memset(&req, 0, sizeof(req));
         req.last_update  = update_time;
         req_msg.msg_type = REQUEST_RESERVATION_INFO;
         req_msg.data     = &req;
@@ -215,5 +213,5 @@ extern int slurm_load_reservations (time_t update_time,
 		break;
 	}
 
-	return SLURM_PROTOCOL_SUCCESS;
+	return SLURM_SUCCESS;
 }
