@@ -146,6 +146,7 @@ extern void slurm_step_launch_params_t_init(slurm_step_launch_params_t *ptr)
 	ptr->pack_nnodes  = NO_VAL;
 	ptr->pack_ntasks  = NO_VAL;
 	ptr->pack_offset  = NO_VAL;
+	ptr->pack_step_cnt = NO_VAL;
 	ptr->pack_task_offset = NO_VAL;
 }
 
@@ -170,6 +171,8 @@ static void _rebuild_mpi_layout(slurm_step_ctx_t *ctx,
 	slurm_step_layout_t *new_step_layout, *orig_step_layout;
 
 	ctx->launch_state->mpi_info->pack_jobid = params->pack_jobid;
+	ctx->launch_state->mpi_info->pack_task_offset =
+		params->pack_task_offset;
 	new_step_layout = xmalloc(sizeof(slurm_step_layout_t));
 	orig_step_layout = ctx->launch_state->mpi_info->step_layout;
 	ctx->launch_state->mpi_info->step_layout = new_step_layout;
@@ -193,13 +196,11 @@ static void _rebuild_mpi_layout(slurm_step_ctx_t *ctx,
  * IN ctx - job step context generated by slurm_step_ctx_create
  * IN params - job step parameters
  * IN callbacks - Identify functions to be called when various events occur
- * IN pack_job_cnt - Total count of pack job steps to be launched, -1 otherwise
  * RET SLURM_SUCCESS or SLURM_ERROR (with errno set)
  */
 extern int slurm_step_launch(slurm_step_ctx_t *ctx,
 			     const slurm_step_launch_params_t *params,
-			     const slurm_step_launch_callbacks_t *callbacks,
-			     int pack_job_cnt)
+			     const slurm_step_launch_callbacks_t *callbacks)
 {
 	launch_tasks_request_msg_t launch;
 	char **env = NULL;
@@ -260,12 +261,15 @@ extern int slurm_step_launch(slurm_step_ctx_t *ctx,
 	launch.cred = ctx->step_resp->cred;
 	launch.job_step_id = ctx->step_resp->job_step_id;
 	launch.node_offset = params->node_offset;
+	launch.pack_step_cnt = params->pack_step_cnt;
 	launch.pack_jobid  = params->pack_jobid;
 	launch.pack_nnodes = params->pack_nnodes;
 	launch.pack_ntasks = params->pack_ntasks;
 	launch.pack_offset = params->pack_offset;
 	launch.pack_task_offset = params->pack_task_offset;
 	launch.pack_task_cnts = params->pack_task_cnts;
+	launch.pack_tids = params->pack_tids;
+	launch.pack_tid_offsets = params->pack_tid_offsets;
 	launch.pack_node_list = params->pack_node_list;
 	if (params->env == NULL) {
 		/*
@@ -456,12 +460,15 @@ extern int slurm_step_launch_add(slurm_step_ctx_t *ctx,
 	launch.spank_job_env_size = params->spank_job_env_size;
 	launch.cred = ctx->step_resp->cred;
 	launch.job_step_id = ctx->step_resp->job_step_id;
+	launch.pack_step_cnt = params->pack_step_cnt;
 	launch.pack_jobid  = params->pack_jobid;
 	launch.pack_nnodes = params->pack_nnodes;
 	launch.pack_ntasks = params->pack_ntasks;
 	launch.pack_offset = params->pack_offset;
 	launch.pack_task_offset = params->pack_task_offset;
 	launch.pack_task_cnts = params->pack_task_cnts;
+	launch.pack_tids = params->pack_tids;
+	launch.pack_tid_offsets = params->pack_tid_offsets;
 	launch.pack_node_list = params->pack_node_list;
 	if (params->env == NULL) {
 		/*
@@ -849,9 +856,10 @@ extern void slurm_step_launch_fwd_signal(slurm_step_ctx_t *ctx, int signo)
 	int retry_cnt = 0;
 
 	/* common to all tasks */
+	memset(&msg, 0, sizeof(msg));
 	msg.job_id      = ctx->job_id;
 	msg.job_step_id = ctx->step_resp->job_step_id;
-	msg.signal      = (uint32_t) signo;
+	msg.signal      = (uint16_t) signo;
 
 	slurm_mutex_lock(&sls->lock);
 
@@ -972,6 +980,7 @@ struct step_launch_state *step_launch_state_create(slurm_step_ctx_t *ctx)
 	/* NOTE: No malloc() of sls->mpi_info required */
 	sls->mpi_info->jobid = ctx->step_req->job_id;
 	sls->mpi_info->pack_jobid = NO_VAL;
+	sls->mpi_info->pack_task_offset = NO_VAL;
 	sls->mpi_info->stepid = ctx->step_resp->job_step_id;
 	sls->mpi_info->step_layout = layout;
 	sls->mpi_state = NULL;
@@ -1557,15 +1566,13 @@ _task_user_managed_io_handler(struct step_launch_state *sls,
 static void
 _handle_msg(void *arg, slurm_msg_t *msg)
 {
-	char *auth_info = slurm_get_auth_info();
 	struct step_launch_state *sls = (struct step_launch_state *)arg;
 	uid_t req_uid;
 	uid_t uid = getuid();
 	srun_user_msg_t *um;
 	int rc;
 
-	req_uid = g_slurm_auth_get_uid(msg->auth_cred, auth_info);
-	xfree(auth_info);
+	req_uid = g_slurm_auth_get_uid(msg->auth_cred);
 
 	if ((req_uid != slurm_uid) && (req_uid != 0) && (req_uid != uid)) {
 		error ("Security violation, slurm message from uid %u",
@@ -1664,7 +1671,7 @@ static int _fail_step_tasks(slurm_step_ctx_t *ctx, char *node, int ret_code)
 	slurm_cond_broadcast(&sls->cond);
 	slurm_mutex_unlock(&sls->lock);
 
-	memset(&msg, 0, sizeof(step_complete_msg_t));
+	memset(&msg, 0, sizeof(msg));
 	msg.job_id = ctx->job_id;
 	msg.job_step_id = ctx->step_resp->job_step_id;
 
@@ -1793,12 +1800,13 @@ static void _print_launch_msg(launch_tasks_request_msg_t *msg,
 			      char *hostname, int nodeid)
 {
 	int i;
-	char tmp_str[10], *task_list = NULL;
+	char *tmp_str = NULL, *task_list = NULL;
 	hostlist_t hl = hostlist_create(NULL);
 
 	for (i=0; i<msg->tasks_to_launch[nodeid]; i++) {
-		sprintf(tmp_str, "%u", msg->global_task_ids[nodeid][i]);
+		xstrfmtcat(tmp_str, "%u", msg->global_task_ids[nodeid][i]);
 		hostlist_push_host(hl, tmp_str);
+		xfree(tmp_str);
 	}
 	task_list = hostlist_ranged_string_xmalloc(hl);
 	hostlist_destroy(hl);
