@@ -443,12 +443,22 @@ extern int assoc_mgr_set_missing_uids();
  */
 extern void assoc_mgr_normalize_assoc_shares(slurmdb_assoc_rec_t *assoc);
 
-/* Find the position of the given TRES ID or type/name in the
- * assoc_mgr_tres_array, if the ID isn't found -1 is returned.
+/*
+ * Find the position of the given TRES ID or type/name in the
+ * assoc_mgr_tres_array. If the TRES name or ID isn't found -1 is returned.
  */
 extern int assoc_mgr_find_tres_pos(slurmdb_tres_rec_t *tres_rec, bool locked);
 
-/* calls assoc_mgr_find_tres_pos and returns the pointer in the
+/*
+ * Find the position of the given TRES name in the
+ * assoc_mgr_tres_array. Ignore anything after ":" in the TRES name.
+ * So tres_rec->name of "gpu" can match accounting TRES name of "gpu:tesla".
+ * If the TRES name isn't found -1 is returned.
+ */
+extern int assoc_mgr_find_tres_pos2(slurmdb_tres_rec_t *tres_rec, bool locked);
+
+/*
+ * Calls assoc_mgr_find_tres_pos and returns the pointer in the
  * assoc_mgr_tres_array.
  * NOTE: The assoc_mgr tres read lock needs to be locked before calling this
  * function and while using the returned record.
@@ -456,6 +466,15 @@ extern int assoc_mgr_find_tres_pos(slurmdb_tres_rec_t *tres_rec, bool locked);
 extern slurmdb_tres_rec_t *assoc_mgr_find_tres_rec(
 	slurmdb_tres_rec_t *tres_rec);
 
+/*
+ * Calls assoc_mgr_find_tres_pos and returns the pointer in the
+ * assoc_mgr_tres_array. Ignores GRES "type" option.
+ * NOTE: The assoc_mgr tres read lock needs to be locked before calling this
+ * function and while using the returned record.
+ */
+extern slurmdb_tres_rec_t *assoc_mgr_find_tres_rec2(
+		slurmdb_tres_rec_t *tres_rec);
+
 /* fills in allocates and sets tres_cnt based off tres_str
  * OUT tres_cnt - array to be filled in g_tres_cnt in length
  * IN tres_str - simple format of tres used with id and count set
@@ -494,12 +513,13 @@ extern char *assoc_mgr_make_tres_str_from_array(
 extern void assoc_mgr_get_default_qos_info(
 	slurmdb_assoc_rec_t *assoc_ptr, slurmdb_qos_rec_t *qos_rec);
 
-/* Calcuate a weighted tres value.
+/*
+ * Calculate a weighted tres value.
  * IN: tres_cnt - array of tres values of size g_tres_count.
  * IN: weights - weights to apply to tres values of size g_tres_count.
  * IN: flags - priority flags (toogle between MAX or SUM of tres).
  * IN: locked - whether the tres read assoc mgr lock is locked or not.
- * RET: returns the calcuated tres weight.
+ * RET: returns the calculated tres weight.
  */
 extern double assoc_mgr_tres_weighted(uint64_t *tres_cnt, double *weights,
 				      uint16_t flags, bool locked);
