@@ -129,7 +129,7 @@ static int _fd_lock_retry(int fd)
 static int _set_cpu_owner_lock(int cpu_id, uint32_t job_id)
 {
 	char tmp[PATH_MAX];
-	int fd, sz;
+	int fd;
 
 	snprintf(tmp, sizeof(tmp), "%s/cpu", slurmd_spooldir);
 	if ((mkdir(tmp, 0700) != 0) && (errno != EEXIST)) {
@@ -144,11 +144,13 @@ static int _set_cpu_owner_lock(int cpu_id, uint32_t job_id)
 	}
 	if (_fd_lock_retry(fd) < 0)
 		error("%s: fd_get_write_lock: %m %s", __func__, tmp);
-	sz = sizeof(uint32_t);
-	if (fd_write_n(fd, (void *) &job_id, sz) != sz)
-		error("%s: write: %m %s", __func__, tmp);
+	safe_write(fd, &job_id, sizeof(job_id));
 
 	return fd;
+
+rwfail:
+	error("%s: write: %m %s", __func__, tmp);
+	return fd;
 }
 
 /* Test if specified job ID owns this CPU for frequency/governor control
@@ -157,7 +159,7 @@ static int _test_cpu_owner_lock(int cpu_id, uint32_t job_id)
 {
 	char tmp[PATH_MAX];
 	uint32_t in_job_id;
-	int fd, sz;
+	int fd;
 
 	snprintf(tmp, sizeof(tmp), "%s/cpu", slurmd_spooldir);
 	if ((mkdir(tmp, 0700) != 0) && (errno != EEXIST)) {
@@ -176,14 +178,9 @@ static int _test_cpu_owner_lock(int cpu_id, uint32_t job_id)
 		close(fd);
 		return -1;
 	}
-	sz = sizeof(uint32_t);
-	if (fd_read_n(fd, (void *) &in_job_id, sz) != sz) {
-		error("%s: read: %m %s", __func__, tmp);
-		(void) fd_release_lock(fd);
-		close(fd);
-		return -1;
-	}
+	safe_read(fd, &in_job_id, sizeof(in_job_id));
 	(void) fd_release_lock(fd);
+
 	if (job_id != in_job_id) {
 		/* Result of various race conditions */
 		debug("%s: CPU %d now owned by job %u rather than job %u",
@@ -196,6 +193,12 @@ static int _test_cpu_owner_lock(int cpu_id, uint32_t job_id)
 	       __func__, cpu_id, job_id);
 
 	return 0;
+
+rwfail:
+	error("%s: read: %m %s", __func__, tmp);
+	(void) fd_release_lock(fd);
+	close(fd);
+	return -1;
 }
 
 /*
@@ -208,10 +211,10 @@ static int _derive_avail_freq(int cpuidx)
 
 	min_freq = _cpu_freq_get_scaling_freq(cpuidx, "scaling_min_freq");
 	if (min_freq == 0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	max_freq = _cpu_freq_get_scaling_freq(cpuidx, "scaling_max_freq");
 	if (max_freq == 0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	delta_freq = (max_freq - min_freq) / (FREQ_LIST_MAX - 1);
 	for (i = 0; i < (FREQ_LIST_MAX - 1); i++)
 		cpufreq[cpuidx].avail_freq[i] = min_freq + (delta_freq * i);
@@ -224,7 +227,7 @@ static int _derive_avail_freq(int cpuidx)
 /*
  * Find available frequencies on this cpu
  * IN      cpuidx     - cpu to query
- * Return: SLURM_SUCCESS or SLURM_FAILURE
+ * Return: SLURM_SUCCESS or SLURM_ERROR
  *         avail_freq array will be in strictly ascending order
  */
 static int
@@ -362,7 +365,7 @@ cpu_freq_init(slurmd_conf_t *conf)
 			}
 		}
 		fclose(fp);
-		if (_cpu_freq_cpu_avail(i) == SLURM_FAILURE)
+		if (_cpu_freq_cpu_avail(i) == SLURM_ERROR)
 			continue;
 		if ((i == 0) && (debug_flags & DEBUG_FLAG_CPU_FREQ)) {
 			for (j = 0; j < cpufreq[i].nfreq; j++) {
@@ -675,7 +678,7 @@ _cpu_freq_next_cpu(char **core_range, uint16_t *cpuidx,
 /*
  * Find current governor on this cpu
  *
- * Return: SLURM_SUCCESS or SLURM_FAILURE
+ * Return: SLURM_SUCCESS or SLURM_ERROR
  */
 static int
 _cpu_freq_get_cur_gov(int cpuidx)
@@ -688,17 +691,17 @@ _cpu_freq_get_cur_gov(int cpuidx)
 		 PATH_TO_CPU "cpu%u/cpufreq/scaling_governor", cpuidx);
 	if ((fp = fopen(path, "r")) == NULL) {
 		error("%s: Could not open scaling_governor", __func__);
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 	if (fgets(gov_value, LINE_LEN, fp) == NULL) {
 		error("%s: Could not read scaling_governor", __func__);
 		fclose(fp);
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 	if (strlen(gov_value) >= GOV_NAME_LEN) {
 		error("%s: scaling_governor is to long", __func__);
 		fclose(fp);
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 	strcpy(cpufreq[cpuidx].org_governor, gov_value);
 	fclose(fp);
@@ -728,7 +731,7 @@ _cpu_freq_set_gov(stepd_step_rec_t *job, int cpuidx, char* gov )
 		fclose(fp);
 	} else {
 		error("%s: Can not set CPU governor: %m", __func__);
-		rc = SLURM_FAILURE;
+		rc = SLURM_ERROR;
 	}
 	if (fd >= 0) {
 		(void) fd_release_lock(fd);
@@ -806,7 +809,7 @@ _cpu_freq_set_scaling_freq(stepd_step_rec_t *job, int cpx, uint32_t freq,
 		fclose(fp);
 	} else {
 		error("%s: Can not set %s: %m", __func__, option);
-		rc = SLURM_FAILURE;
+		rc = SLURM_ERROR;
 	}
 	if (fd >= 0) {
 		(void) fd_release_lock(fd);
@@ -827,7 +830,7 @@ _cpu_freq_set_scaling_freq(stepd_step_rec_t *job, int cpx, uint32_t freq,
  * Get current state
  *
  * IN:     cpuidx        - cpu to query
- * Return: SLURM_SUCCESS or SLURM_FAILURE
+ * Return: SLURM_SUCCESS or SLURM_ERROR
  */
 static int
 _cpu_freq_current_state(int cpuidx)
@@ -866,22 +869,22 @@ _cpu_freq_current_state(int cpuidx)
 	else
 		freq = _cpu_freq_get_scaling_freq(cpuidx, "scaling_cur_freq");
 	if (freq == 0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	cpufreq[cpuidx].org_frequency = freq;
 	freq = _cpu_freq_get_scaling_freq(cpuidx, "scaling_min_freq");
 	if (freq == 0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	cpufreq[cpuidx].org_min_freq = freq;
 	freq = _cpu_freq_get_scaling_freq(cpuidx, "scaling_max_freq");
 	if (freq == 0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	cpufreq[cpuidx].org_max_freq = freq;
 
 	if (_cpu_freq_get_cur_gov(cpuidx) == SLURM_SUCCESS) {
 		cpufreq[cpuidx].org_set = true;
 		return SLURM_SUCCESS;
 	} else {
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 }
 
@@ -894,7 +897,7 @@ _cpu_freq_govspec_string(uint32_t cpu_freq, int cpuidx)
 {
 
 	if ((cpu_freq & CPU_FREQ_RANGE_FLAG) == 0)
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 		
 	switch(cpu_freq)
 	{
@@ -919,7 +922,7 @@ _cpu_freq_govspec_string(uint32_t cpu_freq, int cpuidx)
 			strcpy(cpufreq[cpuidx].new_governor, "userspace");
 		return SLURM_SUCCESS;
 	default:
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 }
 
@@ -1032,7 +1035,7 @@ _cpu_freq_setup_data(stepd_step_rec_t *job, int cpx)
 	}
 
 	/* Get current state */
-	if (_cpu_freq_current_state(cpx) == SLURM_FAILURE)
+	if (_cpu_freq_current_state(cpx) == SLURM_ERROR)
 		return;
 
 	if (job->cpu_freq_min == NO_VAL &&
@@ -1176,23 +1179,23 @@ cpu_freq_set(stepd_step_rec_t *job)
 				 * Set it so it is in range
 				 * have to go to UserSpace to do it. */
 				rc = _cpu_freq_set_gov(job, i, "userspace");
-				if (rc == SLURM_FAILURE)
+				if (rc == SLURM_ERROR)
 					return;
 				rc = _cpu_freq_set_scaling_freq(job, i, freq,
 						         "scaling_setspeed");
-				if (rc == SLURM_FAILURE)
+				if (rc == SLURM_ERROR)
 					continue;
 				if (cpufreq[i].new_governor[0] == '\0') {
 					/* Not requesting new gov, so restore */
 					rc = _cpu_freq_set_gov(job, i,
 						cpufreq[i].org_governor);
-					if (rc == SLURM_FAILURE)
+					if (rc == SLURM_ERROR)
 						continue;
 				}
 			}
 			rc = _cpu_freq_set_scaling_freq(job, i, freq,
 							"scaling_max_freq");
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 		}
 		if (cpufreq[i].new_min_freq != NO_VAL) {
@@ -1202,40 +1205,40 @@ cpu_freq_set(stepd_step_rec_t *job)
 				 * Set it so it is in range
 				 * have to go to UserSpace to do it. */
 				rc = _cpu_freq_set_gov(job, i, "userspace");
-				if (rc == SLURM_FAILURE)
+				if (rc == SLURM_ERROR)
 					continue;
 				rc = _cpu_freq_set_scaling_freq(job, i, freq,
 						         "scaling_setspeed");
-				if (rc == SLURM_FAILURE)
+				if (rc == SLURM_ERROR)
 					continue;
 				if (cpufreq[i].new_governor[0] == '\0') {
 					/* Not requesting new gov, so restore */
 					rc= _cpu_freq_set_gov(job, i,
 						cpufreq[i].org_governor);
-					if (rc == SLURM_FAILURE)
+					if (rc == SLURM_ERROR)
 						continue;
 				}
 			}
 			rc= _cpu_freq_set_scaling_freq(job, i, freq,
 						       "scaling_min_freq");
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 		}
 		if (cpufreq[i].new_frequency != NO_VAL) {
 			if (xstrcmp(cpufreq[i].org_governor,"userspace")) {
 				rc = _cpu_freq_set_gov(job, i, "userspace");
-				if (rc == SLURM_FAILURE)
+				if (rc == SLURM_ERROR)
 					continue;
 			}
 			rc = _cpu_freq_set_scaling_freq(job, i,
 					cpufreq[i].new_frequency,
 					"scaling_setspeed");
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 		}
 		if (cpufreq[i].new_governor[0] != '\0') {
 			rc = _cpu_freq_set_gov(job, i, cpufreq[i].new_governor);
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 		}
 		if (debug_flags & DEBUG_FLAG_CPU_FREQ) {
@@ -1264,10 +1267,20 @@ cpu_freq_reset(stepd_step_rec_t *job)
 {
 	int i, rc, fd;
 	char freq_detail[100];
+	uint32_t jobid;
 
 	if ((!cpu_freq_count) || (!cpufreq))
 		return;
 
+#ifdef HAVE_NATIVE_CRAY
+	if (job->pack_jobid && (job->pack_jobid != NO_VAL))
+		jobid = job->pack_jobid;
+	else
+		jobid = job->jobid;
+#else
+	jobid = job->jobid;
+#endif
+
 	for (i = 0; i < cpu_freq_count; i++) {
 		if (cpufreq[i].new_frequency == NO_VAL
 		    && cpufreq[i].new_min_freq == NO_VAL
@@ -1275,18 +1288,18 @@ cpu_freq_reset(stepd_step_rec_t *job)
 		    && cpufreq[i].new_governor[0] == '\0')
 			continue; /* Nothing to reset on this CPU */
 
-		fd = _test_cpu_owner_lock(i, job->jobid);
+		fd = _test_cpu_owner_lock(i, jobid);
 		if (fd < 0)
 			continue;
 
 		if (cpufreq[i].new_frequency != NO_VAL) {
 			rc = _cpu_freq_set_gov(job, i, "userspace");
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 			rc = _cpu_freq_set_scaling_freq(job, i,
 					cpufreq[i].org_frequency,
 					"scaling_setspeed");
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 			cpufreq[i].new_governor[0] = 'u'; /* force gov reset */
 		}
@@ -1297,19 +1310,19 @@ cpu_freq_reset(stepd_step_rec_t *job)
 			rc = _cpu_freq_set_scaling_freq(job, i,
 					cpufreq[i].org_max_freq,
 					"scaling_max_freq");
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 		}
 		if (cpufreq[i].new_min_freq != NO_VAL) {
 			rc = _cpu_freq_set_scaling_freq(job, i,
 					cpufreq[i].org_min_freq,
 					"scaling_min_freq");
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 		}
 		if (cpufreq[i].new_governor[0] != '\0') {
 			rc = _cpu_freq_set_gov(job, i, cpufreq[i].org_governor);
-			if (rc == SLURM_FAILURE)
+			if (rc == SLURM_ERROR)
 				continue;
 		}
 
@@ -1362,14 +1375,10 @@ cpu_freq_to_string(char *buf, int buf_size, uint32_t cpu_freq)
 				  UNIT_KILO, NO_VAL, 1000, 0);
 }
 
-/*
- * Set environment variables associated with the frequency variables.
- */
-extern int
-cpu_freq_set_env(char* var, uint32_t argmin, uint32_t argmax, uint32_t arggov)
+extern char *cpu_freq_to_cmdline(uint32_t min, uint32_t max, uint32_t gov)
 {
-	uint32_t min, max, gov;
-	char bfgov[32], bfmin[32], bfmax[32], bfall[96];
+	char bfgov[32], bfmin[32], bfmax[32];
+	char *bfall = NULL;
 	bfgov[0] = '\0';
 	bfmin[0] = '\0';
 	bfmax[0] = '\0';
@@ -1379,49 +1388,59 @@ cpu_freq_set_env(char* var, uint32_t argmin, uint32_t argmax, uint32_t arggov)
 	 * Default value from slurmstepd for batch jobs is 0
 	 * Convert slurmstepd values to command line ones.
 	 */
-	min = argmin;
 	if (min == 0)
 		min = NO_VAL;
-	max = argmax;
 	if (max == 0)
 		max = NO_VAL;
-	gov = arggov;
 	if (gov == 0)
 		gov = NO_VAL;
 
 	if ((min == NO_VAL) && (max == NO_VAL) && (gov == NO_VAL))
-		return SLURM_SUCCESS;
+		return NULL;
 
 	if (min != NO_VAL) {
 		if (min & CPU_FREQ_RANGE_FLAG) {
 			cpu_freq_to_string(bfmin, sizeof(bfmin), min);
 		} else {
-			sprintf(bfmin, "%u", min);
+			snprintf(bfmin, 32, "%u", min);
 		}
 	}
 	if (max != NO_VAL) {
 		if (max & CPU_FREQ_RANGE_FLAG) {
 			cpu_freq_to_string(bfmax, sizeof(bfmax), max);
 		} else {
-			sprintf(bfmax, "%u", max);
+			snprintf(bfmax, 32, "%u", max);
 		}
 	}
 	if (gov != NO_VAL) {
 		cpu_freq_to_string(bfgov, sizeof(bfgov), gov);
 	}
 	if ((min != NO_VAL) && (max != NO_VAL) && (gov != NO_VAL)) {
-		sprintf(bfall, "%s-%s:%s", bfmin, bfmax, bfgov);
+		xstrfmtcat(bfall, "%s-%s:%s", bfmin, bfmax, bfgov);
 	} else if ((min != NO_VAL) && (max != NO_VAL)) {
-		sprintf(bfall, "%s-%s", bfmin, bfmax);
+		xstrfmtcat(bfall, "%s-%s", bfmin, bfmax);
 	} else if (max != NO_VAL) {
-		sprintf(bfall, "%s", bfmax);
+		xstrcat(bfall, bfmax);
 	} else if (gov != NO_VAL) {
-		sprintf(bfall, "%s", bfgov);
+		xstrcat(bfall, bfgov);
 	}
-	if (setenvf(NULL, var, "%s", bfall)) {
+
+	return bfall;
+}
+
+/*
+ * Set environment variables associated with the frequency variables.
+ */
+extern int cpu_freq_set_env(char *var, uint32_t min, uint32_t max,
+			    uint32_t gov)
+{
+	char *bfall = cpu_freq_to_cmdline(min, max, gov);
+	if (bfall && setenvf(NULL, var, "%s", bfall)) {
+		xfree(bfall);
 		error("Unable to set %s", var);
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
+	xfree(bfall);
 	return SLURM_SUCCESS;
 }
 
