@@ -42,6 +42,8 @@
 #include "slurm/slurm.h"
 #include "slurm/slurmdb.h"
 #include "src/common/bitstring.h"
+#include "src/common/job_resources.h"
+#include "src/common/node_conf.h"
 #include "src/common/pack.h"
 
 #define GRES_MAGIC 0x438a34d4
@@ -61,8 +63,21 @@ typedef struct {
 	char *path;
 } gres_device_t;
 
+#define GRES_CONF_OLD_FILE	0x01	/* File= is configured. No independent
+					 * information about Type= option.*/
+#define GRES_CONF_HAS_FILE	0x02	/* File= is configured */
+#define GRES_CONF_HAS_TYPE	0x04	/* Type= is configured */
+
+#define GRES_NO_CONSUME		0x0001	/* Requesting no consume of resources */
+
+/* GRES AutoDetect options */
+#define GRES_AUTODETECT_NONE    0x00000000
+#define GRES_AUTODETECT_NVML    0x00000001
+
 /* Gres state information gathered by slurmd daemon */
 typedef struct gres_slurmd_conf {
+	uint8_t config_flags;	/* See GRES_CONF_* values above */
+
 	/* Count of gres available in this configuration record */
 	uint64_t count;
 
@@ -73,7 +88,6 @@ typedef struct gres_slurmd_conf {
 
 	/* Device file associated with this configuration record */
 	char *file;
-	uint8_t has_file;	/* non-zero if file is set, flag for RPC */
 
 	/* Comma-separated list of communication link IDs (numbers) */
 	char *links;
@@ -81,13 +95,22 @@ typedef struct gres_slurmd_conf {
 	/* Name of this gres */
 	char *name;
 
-	/* Type of this gres (e.g. model name) */
+	/* Type of this GRES (e.g. model name) */
 	char *type_name;
 
-	/* Gres ID number */
+	/* GRES ID number */
 	uint32_t plugin_id;
 } gres_slurmd_conf_t;
 
+
+/* Extra data and functions to be passed in to the node_config_load() */
+typedef struct node_config_load {
+	/* How many CPUs there are configured on the node */
+	uint32_t cpu_cnt;
+	/* A pointer to the mac_to_abs function */
+	int (*xcpuinfo_mac_to_abs) (char *mac, char **abs);
+} node_config_load_t;
+
 /* Current GRES state information managed by slurmctld daemon */
 typedef struct gres_node_state {
 	/* Actual hardware found */
@@ -115,9 +138,15 @@ typedef struct gres_node_state {
 	uint64_t  gres_cnt_alloc;
 	bitstr_t *gres_bit_alloc;	/* If gres.conf contains File field */
 
-	/* Topology specific information */
+	/*
+	 * Topology specific information. In the case of gres/mps, there is one
+	 * topo record per file (GPU) and the size of the GRES bitmaps (i.e.
+	 * gres_bit_alloc and topo_gres_bitmap[#]) is equal to the number of
+	 * GPUs on the node while the count is a site-configurable value.
+	 */
 	uint16_t topo_cnt;		/* Size of topo_ arrays */
-	bitstr_t **links_bitmap;
+	int link_len;			/* Size of link_cnt */
+	int **links_cnt;		/* Count of links between GRES */
 	bitstr_t **topo_core_bitmap;
 	bitstr_t **topo_gres_bitmap;
 	uint64_t *topo_gres_cnt_alloc;
@@ -125,7 +154,13 @@ typedef struct gres_node_state {
 	uint32_t *topo_type_id;		/* GRES type (e.g. model ID) */
 	char **topo_type_name;		/* GRES type (e.g. model name) */
 
-	/* GRES type specific information (if gres.conf contains type option) */
+	/*
+	 * GRES type specific information (if gres.conf contains type option)
+	 *
+	 * NOTE: If a job requests GRES without a type specification, these
+	 * type_cnt_alloc will not be incremented. Only the gres_cnt_alloc
+	 * will be incremented.
+	 */
 	uint16_t type_cnt;		/* Size of type_ arrays */
 	uint64_t *type_cnt_alloc;
 	uint64_t *type_cnt_avail;
@@ -138,6 +173,7 @@ typedef struct gres_job_state {
 	char *gres_name;		/* GRES name (e.g. "gpu") */
 	uint32_t type_id;		/* GRES type (e.g. model ID) */
 	char *type_name;		/* GRES type (e.g. model name) */
+	uint16_t flags;			/* GRES_NO_CONSUME, etc. */
 
 	/* Count of required GRES resources plus associated CPUs and memory */
 	uint16_t cpus_per_gres;
@@ -155,12 +191,27 @@ typedef struct gres_job_state {
 	uint16_t def_cpus_per_gres;
 	uint64_t def_mem_per_gres;
 
+	/*
+	 * Selected resource details. One entry per node on the cluster.
+	 * Used by select/cons_tres to identify which resources would be
+	 * allocated on a node IF that node is included in the job allocation.
+	 * Once specific nodes are selected for the job allocation, select
+	 * portions of these arrays are copied to gres_bit_alloc and
+	 * gres_cnt_node_alloc. The fields can then be cleared.
+	 */
+	uint32_t total_node_cnt;	/* cluster total node count */
+	bitstr_t **gres_bit_select;	/* Per node GRES selected,
+					 * Used with GRES files */
+	uint64_t *gres_cnt_node_select;	/* Per node GRES selected,
+					 * Used without GRES files */
+
 	/* Allocated resources details */
 	uint64_t total_gres;		/* Count of allocated GRES to job */
-	uint64_t *gres_cnt_node_alloc;	/* Per node GRES allocated,
-					 * Used without GRES files */
 	uint32_t node_cnt;		/* 0 if no_consume */
-	bitstr_t **gres_bit_alloc;
+	bitstr_t **gres_bit_alloc;	/* Per node GRES allocated,
+					 * Used with GRES files */
+	uint64_t *gres_cnt_node_alloc;	/* Per node GRES allocated,
+					 * Used with and without GRES files */
 
 	/*
 	 * Resources currently allocated to job steps on each node.
@@ -171,10 +222,21 @@ typedef struct gres_job_state {
 	uint64_t  *gres_cnt_step_alloc;
 } gres_job_state_t;
 
+/* Used to set Prolog and Epilog env var. Currently designed for gres/mps. */
+typedef struct gres_epilog_info {
+	uint32_t plugin_id;	/* GRES ID number */
+	uint32_t node_cnt;	/* Count of all hosts allocated to job */
+	char *node_list;	/* List of all hosts allocated to job */
+	bitstr_t **gres_bit_alloc; /* Per-node bitmap of allocated resources */
+	uint64_t *gres_cnt_node_alloc;	/* Per node GRES allocated,
+					 * Used with and without GRES files */
+} gres_epilog_info_t;
+
 /* Gres job step state as used by slurmctld daemon */
 typedef struct gres_step_state {
 	uint32_t type_id;		/* GRES type (e.g. model ID) */
 	char *type_name;		/* GRES type (e.g. model name) */
+	uint16_t flags;			/* GRES_NO_CONSUME, etc. */
 
 	/* Count of required GRES resources plus associated CPUs and memory */
 	uint16_t cpus_per_gres;
@@ -193,6 +255,9 @@ typedef struct gres_step_state {
 	 * gres_bit_alloc are also set if the job's gres_bit_alloc is set
 	 */
 	uint64_t total_gres;		/* allocated GRES for this step */
+	uint64_t gross_gres;		/* used during the scheduling phase,
+					 * GRES that could be available for this
+					 * step if no other steps active */
 	uint64_t *gres_cnt_node_alloc;	/* Per node GRES allocated,
 					 * Used without GRES files */
 	uint32_t node_cnt;
@@ -202,12 +267,17 @@ typedef struct gres_step_state {
 
 /* Per-socket GRES availability information for scheduling purposes */
 typedef struct sock_gres {	/* GRES availability by socket */
+	bitstr_t *bits_any_sock;/* Per-socket GRES bitmap of this name & type */
+	bitstr_t **bits_by_sock;/* Per-socket GRES bitmap of this name & type */
 	uint64_t cnt_any_sock;	/* GRES count unconstrained by cores */
 	uint64_t *cnt_by_sock;	/* Per-socket GRES count of this name & type */
 	char *gres_name;	/* GRES name */
 	gres_job_state_t *job_specs;	/* Pointer to job info, for limits */
 	uint64_t max_node_gres;	/* Maximum GRES permitted on this node */
+	gres_node_state_t *node_specs;	/* Pointer to node info, for state */
 	uint32_t plugin_id;	/* Plugin ID (for quick search) */
+	int sock_cnt;		/* Socket count, size of bits_by_sock and
+				 * cnt_by_sock arrays */
 	uint64_t total_cnt;	/* Total GRES count of this name & type */
 	uint32_t type_id;	/* GRES type (e.g. model ID) */
 	char *type_name;	/* GRES type (e.g. model name) */
@@ -222,12 +292,14 @@ typedef struct gres_mc_data {
 	uint16_t threads_per_core;  /* threads per core required by job */
 
 	uint16_t cpus_per_task;     /* Count of CPUs per task */
+	uint32_t ntasks_per_job;    /* number of tasks to invoke for job or NO_VAL */
 	uint16_t ntasks_per_node;   /* number of tasks to invoke on each node */
 	uint16_t ntasks_per_board;  /* number of tasks to invoke on each board */
 	uint16_t ntasks_per_socket; /* number of tasks to invoke on each socket */
 	uint16_t ntasks_per_core;   /* number of tasks to invoke on each core */
 	uint8_t overcommit;         /* processors being over subscribed */
 	uint16_t plane_size;        /* plane size for SLURM_DIST_PLANE */
+	uint32_t task_dist;         /* task distribution directives */
 	uint8_t whole_node;         /* allocate entire node */
 } gres_mc_data_t;
 
@@ -261,28 +333,46 @@ extern int gres_plugin_fini(void);
  * Perform reconfig, re-read any configuration files
  * OUT did_change - set if gres configuration changed
  */
-extern int gres_plugin_reconfig(bool *did_change);
+extern int gres_plugin_reconfig(void);
 
 /*
- * Provide a plugin-specific help message for salloc, sbatch and srun
- * IN/OUT msg - buffer provided by caller and filled in by plugin
- * IN msg_size - size of msg buffer in bytes
+ * Return a plugin-specific help message for salloc, sbatch and srun
+ * Result must be xfree()'d
  */
-extern int gres_plugin_help_msg(char *msg, int msg_size);
+extern char *gres_plugin_help_msg(void);
+
+/*
+ * Convert a GRES name or model into a number for faster comparison operations
+ * IN name - GRES name or model
+ * RET - An int representing a custom hash of the name
+ */
+extern uint32_t gres_plugin_build_id(char *name);
+
+/*
+ * Takes a GRES config line (typically from slurm.conf) and remove any
+ * records for GRES which are not defined in GresTypes.
+ * RET string of valid GRES, Release memory using xfree()
+ */
+extern char *gres_plugin_name_filter(char *orig_gres, char *nodes);
 
 /*
  **************************************************************************
- *                 PLUGIN CALLS FOR SLURMD DAEMOtN                         *
+ *                 PLUGIN CALLS FOR SLURMD DAEMON                         *
  **************************************************************************
  */
 /*
  * Load this node's configuration (how many resources it has, topology, etc.)
- * IN cpu_cnt - Number of CPUs on configured on this node
+ * IN cpu_cnt - Number of CPUs configured on this node
  * IN node_name - Name of this node
+ * IN gres_list - Node's GRES information as loaded from slurm.conf by slurmd
  * IN xcpuinfo_abs_to_mac - Pointer to xcpuinfo_abs_to_mac() funct, if available
+ * IN xcpuinfo_mac_to_abs - Pointer to xcpuinfo_mac_to_abs() funct, if available
+ * NOTE: Called from slurmd and slurmstepd
  */
 extern int gres_plugin_node_config_load(uint32_t cpu_cnt, char *node_name,
-					void *xcpuinfo_abs_to_mac);
+					List gres_list,
+					void *xcpuinfo_abs_to_mac,
+					void *xcpuinfo_mac_to_abs);
 
 /*
  * Pack this node's gres configuration into a buffer
@@ -336,11 +426,12 @@ extern int gres_plugin_node_config_unpack(Buf buffer, char *node_name);
  * Validate a node's configuration and put a gres record onto a list
  * Called immediately after gres_plugin_node_config_unpack().
  * IN node_name - name of the node for which the gres information applies
- * IN orig_config - Gres information supplied from slurm.conf
+ * IN orig_config - Gres information supplied from merged slurm.conf/gres.conf
  * IN/OUT new_config - Updated gres info from slurm.conf if FastSchedule=0
  * IN/OUT gres_list - List of Gres records for this node to track usage
- * IN cpu_cnt - Count of CPUs (threads) on this node
- * IN core_cnt - Count of cores on this node
+ * IN threads_per_core - Count of CPUs (threads) per core on this node
+ * IN cores_per_sock - Count of cores per socket on this node
+ * IN sock_cnt - Count of sockets on this node
  * IN fast_schedule - 0: Validate and use actual hardware configuration
  *		      1: Validate hardware config, but use slurm.conf config
  *		      2: Don't validate hardware, use slurm.conf configuration
@@ -350,7 +441,8 @@ extern int gres_plugin_node_config_validate(char *node_name,
 					    char *orig_config,
 					    char **new_config,
 					    List *gres_list,
-					    int cpu_cnt, int core_cnt,
+					    int threads_per_core,
+					    int cores_per_sock, int sock_cnt,
 					    uint16_t fast_schedule,
 					    char **reason_down);
 
@@ -369,18 +461,22 @@ extern void gres_plugin_node_feature(char *node_name,
 /*
  * Note that a node's configuration has been modified (e.g. "scontol update ..")
  * IN node_name - name of the node for which the gres information applies
- * IN orig_config - Gres information supplied from slurm.conf
- * IN/OUT new_config - Updated gres info from slurm.conf if FastSchedule=0
+ * IN new_gres - Updated GRES information supplied from slurm.conf or scontrol
+ * IN/OUT gres_str - Node's current GRES string, updated as needed
  * IN/OUT gres_list - List of Gres records for this node to track usage
  * IN fast_schedule - 0: Validate and use actual hardware configuration
  *		      1: Validate hardware config, but use slurm.conf config
  *		      2: Don't validate hardware, use slurm.conf configuration
+ * IN cores_per_sock - Number of cores per socket on this node
+ * IN sock_per_node - Total count of sockets on this node (on any board)
  */
 extern int gres_plugin_node_reconfig(char *node_name,
-				     char *orig_config,
-				     char **new_config,
+				     char *new_gres,
+				     char **gres_str,
 				     List *gres_list,
-				     uint16_t fast_schedule);
+				     uint16_t fast_schedule,
+				     int cores_per_sock,
+				     int sock_per_node);
 
 /*
  * Pack a node's current gres status, called from slurmctld for save/restore
@@ -437,7 +533,8 @@ extern char *gres_get_node_drain(List gres_list);
 extern char *gres_get_node_used(List gres_list);
 
 /*
- * Give the total system count of a given gres
+ * Give the total system count of a given GRES
+ * Returns NO_VAL64 if name not found
  */
 extern uint64_t gres_get_system_cnt(char *name);
 
@@ -459,7 +556,8 @@ extern uint64_t gres_plugin_node_config_cnt(List gres_list, char *name);
  * RET SLURM_SUCCESS or error code
  */
 extern int gres_plugin_node_count(List gres_list, int arr_len,
-				  int *gres_count_ids, int *gres_count_vals,
+				  uint32_t *gres_count_ids,
+				  uint64_t *gres_count_vals,
 				  int val_type);
 
 /*
@@ -483,6 +581,43 @@ extern int gres_plugin_job_count(List gres_list, int arr_len,
  */
 extern char *gres_plugin_job_alloc_count(List gres_list);
 
+/*
+ * Pack a job's allocated gres information for use by prolog/epilog
+ * IN gres_list - generated by gres_plugin_job_config_validate()
+ * IN/OUT buffer - location to write state to
+ */
+extern int gres_plugin_job_alloc_pack(List gres_list, Buf buffer,
+				      uint16_t protocol_version);
+
+/*
+ * Unpack a job's allocated gres information for use by prolog/epilog
+ * OUT gres_list - restored state stored by gres_plugin_job_alloc_pack()
+ * IN/OUT buffer - location to read state from
+ */
+extern int gres_plugin_job_alloc_unpack(List *gres_list, Buf buffer,
+					uint16_t protocol_version);
+
+/*
+ * Build List of information needed to set job's Prolog or Epilog environment
+ * variables
+ *
+ * IN job_gres_list - job's GRES allocation info
+ * IN hostlist - list of nodes associated with the job
+ * RET information about the job's GRES allocation needed by Prolog or Epilog
+ */
+extern List gres_plugin_epilog_build_env(List job_gres_list, char *node_list);
+
+/*
+ * Set environment variables as appropriate for a job's prolog or epilog based
+ * GRES allocated to the job.
+ *
+ * IN/OUT epilog_env_ptr - environment variable array
+ * IN epilog_gres_list - generated by TBD
+ * IN node_inx - zero origin node index
+ */
+extern void gres_plugin_epilog_set_env(char ***epilog_env_ptr,
+				       List epilog_gres_list, int node_inx);
+
 /*
  * Given a job's requested GRES configuration, validate it and build a GRES list
  * Note: This function can be used for a new request with gres_list==NULL or
@@ -507,6 +642,7 @@ extern char *gres_plugin_job_alloc_count(List gres_list);
  * RET SLURM_SUCCESS or ESLURM_INVALID_GRES
  */
 extern int gres_plugin_job_state_validate(char *cpus_per_tres,
+					  char *tres_freq,
 					  char *tres_per_job,
 					  char *tres_per_node,
 					  char *tres_per_socket,
@@ -521,6 +657,31 @@ extern int gres_plugin_job_state_validate(char *cpus_per_tres,
 					  uint16_t *cpus_per_task,
 					  List *gres_list);
 
+/*
+ * Determine if a job's specified GRES can be supported. This is designed to
+ * prevent the running of a job using the GRES options only supported by the
+ * select/cons_tres plugin when switching (on slurmctld restart) from the
+ * cons_tres plugin to any other select plugin.
+ *
+ * IN gres_list - List of GRES records for this job to track usage
+ * RET SLURM_SUCCESS or ESLURM_INVALID_GRES
+ */
+extern int gres_plugin_job_revalidate(List gres_list);
+
+/*
+ * Determine if a job's specified GRES are currently valid. This is designed to
+ * manage jobs allocated GRES which are either no longer supported or a GRES
+ * configured with the "File" option in gres.conf where the count has changed,
+ * in which case we don't know how to map the job's old GRES bitmap onto the
+ * current GRES bitmaps.
+ *
+ * IN job_id - ID of job being validated (used for logging)
+ * IN job_gres_list - List of GRES records for this job to track usage
+ * RET SLURM_SUCCESS or ESLURM_INVALID_GRES
+ */
+extern int gres_plugin_job_revalidate2(uint32_t job_id, List job_gres_list,
+				       bitstr_t *node_bitmap);
+
 /*
  * Clear GRES allocation info for all job GRES at start of scheduling cycle
  * Return TRUE if any gres_per_job constraints to satisfy
@@ -543,11 +704,13 @@ extern bool gres_plugin_job_sched_test2(List job_gres_list, List sock_gres_list,
 					uint32_t job_id);
 
 /*
- * Update a job's total_gres counter as we add a node to potential allocaiton
+ * Update a job's total_gres counter as we add a node to potential allocation
  * IN job_gres_list - List of job's GRES requirements (job_gres_state_t)
  * IN sock_gres_list - Per socket GRES availability on this node (sock_gres_t)
+ * IN avail_cpus - CPUs currently available on this node
  */
-extern void gres_plugin_job_sched_add(List job_gres_list, List sock_gres_list);
+extern void gres_plugin_job_sched_add(List job_gres_list, List sock_gres_list,
+				      uint16_t avail_cpus);
 
 /*
  * Create/update List GRES that can be made available on the specified node
@@ -671,6 +834,9 @@ extern uint32_t gres_plugin_job_test(List job_gres_list, List node_gres_list,
  * IN node_name       - name of the node (for logging)
  * IN enforce_binding - if true then only use GRES with direct access to cores
  * IN s_p_n           - Expected sockets_per_node (NO_VAL if not limited)
+ * OUT req_sock_map   - bitmap of specific requires sockets
+ * IN user_id         - job's user ID
+ * IN node_inx        - index of node to be evaluated
  * RET: List of sock_gres_t entries identifying what resources are available on
  *	each core. Returns NULL if none available. Call FREE_NULL_LIST() to
  *	release memory.
@@ -679,7 +845,9 @@ extern List gres_plugin_job_test2(List job_gres_list, List node_gres_list,
 				  bool use_total_gres, bitstr_t *core_bitmap,
 				  uint16_t sockets, uint16_t cores_per_sock,
 				  uint32_t job_id, char *node_name,
-				  bool enforce_binding, uint32_t s_p_n);
+				  bool enforce_binding, uint32_t s_p_n,
+				  bitstr_t **req_sock_map, uint32_t user_id,
+				  const uint32_t node_inx);
 
 /*
  * Determine which GRES can be used on this node given the available cores.
@@ -716,7 +884,6 @@ extern int gres_plugin_job_core_filter2(List sock_gres_list, uint64_t avail_mem,
  *	sockets/cores are required
  * IN mc_ptr - job's multi-core specs, NO_VAL and INFINITE mapped to zero
  * IN sock_gres_list - list of sock_gres_t entries built by gres_plugin_job_test2()
- * IN avail_cores_per_sock - Count of available cores on each socket
  * IN sockets - Count of sockets on the node
  * IN cores_per_socket - Count of cores per socket on the node
  * IN cpus_per_core - Count of CPUs per core on the node
@@ -724,9 +891,8 @@ extern int gres_plugin_job_core_filter2(List sock_gres_list, uint64_t avail_mem,
  * IN min_tasks_this_node - Minimum count of tasks that can be started on this
  *                          node, UPDATED
  * IN max_tasks_this_node - Maximum count of tasks that can be started on this
- *                          node, UPDATED
+ *                          node or NO_VAL, UPDATED
  * IN rem_nodes - desired additional node count to allocate, including this node
- * IN rem_tasks - desired additional task count to allocate
  * IN enforce_binding - GRES must be co-allocated with cores
  * IN first_pass - set if first scheduling attempt for this job, use
  *		   co-located GRES and cores if possible
@@ -734,36 +900,103 @@ extern int gres_plugin_job_core_filter2(List sock_gres_list, uint64_t avail_mem,
  */
 extern void gres_plugin_job_core_filter3(gres_mc_data_t *mc_ptr,
 					 List sock_gres_list,
-					 uint16_t *avail_cores_per_sock,
 					 uint16_t sockets,
 					 uint16_t cores_per_socket,
 					 uint16_t cpus_per_core,
 					 uint16_t *avail_cpus,
-					 int *min_tasks_this_node,
-					 int *max_tasks_this_node,
+					 uint32_t *min_tasks_this_node,
+					 uint32_t *max_tasks_this_node,
 					 int rem_nodes,
-					 int rem_tasks,
 					 bool enforce_binding,
 					 bool first_pass,
 					 bitstr_t *avail_core);
 
 /*
- * Allocate resource to a job and update node and job gres information
+ * Return the maximum number of tasks that can be started on a node with
+ * sock_gres_list (per-socket GRES details for some node)
+ */
+extern uint32_t gres_plugin_get_task_limit(List sock_gres_list);
+
+/*
+ * Make final GRES selection for the job
+ * sock_gres_list IN - per-socket GRES details, one record per allocated node
+ * job_id IN - job ID for logging
+ * job_res IN - job resource allocation
+ * overcommit IN - job's ability to overcommit resources
+ * tres_mc_ptr IN - job's multi-core options
+ * node_table_ptr IN - slurmctld's node records
+ * RET SLURM_SUCCESS or error code
+ */
+extern int gres_plugin_job_core_filter4(List *sock_gres_list, uint32_t job_id,
+					struct job_resources *job_res,
+					uint8_t overcommit,
+					gres_mc_data_t *tres_mc_ptr,
+					struct node_record *node_table_ptr);
+
+/*
+ * Determine if job GRES specification includes a tres-per-task specification
+ * RET TRUE if any GRES requested by the job include a tres-per-task option
+ */
+extern bool gres_plugin_job_tres_per_task(List job_gres_list);
+
+/*
+ * Determine if the job GRES specification includes a mem-per-tres specification
+ * RET largest mem-per-tres specification found
+ */
+extern uint64_t gres_plugin_job_mem_max(List job_gres_list);
+
+/*
+ * Set per-node memory limits based upon GRES assignments
+ * RET TRUE if mem-per-tres specification used to set memory limits
+ */
+extern bool gres_plugin_job_mem_set(List job_gres_list,
+				    job_resources_t *job_res);
+
+/*
+ * Determine the minimum number of CPUs required to satify the job's GRES
+ *	request (based upon total GRES times cpus_per_gres value)
+ * node_count IN - count of nodes in job allocation
+ * sockets_per_node IN - count of sockets per node in job allocation
+ * task_count IN - count of tasks in job allocation
+ * job_gres_list IN - job GRES specification
+ * RET count of required CPUs for the job
+ */
+extern int gres_plugin_job_min_cpus(uint32_t node_count,
+				    uint32_t sockets_per_node,
+				    uint32_t task_count,
+				    List job_gres_list);
+
+/*
+ * Determine the minimum number of CPUs required to satify the job's GRES
+ *	request on one node
+ * sockets_per_node IN - count of sockets per node in job allocation
+ * tasks_per_node IN - count of tasks per node in job allocation
+ * job_gres_list IN - job GRES specification
+ * RET count of required CPUs for the job
+ */
+extern int gres_plugin_job_min_cpu_node(uint32_t sockets_per_node,
+					uint32_t tasks_per_node,
+					List job_gres_list);
+
+/*
+ * Select and allocate GRES to a job and update node and job GRES information
  * IN job_gres_list - job's gres_list built by gres_plugin_job_state_validate()
  * IN node_gres_list - node's gres_list built by
  *		       gres_plugin_node_config_validate()
  * IN node_cnt    - total number of nodes originally allocated to the job
- * IN node_offset - zero-origin index to the node of interest
+ * IN node_index  - zero-origin global node index
+ * IN node_offset - zero-origin index in job allocation to the node of interest
  * IN job_id      - job's ID (for logging)
  * IN node_name   - name of the node (for logging)
  * IN core_bitmap - cores allocated to this job on this node (NULL if not
  *                  available)
+ * IN user_id     - job's user ID
  * RET SLURM_SUCCESS or error code
  */
 extern int gres_plugin_job_alloc(List job_gres_list, List node_gres_list,
-				 int node_cnt, int node_offset,
+				 int node_cnt, int node_index, int node_offset,
 				 uint32_t job_id, char *node_name,
-				 bitstr_t *core_bitmap);
+				 bitstr_t *core_bitmap, uint32_t user_id);
 
 /* Clear any vestigial job gres state. This may be needed on job requeue. */
 extern void gres_plugin_job_clear(List job_gres_list);
@@ -776,11 +1009,19 @@ extern void gres_plugin_job_clear(List job_gres_list);
  * IN node_offset - zero-origin index to the node of interest
  * IN job_id      - job's ID (for logging)
  * IN node_name   - name of the node (for logging)
+ * IN old_job     - true if job started before last slurmctld reboot.
+ *		    Immediately after slurmctld restart and before the node's
+ *		    registration, the GRES type and topology. This results in
+ *		    some incorrect internal bookkeeping, but does not cause
+ *		    failures in terms of allocating GRES to jobs.
+ * IN user_id     - job's user ID
+ * IN: job_fini   - job fully terminating on this node (not just a test)
  * RET SLURM_SUCCESS or error code
  */
 extern int gres_plugin_job_dealloc(List job_gres_list, List node_gres_list,
 				   int node_offset, uint32_t job_id,
-				   char *node_name);
+				   char *node_name, bool old_job,
+				   uint32_t user_id, bool job_fini);
 
 /*
  * Merge one job's gres allocation into another job's gres allocation.
@@ -908,13 +1149,32 @@ extern int gres_plugin_step_state_unpack(List *gres_list, Buf buffer,
 extern uint64_t gres_plugin_step_count(List step_gres_list, char *gres_name);
 
 /*
- * Set environment variables as required for all tasks of a job step
+ * Configure the GRES hardware allocated to the current step while privileged
+ *
+ * IN step_gres_list - Step's GRES specification
+ * IN node_id        - relative position of this node in step
+ * IN settings       - string containing configuration settings for the hardware
+ */
+extern void gres_plugin_step_hardware_init(List step_gres_list,
+					   uint32_t node_id, char *settings);
+
+/*
+ * Optionally undo GRES hardware configuration while privileged
+ */
+extern void gres_plugin_step_hardware_fini(void);
+
+/*
+ * Set environment as required for all tasks of a job step
  * IN/OUT job_env_ptr - environment variable array
- * IN step_gres_list - generated by gres_plugin_step_allocate()
- * IN accel_bind_type - GRES binding options
+ * IN step_gres_list - generated by gres_plugin_step_alloc()
+ * IN accel_bind_type - GRES binding options (old format, a bitmap)
+ * IN tres_bind - TRES binding directives (new format, a string)
+ * IN tres_freq - TRES power management directives
+ * IN local_proc_id - task rank, local to this compute node only
  */
 extern void gres_plugin_step_set_env(char ***job_env_ptr, List step_gres_list,
-				     uint16_t accel_bind_type);
+				     uint16_t accel_bind_type, char *tres_bind,
+				     char *tres_freq, int local_proc_id);
 
 /*
  * Log a step's current gres state
@@ -925,18 +1185,23 @@ extern void gres_plugin_step_state_log(List gres_list, uint32_t job_id,
 				       uint32_t step_id);
 
 /*
- * Determine how many cores of a job's allocation can be allocated to a job
+ * Determine how many cores of a job's allocation can be allocated to a step
  *	on a specific node
  * IN job_gres_list - a running job's gres info
  * IN/OUT step_gres_list - a pending job step's gres requirements
  * IN node_offset - index into the job's node allocation
+ * IN first_step_node - true if this is node zero of the step (do initialization)
+ * IN cpus_per_task - number of CPUs required per task
+ * IN max_rem_nodes - maximum nodes remaining for step (including this one)
  * IN ignore_alloc - if set ignore resources already allocated to running steps
  * IN job_id, step_id - ID of the step being allocated.
  * RET Count of available cores on this node (sort of):
  *     NO_VAL64 if no limit or 0 if node is not usable
  */
 extern uint64_t gres_plugin_step_test(List step_gres_list, List job_gres_list,
-				      int node_offset, bool ignore_alloc,
+				      int node_offset, bool first_step_node,
+				      uint16_t cpus_per_task, int max_rem_nodes,
+				      bool ignore_alloc,
 				      uint32_t job_id, uint32_t step_id);
 
 /*
@@ -945,12 +1210,16 @@ extern uint64_t gres_plugin_step_test(List step_gres_list, List job_gres_list,
  *		gres_plugin_step_state_validate()
  * IN job_gres_list - job's gres_list built by gres_plugin_job_state_validate()
  * IN node_offset - job's zero-origin index to the node of interest
+ * IN first_step_node - true if this is node zero of the step (do initialization)
+ * IN tasks_on_node - number of tasks to be launched on this node
+ * IN rem_nodes - desired additional node count to allocate, including this node
  * IN job_id, step_id - ID of the step being allocated.
  * RET SLURM_SUCCESS or error code
  */
 extern int gres_plugin_step_alloc(List step_gres_list, List job_gres_list,
-				  int node_offset, uint32_t job_id,
-				  uint32_t step_id);
+				  int node_offset, bool first_step_node,
+				  uint16_t tasks_on_node, uint32_t rem_nodes,
+				  uint32_t job_id, uint32_t step_id);
 
 /*
  * Deallocate resource to a step and update job and step gres information
@@ -1026,7 +1295,7 @@ enum gres_step_data_type {
 
 /*
  * get data from a step's GRES data structure
- * IN job_gres_list  - step's GRES data structure
+ * IN step_gres_list  - step's GRES data structure
  * IN gres_name - name of a GRES type
  * IN node_inx - zero-origin index of the node within the job's allocation
  *	for which data is desired. Note this can differ from the step's
@@ -1043,7 +1312,10 @@ extern int gres_get_step_info(List step_gres_list, char *gres_name,
 extern gres_job_state_t *gres_get_job_state(List gres_list, char *name);
 extern gres_step_state_t *gres_get_step_state(List gres_list, char *name);
 
-/* Translate a gres_list into a tres_str
+extern uint32_t gres_get_autodetect_types(void);
+
+/*
+ * Translate a gres_list into a tres_str
  * IN gres_list - filled in with gres_job_state_t or gres_step_state_t's
  * IN is_job - if is job function expects gres_job_state_t's else
  *             gres_step_state_t's
@@ -1076,6 +1348,24 @@ extern void gres_set_node_tres_cnt(List gres_list, uint64_t *tres_cnt,
 /* return the major info from a given path of a device */
 extern char *gres_device_major(char *dev_path);
 
-extern void destroy_gres_device(void *p);
+/* Free memory for gres_device_t record */
+extern void destroy_gres_device(void *gres_device_ptr);
+
+/* Destroy a gres_slurmd_conf_t record, free it's memory */
+extern void destroy_gres_slurmd_conf(void *x);
+
+/*
+ * Convert GRES config_flags to a string. The pointer returned references local
+ * storage in this function, which is not re-entrant.
+ */
+extern char *gres_flags2str(uint8_t config_flags);
+
+/*
+ * Creates a gres_slurmd_conf_t record to add to a list of gres_slurmd_conf_t
+ * records
+ */
+extern void add_gres_to_list(List gres_list, char *name, uint64_t device_cnt,
+			     int cpu_cnt, char *cpu_aff_abs_range,
+			     char *device_file, char *type, char *links);
 
 #endif /* !_GRES_H */
