@@ -6,11 +6,11 @@
  *  Written by Mark A. Grondona <mgrondona@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -42,24 +42,23 @@
 
 #define IO_PROTOCOL_VERSION 0xb001
 
-/*
-static void
-_print_data(char *data, int datalen)
-{
-	char buf[1024];
-	size_t len = 0;
-	int i;
+/* If this changes, io_hdr_pack|unpack must change. */
+int g_io_hdr_size = sizeof(uint32_t) + 3*sizeof(uint16_t);
 
-	for (i = 0; i < datalen; i += sizeof(char))
-		len += sprintf(buf+len, "%02x", data[i]);
+/* If this changes, io_init_msg_pack|unpack must change. */
+static int g_io_init_msg_packed_size =
+	sizeof(uint16_t)    /* version */
+	+ sizeof(uint32_t)  /* nodeid */
+	+ (SLURM_IO_KEY_SIZE + sizeof(uint32_t)) /* signature */
+	+ sizeof(uint32_t)  /* stdout_objs */
+	+ sizeof(uint32_t); /* stderr_objs */
 
-	info("data: %s", buf);
-}
-*/
+#define io_init_msg_packed_size() g_io_init_msg_packed_size
 
 void
 io_hdr_pack(io_hdr_t *hdr, Buf buffer)
 {
+	/* If this function changes, io_hdr_packed_size must change. */
 	pack16(hdr->type, buffer);
 	pack16(hdr->gtaskid, buffer);
 	pack16(hdr->ltaskid, buffer);
@@ -69,6 +68,7 @@ io_hdr_pack(io_hdr_t *hdr, Buf buffer)
 int
 io_hdr_unpack(io_hdr_t *hdr, Buf buffer)
 {
+	/* If this function changes, io_hdr_packed_size must change. */
 	safe_unpack16(&hdr->type, buffer);
 	safe_unpack16(&hdr->gtaskid, buffer);
 	safe_unpack16(&hdr->ltaskid, buffer);
@@ -80,12 +80,6 @@ io_hdr_unpack(io_hdr_t *hdr, Buf buffer)
 	return SLURM_ERROR;
 }
 
-int
-io_hdr_packed_size()
-{
-	return sizeof(uint32_t) + 3*sizeof(uint16_t);
-}
-
 /*
  * Only return when the all of the bytes have been read, or an unignorable
  * error has occurred.
@@ -169,22 +163,10 @@ io_init_msg_validate(struct slurm_io_init_msg *msg, const char *sig)
 }
 
 
-static int
-io_init_msg_packed_size(void)
-{
-	int len;
-
-	len = sizeof(uint16_t)        /* version */
-		+ sizeof(uint32_t)    /* nodeid */
-		+ (SLURM_IO_KEY_SIZE + sizeof(uint32_t))  /* signature */
-		+ sizeof(uint32_t)    /* stdout_objs */
-		+ sizeof(uint32_t);   /* stderr_objs */
-	return len;
-}
-
 static void
 io_init_msg_pack(struct slurm_io_init_msg *hdr, Buf buffer)
 {
+	/* If this function changes, io_init_msg_packed_size must change. */
 	pack16(hdr->version, buffer);
        	pack32(hdr->nodeid, buffer);
 	pack32(hdr->stdout_objs, buffer);
@@ -197,6 +179,7 @@ io_init_msg_pack(struct slurm_io_init_msg *hdr, Buf buffer)
 static int
 io_init_msg_unpack(struct slurm_io_init_msg *hdr, Buf buffer)
 {
+	/* If this function changes, io_init_msg_packed_size must change. */
 	uint32_t val;
 	safe_unpack16(&hdr->version, buffer);
 	safe_unpack32(&hdr->nodeid, buffer);
@@ -218,35 +201,23 @@ int
 io_init_msg_write_to_fd(int fd, struct slurm_io_init_msg *msg)
 {
 	Buf buf;
-	char *ptr;
-	size_t rem_size;
-	ssize_t size_written;
+	int rc = SLURM_ERROR;
 
 	xassert(msg);
 
-	debug2("Entering io_init_msg_write_to_fd");
+	debug2("%s: entering", __func__);
 	msg->version = IO_PROTOCOL_VERSION;
 	buf = init_buf(io_init_msg_packed_size());
-	debug2("  msg->nodeid = %d", msg->nodeid);
+	debug2("%s: msg->nodeid = %d", __func__, msg->nodeid);
 	io_init_msg_pack(msg, buf);
 
-	ptr = get_buf_data(buf);
-	rem_size = io_init_msg_packed_size();
-	while (rem_size) {
-		size_written = write(fd, ptr, rem_size);
-		if (size_written < 0) {
-			if (errno == EINTR)
-				continue;
-			free_buf(buf);
-			return SLURM_ERROR;
-		}
-		rem_size -= size_written;
-		ptr += size_written;
-	}
+	safe_write(fd, buf->head, io_init_msg_packed_size());
+	rc = SLURM_SUCCESS;
 
+rwfail:
 	free_buf(buf);
-	debug2("Leaving  io_init_msg_write_to_fd");
-	return SLURM_SUCCESS;
+	debug2("%s: leaving", __func__);
+	return rc;
 }
 
 int
