@@ -9,11 +9,11 @@
  *  Portions Copyright (C) 2012 SchedMD LLC.
  *  Written by Danny Auble <da@schedmd.com>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -29,13 +29,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -121,7 +121,7 @@ plugin_peek( const char *fq_path,
 	} else {
 		dlclose( plug );
 		/* could be vestigial library, don't treat as an error */
-		verbose( "%s: not a SLURM plugin", fq_path );
+		verbose( "%s: not a Slurm plugin", fq_path );
 		return SLURM_ERROR;
 	}
 
@@ -219,6 +219,14 @@ plugin_load_from_file(plugin_handle_t *p, const char *fq_path)
 	return EPLUGIN_SUCCESS;
 }
 
+/*
+ * Load plugin and setup linking
+ * IN type_name - name of plugin
+ * IN n_syms - number of pointers in ptrs
+ * IN names - pointer list of symbols to link
+ * IN ptr - list of pointers to set with pointers given in names
+ * RET opaque ptr to handler or PLUGIN_INVALID_HANDLE on error
+ */
 plugin_handle_t
 plugin_load_and_link(const char *type_name, int n_syms,
 		     const char *names[], void *ptrs[])
@@ -269,9 +277,16 @@ plugin_load_and_link(const char *type_name, int n_syms,
 					xfree(file_name);
 					break;
 				} else {
-					(void) dlclose(plug);
-					err = EPLUGIN_MISSING_SYMBOL;
-					plug = PLUGIN_INVALID_HANDLE;
+					/*
+					 * Plugin loading failed part way
+					 * through loading, it is unknown what
+					 * actually happened but now process
+					 * memory is suspect and we are going to
+					 * abort since this should only ever
+					 * happen during development.
+					 */
+					fatal("%s: Plugin loading failed due to missing symbols. Plugin is corrupted.",
+					      __func__);
 				}
 			} else
 				plug = PLUGIN_INVALID_HANDLE;
@@ -429,14 +444,7 @@ extern plugin_context_t *plugin_context_create(
 	/* Get plugin list. */
 	if (!c->plugin_list) {
 		char *plugin_dir;
-		c->plugin_list = plugrack_create();
-		if (!c->plugin_list) {
-			error("cannot create plugin manager");
-			goto fail;
-		}
-		plugrack_set_major_type(c->plugin_list, plugin_type);
-		plugrack_set_paranoia(
-			c->plugin_list, PLUGRACK_PARANOIA_NONE, 0);
+		c->plugin_list = plugrack_create(plugin_type);
 		plugin_dir = slurm_get_plugin_dir();
 		plugrack_read_dir(c->plugin_list, plugin_dir);
 		xfree(plugin_dir);
