@@ -5,11 +5,11 @@
  *  Copyright (C) 2013 Bull.
  *  Written by Yiannis Georgiou <yiannis.georgiou@bull.net>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -25,13 +25,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -62,6 +62,7 @@ typedef struct slurm_acct_gather_filesystem_ops {
 				 int *full_options_cnt);
 	void (*conf_set)	(s_p_hashtbl_t *tbl);
 	void (*conf_values)        (List *data);
+	int (*get_data)		(acct_gather_data_t *data);
 } slurm_acct_gather_filesystem_ops_t;
 /*
  * These strings must be kept in the same order as the fields
@@ -72,6 +73,7 @@ static const char *syms[] = {
 	"acct_gather_filesystem_p_conf_options",
 	"acct_gather_filesystem_p_conf_set",
 	"acct_gather_filesystem_p_conf_values",
+	"acct_gather_filesystem_p_get_data",
 };
 
 static slurm_acct_gather_filesystem_ops_t ops;
@@ -153,7 +155,9 @@ extern int acct_gather_filesystem_fini(void)
 
 		if (watch_node_thread_id) {
 			slurm_mutex_unlock(&g_context_lock);
+			slurm_mutex_lock(&profile_timer->notify_mutex);
 			slurm_cond_signal(&profile_timer->notify);
+			slurm_mutex_unlock(&profile_timer->notify_mutex);
 			pthread_join(watch_node_thread_id, NULL);
 			slurm_mutex_lock(&g_context_lock);
 		}
@@ -166,6 +170,20 @@ extern int acct_gather_filesystem_fini(void)
 	return rc;
 }
 
+/*
+ * This is sent an array that will be filled in from the plugin(s).  It is not a
+ * direct pointer since we could have (in the future) this be stackable.
+ */
+extern int acct_gather_filesystem_g_get_data(acct_gather_data_t *data)
+{
+	int retval = SLURM_SUCCESS;
+
+	if (acct_gather_filesystem_init() < 0)
+		return SLURM_ERROR;
+	retval = (*(ops.get_data))(data);
+	return retval;
+}
+
 extern int acct_gather_filesystem_startpoll(uint32_t frequency)
 {
 	int retval = SLURM_SUCCESS;
@@ -197,27 +215,30 @@ extern int acct_gather_filesystem_startpoll(uint32_t frequency)
 }
 
 
-extern void acct_gather_filesystem_g_conf_options(s_p_options_t **full_options,
+extern int acct_gather_filesystem_g_conf_options(s_p_options_t **full_options,
 						  int *full_options_cnt)
 {
         if (acct_gather_filesystem_init() < 0)
-                return;
+		return SLURM_ERROR;
         (*(ops.conf_options))(full_options, full_options_cnt);
+	return SLURM_SUCCESS;
 }
 
-extern void acct_gather_filesystem_g_conf_set(s_p_hashtbl_t *tbl)
+extern int acct_gather_filesystem_g_conf_set(s_p_hashtbl_t *tbl)
 {
         if (acct_gather_filesystem_init() < 0)
-                return;
+		return SLURM_ERROR;
 
         (*(ops.conf_set))(tbl);
+	return SLURM_SUCCESS;
 }
 
 
-extern void acct_gather_filesystem_g_conf_values(void *data)
+extern int acct_gather_filesystem_g_conf_values(void *data)
 {
 	if (acct_gather_filesystem_init() < 0)
-		return;
+		return SLURM_ERROR;
 
 	(*(ops.conf_values))(data);
+	return SLURM_SUCCESS;
 }
