@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  src/common/slurm_cred.h - SLURM job and sbcast credential functions
+ *  src/common/slurm_cred.h - Slurm job and sbcast credential functions
  *****************************************************************************
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
@@ -7,11 +7,11 @@
  *  Written by Mark Grondona <grondona1@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -72,6 +72,8 @@
  */
 typedef struct slurm_cred_context   * slurm_cred_ctx_t;
 
+/* Used by slurm_cred_get_arg() */
+#define CRED_ARG_JOB_GRES_LIST 1
 
 /*
  * Initialize current process for slurm credential creation.
@@ -127,7 +129,7 @@ int  slurm_cred_ctx_unpack(slurm_cred_ctx_t ctx, Buf buffer);
 
 
 /*
- * Container for SLURM credential create and verify arguments
+ * Container for Slurm credential create and verify arguments
  *
  * The core_bitmap, cores_per_socket, sockets_per_node, and
  * sock_core_rep_count is based upon the nodes allocated to the
@@ -139,9 +141,13 @@ typedef struct {
 	uint32_t  stepid;
 	uid_t uid;
 	gid_t gid;
-	char *user_name;
+	char *pw_name;
+	char *pw_gecos;
+	char *pw_dir;
+	char *pw_shell;
 	int ngids;
 	gid_t *gids;
+	char **gr_names;
 
 	/* job_core_bitmap and step_core_bitmap cover the same set of nodes,
 	 * namely the set of nodes allocated to the job. The core and socket
@@ -172,10 +178,10 @@ typedef struct {
 } slurm_cred_arg_t;
 
 /* Initialize the plugin. */
-int slurm_crypto_init(void);
+int slurm_cred_init(void);
 
 /* Terminate the plugin and release all memory. */
-int slurm_crypto_fini(void);
+int slurm_cred_fini(void);
 
 /*
  * Create a slurm credential using the values in `arg.'
@@ -207,9 +213,17 @@ slurm_cred_t *slurm_cred_faker(slurm_cred_arg_t *arg);
  * slurm_cred_get_args() or slurm_cred_verify() */
 void slurm_cred_free_args(slurm_cred_arg_t *arg);
 
-/* Make a copy of the credential's arguements */
+/* Make a copy of the credential's arguments */
 int slurm_cred_get_args(slurm_cred_t *cred, slurm_cred_arg_t *arg);
 
+/*
+ * Return a pointer specific field from a job credential
+ * cred IN - job credential
+ * cred_arg_type in - Field desired
+ * RET - pointer to the information of interest, NULL on error
+ */
+extern void *slurm_cred_get_arg(slurm_cred_t *cred, int cred_arg_type);
+
 /*
  * Verify the signed credential `cred,' and return cred contents in
  * the cred_arg structure. The credential is cached and cannot be reused.
@@ -226,7 +240,7 @@ int slurm_cred_verify(slurm_cred_ctx_t ctx, slurm_cred_t *cred,
 
 /*
  * Rewind the last play of credential cred. This allows the credential
- *  be used again. Returns SLURM_FAILURE if no credential state is found
+ *  be used again. Returns SLURM_ERROR if no credential state is found
  *  to be rewound, SLURM_SUCCESS otherwise.
  */
 int slurm_cred_rewind(slurm_cred_ctx_t ctx, slurm_cred_t *cred);
@@ -241,7 +255,7 @@ void slurm_cred_handle_reissue(slurm_cred_ctx_t ctx, slurm_cred_t *cred);
 
 /*
  * Revoke all credentials for job id jobid
- * time IN - the time the job terminiation was requested by slurmctld
+ * time IN - the time the job termination was requested by slurmctld
  *           (local time from slurmctld server)
  * start_time IN - job start time, used to recongnize job requeue
  */
@@ -341,6 +355,7 @@ void slurm_cred_print(slurm_cred_t *cred);
 
 typedef struct {
 	uint32_t job_id;
+	uint32_t pack_jobid;
 	uid_t uid;
 	gid_t gid;
 	char *user_name;
