@@ -1020,13 +1020,10 @@ extern void slurm_persist_pack_init_req_msg(
 	/* always send version field first for backwards compatibility */
 	pack16(msg->version, buffer);
 
-	if (msg->version >= SLURM_17_11_PROTOCOL_VERSION) {
+	if (msg->version >= SLURM_MIN_PROTOCOL_VERSION) {
 		packstr(msg->cluster_name, buffer);
 		pack16(msg->persist_type, buffer);
 		pack16(msg->port, buffer);
-	} else if (msg->version >= SLURM_MIN_PROTOCOL_VERSION) {
-		packstr(msg->cluster_name, buffer);
-		pack16(msg->port, buffer);
 	} else {
 		error("%s: invalid protocol version %u",
 		      __func__, msg->version);
@@ -1045,13 +1042,10 @@ extern int slurm_persist_unpack_init_req_msg(
 
 	safe_unpack16(&msg_ptr->version, buffer);
 
-	if (msg_ptr->version >= SLURM_17_11_PROTOCOL_VERSION) {
+	if (msg_ptr->version >= SLURM_MIN_PROTOCOL_VERSION) {
 		safe_unpackstr_xmalloc(&msg_ptr->cluster_name, &tmp32, buffer);
 		safe_unpack16(&msg_ptr->persist_type, buffer);
 		safe_unpack16(&msg_ptr->port, buffer);
-	} else if (msg_ptr->version >= SLURM_MIN_PROTOCOL_VERSION) {
-		safe_unpackstr_xmalloc(&msg_ptr->cluster_name, &tmp32, buffer);
-		safe_unpack16(&msg_ptr->port, buffer);
 	} else {
 		error("%s: invalid protocol_version %u",
 		      __func__, msg_ptr->version);
