@@ -44,6 +44,7 @@
  * Define slurm-specific aliases for use by plugins, see slurm_xlator.h
  * for details.
  */
+strong_alias(slurmdbd_free_buffer,	slurm_slurmdbd_free_buffer);
 strong_alias(slurmdbd_free_list_msg,	slurm_slurmdbd_free_list_msg);
 strong_alias(slurmdbd_free_usage_msg,	slurm_slurmdbd_free_usage_msg);
 strong_alias(slurmdbd_free_id_rc_msg,	slurm_slurmdbd_free_id_rc_msg);
@@ -1091,7 +1092,7 @@ extern void slurmdbd_free_job_start_msg(void *in)
 	if (msg) {
 		xfree(msg->account);
 		xfree(msg->array_task_str);
-		xfree(msg->block_id);
+		xfree(msg->constraints);
 		xfree(msg->gres_alloc);
 		xfree(msg->gres_req);
 		xfree(msg->gres_used);
