@@ -42,9 +42,7 @@
  * Description:
  *
  * void *xmalloc(size_t size);
- * void *try_xmalloc(size_t size);
  * void xrealloc(void *p, size_t newsize);
- * int  try_xrealloc(void *p, size_t newsize);
  * void xfree(void *p);
  * int  xsize(void *p);
  *
@@ -52,18 +50,12 @@
  * memory. The memory is set to zero. xmalloc() will not return unless
  * there are no errors. The memory must be freed using xfree().
  *
- * try_xmalloc(size) is the same as above, but a NULL pointer is returned
- * when there is an error allocating the memory.
- *
  * xrealloc(p, newsize) changes the size of the block pointed to by p to the
  * value of newsize. Newly allocated memory is zeroed. If p is NULL,
  * xrealloc() performs the same function as  `p = xmalloc(newsize)'. If p
  * is not NULL, it is required to have been initialized with a call to
  * [try_]xmalloc() or [try_]xrealloc().
  *
- * try_xrealloc(p, newsize) is the same as above, but returns <= 0 if the
- * there is an error allocating the requested memory.
- *
  * xfree(p) frees the memory block pointed to by p. The memory must have been
  * initialized with a call to [try_]xmalloc() or [try_]xrealloc().
  *
@@ -76,45 +68,48 @@
 #ifndef _XMALLOC_H
 #define _XMALLOC_H
 
-#include <stdint.h>
+#include <stdbool.h>
 #include <sys/types.h>
 
-#include "macros.h"
+#define xcalloc(__cnt, __sz) \
+	slurm_xcalloc(__cnt, __sz, true, false, __FILE__, __LINE__, __func__)
+
+#define try_xcalloc(__cnt, __sz) \
+	slurm_xcalloc(__cnt, __sz, true, true, __FILE__, __LINE__, __func__)
+
+#define xcalloc_nz(__cnt, __sz) \
+	slurm_xcalloc(__cnt, __sz, false, false, __FILE__, __LINE__, __func__)
 
 #define xmalloc(__sz) \
-	slurm_xmalloc ((uint64_t) __sz, true, __FILE__, __LINE__, __func__)
-
-#define xmalloc_nz(__sz) \
-	slurm_xmalloc ((uint64_t) __sz, false, __FILE__, __LINE__, __func__)
+	slurm_xcalloc(1, __sz, true, false, __FILE__, __LINE__, __func__)
 
 #define try_xmalloc(__sz) \
-	slurm_try_xmalloc((uint64_t) __sz, __FILE__, __LINE__, __func__)
+	slurm_xcalloc(1, __sz, true, true, __FILE__, __LINE__, __func__)
+
+#define xmalloc_nz(__sz) \
+	slurm_xcalloc(1, __sz, false, false, __FILE__, __LINE__, __func__)
 
 #define xfree(__p) \
 	slurm_xfree((void **)&(__p), __FILE__, __LINE__, __func__)
 
-#define xrealloc(__p, __sz) \
-        slurm_xrealloc((void **)&(__p), __sz, true, \
-                       __FILE__, __LINE__, __func__)
+#define xrecalloc(__p, __cnt, __sz) \
+        slurm_xrecalloc((void **)&(__p), __cnt, __sz, true, false, __FILE__, __LINE__, __func__)
 
-#define xrealloc_nz(__p, __sz) \
-        slurm_xrealloc((void **)&(__p), __sz, false, \
-                       __FILE__, __LINE__, __func__)
+#define xrealloc(__p, __sz) \
+        slurm_xrecalloc((void **)&(__p), 1, __sz, true, false, __FILE__, __LINE__, __func__)
 
 #define try_xrealloc(__p, __sz) \
-	slurm_try_xrealloc((void **)&(__p), __sz, \
-                           __FILE__, __LINE__,  __func__)
+        slurm_xrecalloc((void **)&(__p), 1, __sz, true, true, __FILE__, __LINE__, __func__)
+
+#define xrealloc_nz(__p, __sz) \
+        slurm_xrecalloc((void **)&(__p), 1, __sz, false, false, __FILE__, __LINE__, __func__)
 
 #define xsize(__p) \
 	slurm_xsize((void *)__p, __FILE__, __LINE__, __func__)
 
-void *slurm_xmalloc(uint64_t, bool, const char *, int, const char *);
-void *slurm_try_xmalloc(size_t , const char *, int , const char *);
+void *slurm_xcalloc(size_t, size_t, bool, bool, const char *, int, const char *);
 void slurm_xfree(void **, const char *, int, const char *);
-void *slurm_xrealloc(void **, size_t, bool, const char *, int, const char *);
-int  slurm_try_xrealloc(void **, size_t, const char *, int, const char *);
+void *slurm_xrecalloc(void **, size_t, size_t, bool, bool, const char *, int, const char *);
 size_t slurm_xsize(void *, const char *, int, const char *);
 
-#define XMALLOC_MAGIC 0x42
-
 #endif /* !_XMALLOC_H */
