@@ -7,11 +7,11 @@
  *  Written by Jim Garlick <garlick@llnl.gov>, et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -45,11 +45,12 @@
 #define xstrcat(__p, __q)		_xstrcat(&(__p), __q)
 #define xstrncat(__p, __q, __l)		_xstrncat(&(__p), __q, __l)
 #define xstrcatchar(__p, __c)		_xstrcatchar(&(__p), __c)
-#define xslurm_strerrorcat(__p)		_xslurm_strerrorcat(&(__p))
 #define xstrftimecat(__p, __fmt)	_xstrftimecat(&(__p), __fmt)
 #define xiso8601timecat(__p, __msec)            _xiso8601timecat(&(__p), __msec)
 #define xrfc5424timecat(__p, __msec)            _xrfc5424timecat(&(__p), __msec)
 #define xstrfmtcat(__p, __fmt, args...)	_xstrfmtcat(&(__p), __fmt, ## args)
+#define xstrfmtcatat(__p, __q, __fmt, args...) \
+	_xstrfmtcatat(&(__p), __q, __fmt, ## args)
 #define xmemcat(__p, __s, __e)          _xmemcat(&(__p), __s, __e)
 #define xstrsubstitute(__p, __pat, __rep) _xstrsubstitute(&(__p), __pat, __rep)
 #define xstrsubstituteall(__p, __pat, __rep)			\
@@ -82,11 +83,6 @@ void _xstrncat(char **str1, const char *str2, size_t len);
 */
 void _xstrcatchar(char **str1, char c);
 
-/*
-** concatenate stringified errno onto str
-*/
-void _xslurm_strerrorcat(char **str);
-
 /*
 ** concatenate current time onto str, using fmt if it is non-NUL
 ** see strftime(3) for the usage of the format string
@@ -110,6 +106,13 @@ void _xrfc5424timecat(char **str, bool);
 int _xstrfmtcat(char **str, const char *fmt, ...)
   __attribute__ ((format (printf, 2, 3)));
 
+/*
+ * Concatenate printf-style formatted string onto str at position pos.
+ * Return value is result from vsnprintf(3).
+ */
+int _xstrfmtcatat(char **str, char **pos, const char *fmt, ...)
+	__attribute__ ((format (printf, 3, 4)));
+
 /*
 ** concatenate range of memory from start to end (not including end)
 ** onto str.
@@ -149,14 +152,6 @@ char *xbasename(char *path);
 */
 bool _xstrsubstitute(char **str, const char *pattern, const char *replacement);
 
-/*
- * Remove all quotes that surround a string in the string "str",
- *   str (IN)	        target string (pointer to in case of expansion)
- *   increased (IN/OUT)	current position in "str"
- *   RET char *         str returned without quotes in it. needs to be xfreed
- */
-char *xstrstrip(char *str);
-
 /* xshort_hostname
  *   Returns an xmalloc'd string containing the hostname
  *   of the local machine.  The hostname contains only
@@ -215,6 +210,6 @@ int xstrncasecmp(const char *s1, const char *s2, size_t n);
 char *xstrstr(const char *haystack, const char *needle);
 
 /* safe case insensitive version of strstr(). */
-char *xstrcasestr(char *haystack, char *needle);
+char *xstrcasestr(const char *haystack, const char *needle);
 
 #endif /* !_XSTRING_H */
