@@ -284,6 +284,13 @@ static int _mysql_make_table_current(mysql_conn_t *mysql_conn, char *table_name,
 	 * to work they will have to downgrade mysql to <= 5.7.3 to make things
 	 * work correctly or manually edit the database to get things to work.
 	 */
+	/*
+	 * `query` is compared against the current table_defs_table.definition
+	 * and run if they are different. `correct_query` is inserted into the
+	 * table, so it must be what future `query` schemas will be.
+	 * In other words, `query` transitions the table to the new schema,
+	 * `correct_query` represents the new schema
+	 */
 	query = xstrdup_printf("alter table %s", table_name);
 	correct_query = xstrdup(query);
 	START_TIMER;
@@ -361,10 +368,9 @@ static int _mysql_make_table_current(mysql_conn_t *mysql_conn, char *table_name,
 		if (temp[end]) {
 			end++;
 			primary_key = xstrndup(temp, end);
-			if (old_primary) {
+			if (old_primary)
 				xstrcat(query, " drop primary key,");
-				xstrcat(correct_query, " drop primary key,");
-			}
+			xstrcat(correct_query, " drop primary key,");
 			xstrfmtcat(query, " add %s,",  primary_key);
 			xstrfmtcat(correct_query, " add %s,",  primary_key);
 
@@ -372,10 +378,34 @@ static int _mysql_make_table_current(mysql_conn_t *mysql_conn, char *table_name,
 		}
 	}
 
-	if ((temp = strstr(ending, "unique index ("))) {
+	if ((temp = strstr(ending, "unique index"))) {
 		int open = 0, close = 0;
-		int end = 0;
+		/* sizeof includes NULL, and end should start 1 back */
+		int end = sizeof("unique index") - 2;
+		char *udex_name = NULL, *name_marker = NULL;
 		while (temp[end++]) {
+			/*
+			 * Extracts the index name, which is given explicitly
+			 * or is the name of the first field included in the
+			 * index.
+			 * "unique index indexname (field1, field2)"
+			 * "unique index (indexname, field2)"
+			 * indexname is started by the first non '(' or ' '
+			 *     after "unique index"
+			 * indexname is terminated by '(' ')' ' ' or ','
+			 */
+			if (name_marker) {
+				if (!udex_name && (temp[end] == '(' ||
+						   temp[end] == ')' ||
+						   temp[end] == ' ' ||
+						   temp[end] == ','))
+					udex_name = xstrndup(name_marker,
+						temp + end - name_marker);
+			} else if (temp[end] != '(' && temp[end] != ' ') {
+				name_marker = temp + end;
+			}
+
+			/* find the end of the parenthetical expression */
 			if (temp[end] == '(')
 				open++;
 			else if (temp[end] == ')')
@@ -388,16 +418,14 @@ static int _mysql_make_table_current(mysql_conn_t *mysql_conn, char *table_name,
 		if (temp[end]) {
 			end++;
 			unique_index = xstrndup(temp, end);
-			if (old_index) {
-				xstrfmtcat(query, " drop index %s,",
-					   old_index);
-				xstrfmtcat(correct_query, " drop index %s,",
-					   old_index);
-			}
+			if (old_index)
+				xstrfmtcat(query, " drop index %s,", old_index);
+			xstrfmtcat(correct_query, " drop index %s,", udex_name);
 			xstrfmtcat(query, " add %s,", unique_index);
 			xstrfmtcat(correct_query, " add %s,", unique_index);
 			xfree(unique_index);
 		}
+		xfree(udex_name);
 	}
 	xfree(old_index);
 
@@ -436,15 +464,12 @@ static int _mysql_make_table_current(mysql_conn_t *mysql_conn, char *table_name,
 			if (db_key) {
 				xstrfmtcat(query,
 					   " drop key %s,", db_key->name);
-				xstrfmtcat(correct_query,
-					   " drop key %s,", db_key->name);
 				_destroy_db_key(db_key);
-			} else {
-				xstrfmtcat(correct_query,
-					   " drop key %s,", new_key_name);
+			} else
 				info("adding %s to table %s",
 				     new_key, table_name);
-			}
+			xstrfmtcat(correct_query,
+				   " drop key %s,", new_key_name);
 
 			xstrfmtcat(query, " add %s,",  new_key);
 			xstrfmtcat(correct_query, " add %s,",  new_key);
@@ -678,7 +703,10 @@ extern int mysql_db_get_db_connection(mysql_conn_t *mysql_conn, char *db_name,
 	int rc = SLURM_SUCCESS;
 	bool storage_init = false;
 	char *db_host = db_info->host;
-
+	unsigned int my_timeout = 30;
+#ifdef MYSQL_OPT_RECONNECT
+	my_bool reconnect = 1;
+#endif
 	xassert(mysql_conn);
 
 	slurm_mutex_lock(&mysql_conn->lock);
@@ -687,63 +715,60 @@ extern int mysql_db_get_db_connection(mysql_conn_t *mysql_conn, char *db_name,
 		slurm_mutex_unlock(&mysql_conn->lock);
 		fatal("mysql_init failed: %s",
 		      mysql_error(mysql_conn->db_conn));
-	} else {
-		/* If this ever changes you will need to alter
-		 * src/common/slurmdbd_defs.c function _send_init_msg to
-		 * handle a different timeout when polling for the
-		 * response.
-		 */
-		unsigned int my_timeout = 30;
-#ifdef MYSQL_OPT_RECONNECT
-		my_bool reconnect = 1;
-		/* make sure reconnect is on */
-		mysql_options(mysql_conn->db_conn, MYSQL_OPT_RECONNECT,
-			      &reconnect);
-#endif
-		mysql_options(mysql_conn->db_conn, MYSQL_OPT_CONNECT_TIMEOUT,
-			      (char *)&my_timeout);
-		while (!storage_init) {
-			debug2("Attempting to connect to %s:%d", db_host,
-			       db_info->port);
-			if (!mysql_real_connect(mysql_conn->db_conn, db_host,
-					        db_info->user, db_info->pass,
-					        db_name, db_info->port, NULL,
-					        CLIENT_MULTI_STATEMENTS)) {
-				int err = mysql_errno(mysql_conn->db_conn);
-				if (err == ER_BAD_DB_ERROR) {
-					debug("Database %s not created.  "
-					      "Creating", db_name);
-					rc = _create_db(db_name, db_info);
-				} else {
-					const char *err_str = mysql_error(
-						mysql_conn->db_conn);
-					if ((db_host == db_info->host)
-					    && db_info->backup) {
-						debug2("mysql_real_connect failed: %d %s",
-						       err, err_str);
-						db_host = db_info->backup;
-						continue;
-					}
+	}
 
-					error("mysql_real_connect failed: "
-					      "%d %s",
-					      err, err_str);
-					rc = ESLURM_DB_CONNECTION;
-					mysql_close(mysql_conn->db_conn);
-					mysql_conn->db_conn = NULL;
-					break;
-				}
-			} else {
-				storage_init = true;
-				if (mysql_conn->rollback)
-					mysql_autocommit(
-						mysql_conn->db_conn, 0);
-				rc = _mysql_query_internal(
-					mysql_conn->db_conn,
-					"SET session sql_mode='ANSI_QUOTES,"
-					"NO_ENGINE_SUBSTITUTION';");
+	/* If this ever changes you will need to alter
+	 * src/common/slurmdbd_defs.c function _send_init_msg to
+	 * handle a different timeout when polling for the
+	 * response.
+	 */
+#ifdef MYSQL_OPT_RECONNECT
+	/* make sure reconnect is on */
+	mysql_options(mysql_conn->db_conn, MYSQL_OPT_RECONNECT,
+		      &reconnect);
+#endif
+	mysql_options(mysql_conn->db_conn, MYSQL_OPT_CONNECT_TIMEOUT,
+		      (char *)&my_timeout);
+	while (!storage_init) {
+		debug2("Attempting to connect to %s:%d", db_host,
+		       db_info->port);
+		if (!mysql_real_connect(mysql_conn->db_conn, db_host,
+					db_info->user, db_info->pass,
+					db_name, db_info->port, NULL,
+					CLIENT_MULTI_STATEMENTS)) {
+			const char *err_str = NULL;
+			int err = mysql_errno(mysql_conn->db_conn);
+
+			if (err == ER_BAD_DB_ERROR) {
+				debug("Database %s not created.  Creating",
+				      db_name);
+				rc = _create_db(db_name, db_info);
+				continue;
 			}
+
+			err_str = mysql_error(mysql_conn->db_conn);
+
+			if ((db_host == db_info->host) && db_info->backup) {
+				debug2("mysql_real_connect failed: %d %s",
+				       err, err_str);
+				db_host = db_info->backup;
+				continue;
+			}
+
+			error("mysql_real_connect failed: %d %s",
+			      err, err_str);
+			rc = ESLURM_DB_CONNECTION;
+			mysql_close(mysql_conn->db_conn);
+			mysql_conn->db_conn = NULL;
+			break;
 		}
+
+		storage_init = true;
+		if (mysql_conn->rollback)
+			mysql_autocommit(mysql_conn->db_conn, 0);
+		rc = _mysql_query_internal(mysql_conn->db_conn,
+					   "SET session sql_mode='ANSI_QUOTES,"
+					   "NO_ENGINE_SUBSTITUTION';");
 	}
 	slurm_mutex_unlock(&mysql_conn->lock);
 	errno = rc;
