@@ -5,11 +5,11 @@
  *  Copyright (C) 2015 SchedMD LLC.
  *  Written by Danny Auble <da@schedmd.com>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -25,13 +25,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -71,7 +71,9 @@ extern int as_mysql_add_tres(mysql_conn_t *mysql_conn,
 			continue;
 		} else if ((!xstrcasecmp(object->type, "gres") ||
 			    !xstrcasecmp(object->type, "bb") ||
-			    !xstrcasecmp(object->type, "license"))) {
+			    !xstrcasecmp(object->type, "license") ||
+			    !xstrcasecmp(object->type, "fs") ||
+			    !xstrcasecmp(object->type, "ic"))) {
 			if (!object->name) {
 				error("%s type tres "
 				      "need to have a name, "
@@ -267,7 +269,8 @@ empty:
 		xstrfmtcat(tmp, ", %s", tres_req_inx[i]);
 	}
 
-	query = xstrdup_printf("select %s from %s %s", tmp, tres_table, extra);
+	query = xstrdup_printf("select %s from %s %s order by id",
+			       tmp, tres_table, extra);
 	xfree(tmp);
 	xfree(extra);
 
