@@ -38,6 +38,8 @@
 \*****************************************************************************/
 
 #include "src/common/slurm_xlator.h"
+
+#include "src/common/fd.h"
 #include "src/common/slurmdbd_pack.h"
 #include "src/common/xsignal.h"
 #include "src/common/xstring.h"
@@ -472,7 +474,7 @@ static void _save_dbd_state(void)
 end_it:
 	if (fd >= 0) {
 		verbose("slurmdbd: saved %d pending RPCs", wrote);
-		(void) close(fd);
+		fsync_and_close(fd, "dbd.messages");
 	}
 	xfree(dbd_fname);
 }
@@ -951,15 +953,16 @@ extern int send_recv_slurmdbd_msg(uint16_t rpc_version,
 	rc = slurm_persist_send_msg(slurmdbd_conn, buffer);
 	free_buf(buffer);
 	if (rc != SLURM_SUCCESS) {
-		error("slurmdbd: Sending message type %s: %d: %m",
-		      rpc_num2string(req->msg_type), rc);
+		error("slurmdbd: Sending message type %s: %d: %s",
+		      slurmdbd_msg_type_2_str(req->msg_type, 1), rc,
+		      slurm_strerror(rc));
 		goto end_it;
 	}
 
 	buffer = slurm_persist_recv_msg(slurmdbd_conn);
 	if (buffer == NULL) {
-		error("slurmdbd: Getting response to message type %u",
-		      req->msg_type);
+		error("slurmdbd: Getting response to message type: %s",
+		      slurmdbd_msg_type_2_str(req->msg_type, 1));
 		rc = SLURM_ERROR;
 		goto end_it;
 	}
