@@ -75,7 +75,7 @@
  * overwritten when linking with the slurmctld.
  */
 #if defined (__APPLE__)
-slurmd_conf_t *conf __attribute__((weak_import)) = NULL;
+extern slurmd_conf_t *conf __attribute__((weak_import));
 #else
 slurmd_conf_t *conf = NULL;
 #endif
@@ -257,18 +257,18 @@ static int _init_ipmi_config (void)
 	if (ipmi_monitoring_init(ipmimonitoring_init_flags, &errnum) < 0) {
 		error("ipmi_monitoring_init: %s",
 		      ipmi_monitoring_ctx_strerror(errnum));
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 	if (!(ipmi_ctx = ipmi_monitoring_ctx_create())) {
 		error("ipmi_monitoring_ctx_create");
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 	if (sdr_cache_directory) {
 		if (ipmi_monitoring_ctx_sdr_cache_directory(
 			    ipmi_ctx, sdr_cache_directory) < 0) {
 			error("ipmi_monitoring_ctx_sdr_cache_directory: %s",
 			      ipmi_monitoring_ctx_errormsg(ipmi_ctx));
-			return SLURM_FAILURE;
+			return SLURM_ERROR;
 		}
 	}
 	/* Must call otherwise only default interpretations ever used */
@@ -276,7 +276,7 @@ static int _init_ipmi_config (void)
 		    ipmi_ctx, sensor_config_file) < 0) {
 		error("ipmi_monitoring_ctx_sensor_config_file: %s",
 		      ipmi_monitoring_ctx_errormsg(ipmi_ctx));
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 
 	if (slurm_ipmi_conf.reread_sdr_cache)
@@ -348,7 +348,7 @@ static int _check_power_sensor(void)
 			      MAX_LOG_ERRORS);
 			check_err_cnt++;
 		}
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 
 	check_err_cnt = 0;
@@ -361,12 +361,12 @@ static int _check_power_sensor(void)
 		if (sensor_units < 0) {
 			error("ipmi_monitoring_sensor_read_sensor_units: %s",
 			      ipmi_monitoring_ctx_errormsg(ipmi_ctx));
-			return SLURM_FAILURE;
+			return SLURM_ERROR;
 		}
 		if (sensor_units != slurm_ipmi_conf.variable) {
 			error("Configured sensor is not in Watt, "
 			      "please check ipmi.conf");
-			return SLURM_FAILURE;
+			return SLURM_ERROR;
 		}
 
 		/* update current value of the sensor */
@@ -377,7 +377,7 @@ static int _check_power_sensor(void)
 			    (uint32_t) (*((double *)sensor_reading));
 		} else {
 			error("ipmi read an empty value for power consumption");
-			return SLURM_FAILURE;
+			return SLURM_ERROR;
 		}
 		++i;
 	} while (ipmi_monitoring_sensor_iterator_next(ipmi_ctx));
@@ -395,7 +395,7 @@ static int _find_power_sensor(void)
 {
 	int sensor_count;
 	int i;
-	int rc = SLURM_FAILURE;
+	int rc = SLURM_ERROR;
 	void* sensor_reading;
 	int sensor_units, record_id;
 	static uint8_t find_err_cnt = 0;
@@ -422,7 +422,7 @@ static int _find_power_sensor(void)
 			      MAX_LOG_ERRORS);
 			find_err_cnt++;
 		}
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 
 	find_err_cnt = 0;
@@ -434,7 +434,7 @@ static int _find_power_sensor(void)
 		if (sensor_units < 0) {
 			error("ipmi_monitoring_sensor_read_sensor_units: %s",
 			      ipmi_monitoring_ctx_errormsg(ipmi_ctx));
-			return SLURM_FAILURE;
+			return SLURM_ERROR;
 		}
 
 		if (sensor_units != slurm_ipmi_conf.variable)
@@ -444,7 +444,7 @@ static int _find_power_sensor(void)
 		if (record_id < 0) {
 			error("ipmi_monitoring_sensor_read_record_id: %s",
 			      ipmi_monitoring_ctx_errormsg(ipmi_ctx));
-			return SLURM_FAILURE;
+			return SLURM_ERROR;
 		}
 
 		sensor_reading =
@@ -469,7 +469,7 @@ static int _find_power_sensor(void)
 			last_update_time = time(NULL);
 		} else {
 			error("ipmi read an empty value for power consumption");
-			rc = SLURM_FAILURE;
+			rc = SLURM_ERROR;
 			continue;
 		}
 		rc = SLURM_SUCCESS;
@@ -519,7 +519,7 @@ static int _read_ipmi_values(void)
 			      MAX_LOG_ERRORS);
 			read_err_cnt++;
 		}
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 
 	read_err_cnt = 0;
@@ -533,7 +533,7 @@ static int _read_ipmi_values(void)
 			    (uint32_t) (*((double *)sensor_reading));
 		} else {
 			error("ipmi read an empty value for power consumption");
-			return SLURM_FAILURE;
+			return SLURM_ERROR;
 		}
 		++i;
 	} while (ipmi_monitoring_sensor_iterator_next(ipmi_ctx));
@@ -552,7 +552,7 @@ static void _update_energy(acct_gather_energy_t *e, uint32_t last_update_watt,
 
 	if (e->current_watts) {
 		prev_watts = e->current_watts;
-		e->base_watts = ((e->base_watts * readings) +
+		e->ave_watts = ((e->ave_watts * readings) +
 				 e->current_watts) / (readings + 1);
 		e->current_watts = last_update_watt;
 		if (previous_update_time == 0)
@@ -568,7 +568,7 @@ static void _update_energy(acct_gather_energy_t *e, uint32_t last_update_watt,
 		e->consumed_energy += e->base_consumed_energy;
 	} else {
 		e->consumed_energy = 0;
-		e->base_watts = 0;
+		e->ave_watts = 0;
 		e->current_watts = last_update_watt;
 	}
 	e->poll_time = time(NULL);
@@ -609,7 +609,7 @@ static int _thread_update_node_energy(void)
 			     sensors[i].energy.current_watts,
 			     sensors[i].energy.consumed_energy,
 			     sensors[i].energy.base_consumed_energy,
-			     sensors[i].energy.base_watts);
+			     sensors[i].energy.ave_watts);
 	}
 
 	return rc;
@@ -621,7 +621,7 @@ static int _thread_update_node_energy(void)
 static int _thread_init(void)
 {
 	static bool first = true;
-	static bool first_init = SLURM_FAILURE;
+	static bool first_init = SLURM_ERROR;
 	int rc = SLURM_SUCCESS;
 	uint16_t i;
 
@@ -631,7 +631,7 @@ static int _thread_init(void)
 
 	if (_init_ipmi_config() != SLURM_SUCCESS) {
 		//TODO verbose error?
-		rc = SLURM_FAILURE;
+		rc = SLURM_ERROR;
 	} else {
 		if ((sensors_len == 0 && _find_power_sensor() != SLURM_SUCCESS)
 		    || _check_power_sensor() != SLURM_SUCCESS) {
@@ -739,7 +739,9 @@ static void *_thread_ipmi_run(void *no_data)
 			info("ipmi-thread: aborted");
 		slurm_mutex_unlock(&ipmi_mutex);
 
+		slurm_mutex_lock(&launch_mutex);
 		slurm_cond_signal(&launch_cond);
+		slurm_mutex_unlock(&launch_mutex);
 
 		return NULL;
 	}
@@ -749,7 +751,9 @@ static void *_thread_ipmi_run(void *no_data)
 	slurm_mutex_unlock(&ipmi_mutex);
 	flag_thread_started = true;
 
+	slurm_mutex_lock(&launch_mutex);
 	slurm_cond_signal(&launch_cond);
+	slurm_mutex_unlock(&launch_mutex);
 
 	/* setup timer */
 	gettimeofday(&tvnow, NULL);
@@ -907,7 +911,7 @@ static void _get_node_energy(acct_gather_energy_t *energy)
 		id = descriptions[i].sensor_idxs[j];
 		e = &sensors[id].energy;
 		energy->base_consumed_energy += e->base_consumed_energy;
-		energy->base_watts += e->base_watts;
+		energy->ave_watts += e->ave_watts;
 		energy->consumed_energy += e->consumed_energy;
 		energy->current_watts += e->current_watts;
 		energy->previous_consumed_energy += e->previous_consumed_energy;
@@ -941,17 +945,18 @@ extern int fini(void)
 
 	flag_energy_accounting_shutdown = true;
 
+	slurm_mutex_lock(&launch_mutex);
 	/* clean up the launch thread */
 	slurm_cond_signal(&launch_cond);
+	slurm_mutex_unlock(&launch_mutex);
 
 	if (thread_ipmi_id_launcher)
 		pthread_join(thread_ipmi_id_launcher, NULL);
 
+	slurm_mutex_lock(&ipmi_mutex);
 	/* clean up the run thread */
 	slurm_cond_signal(&ipmi_cond);
 
-	slurm_mutex_lock(&ipmi_mutex);
-
 	if (ipmi_ctx)
 		ipmi_monitoring_ctx_destroy(ipmi_ctx);
 	reset_slurm_ipmi_conf(&slurm_ipmi_conf);
