@@ -11,11 +11,11 @@
  *  and Danny Auble <da@schedmd.com> @ SchedMD.
  *  Adapted by Yoann Blein <yoann.blein@bull.net> @ Bull.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -31,13 +31,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  *
  *  This file is patterned after jobcomp_linux.c, written by Morris Jette and
@@ -82,14 +82,14 @@
  * plugin_type - a string suggesting the type of the plugin or its
  * applicability to a particular form of data or method of data handling.
  * If the low-level plugin API is used, the contents of this string are
- * unimportant and may be anything.  SLURM uses the higher-level plugin
+ * unimportant and may be anything.  Slurm uses the higher-level plugin
  * interface which requires this string to be of the form
  *
  *	<application>/<method>
  *
  * where <application> is a description of the intended application of
- * the plugin (e.g., "jobacct" for SLURM job completion logging) and <method>
- * is a description of how this plugin satisfies that application.  SLURM will
+ * the plugin (e.g., "jobacct" for Slurm job completion logging) and <method>
+ * is a description of how this plugin satisfies that application.  Slurm will
  * only load job completion logging plugins if the plugin_type string has a
  * prefix of "jobacct/".
  *
@@ -362,7 +362,7 @@ extern int acct_gather_profile_p_node_step_start(stepd_step_rec_t* job)
 
 	if (file_id < 1) {
 		info("PROFILE: Failed to create Node group");
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 	/*
 	 * fd_set_close_on_exec(file_id); Not supported for HDF5
@@ -373,7 +373,7 @@ extern int acct_gather_profile_p_node_step_start(stepd_step_rec_t* job)
 		H5Fclose(file_id);
 		file_id = -1;
 		info("PROFILE: Failed to create Node group");
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	}
 	put_int_attribute(gid_node, ATTR_NODEINX, g_job->nodeid);
 	put_string_attribute(gid_node, ATTR_NODENAME, g_job->node_name);
@@ -659,4 +659,3 @@ extern bool acct_gather_profile_p_is_active(uint32_t type)
 	return (type == ACCT_GATHER_PROFILE_NOT_SET)
 		|| (g_profile_running & type);
 }
-
