@@ -8,11 +8,11 @@
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette1@llnl.gov>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -28,13 +28,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -69,14 +69,14 @@
  * plugin_type - A string suggesting the type of the plugin or its
  * applicability to a particular form of data or method of data handling.
  * If the low-level plugin API is used, the contents of this string are
- * unimportant and may be anything.  SLURM uses the higher-level plugin
+ * unimportant and may be anything.  Slurm uses the higher-level plugin
  * interface which requires this string to be of the form
  *
  *	<application>/<method>
  *
  * where <application> is a description of the intended application of
- * the plugin (e.g., "auth" for SLURM authentication) and <method> is a
- * description of how this plugin satisfies that application.  SLURM will
+ * the plugin (e.g., "auth" for Slurm authentication) and <method> is a
+ * description of how this plugin satisfies that application.  Slurm will
  * only load authentication plugins if the plugin_type string has a prefix
  * of "auth/".
  *
@@ -96,8 +96,7 @@ static void _set_env(char ***env_ptr, void *gres_ptr, int node_inx,
 		     bool *already_seen, int *local_inx,
 		     bool reset, bool is_job)
 {
-	char *global_list = NULL, *local_list = NULL;
-	char *slurm_env_var = NULL;
+	char *global_list = NULL, *local_list = NULL, *slurm_env_var = NULL;
 
 	if (is_job)
 			slurm_env_var = "SLURM_JOB_MICS";
@@ -111,9 +110,8 @@ static void _set_env(char ***env_ptr, void *gres_ptr, int node_inx,
 	}
 
 	common_gres_set_env(gres_devices, env_ptr, gres_ptr, node_inx,
-			    usable_gres, "", local_inx,
-			    &local_list, &global_list,
-			    reset, is_job);
+			    usable_gres, "", local_inx, NULL,
+			    &local_list, &global_list, reset, is_job, NULL);
 
 	if (global_list) {
 		env_array_overwrite(env_ptr, slurm_env_var, global_list);
@@ -128,20 +126,34 @@ static void _set_env(char ***env_ptr, void *gres_ptr, int node_inx,
 	}
 }
 
+extern int init(void)
+{
+	debug("%s: %s loaded", __func__, plugin_name);
+
+	return SLURM_SUCCESS;
+}
+
+extern int fini(void)
+{
+	debug("%s: unloading %s", __func__, plugin_name);
+	FREE_NULL_LIST(gres_devices);
+
+	return SLURM_SUCCESS;
+}
+
 /*
  * We could load gres state or validate it using various mechanisms here.
  * This only validates that the configuration was specified in gres.conf.
  * In the general case, no code would need to be changed.
  */
-extern int node_config_load(List gres_conf_list)
+extern int node_config_load(List gres_conf_list, node_config_load_t *config)
 {
 	int rc = SLURM_SUCCESS;
 
 	if (gres_devices)
 		return rc;
 
-	rc = common_node_config_load(gres_conf_list, gres_name,
-				     &gres_devices);
+	rc = common_node_config_load(gres_conf_list, gres_name, &gres_devices);
 
 	if (rc != SLURM_SUCCESS)
 		fatal("%s failed to load configuration", plugin_name);
@@ -184,7 +196,7 @@ extern void step_set_env(char ***step_env_ptr, void *gres_ptr)
 }
 
 /*
- * Reset environment variables as appropriate for a job (i.e. this one tasks)
+ * Reset environment variables as appropriate for a job (i.e. this one task)
  * based upon the job step's GRES state and assigned CPUs.
  */
 extern void step_reset_env(char ***step_env_ptr, void *gres_ptr,
@@ -209,19 +221,73 @@ extern void recv_stepd(int fd)
 	common_recv_stepd(fd, &gres_devices);
 }
 
+/*
+ * get data from a job's GRES data structure
+ * IN job_gres_data  - job's GRES data structure
+ * IN node_inx - zero-origin index of the node within the job's allocation
+ *	for which data is desired
+ * IN data_type - type of data to get from the job's data
+ * OUT data - pointer to the data from job's GRES data structure
+ *            DO NOT FREE: This is a pointer into the job's data structure
+ * RET - SLURM_SUCCESS or error code
+ */
 extern int job_info(gres_job_state_t *job_gres_data, uint32_t node_inx,
 		    enum gres_job_data_type data_type, void *data)
 {
 	return EINVAL;
 }
 
+/*
+ * get data from a step's GRES data structure
+ * IN step_gres_data  - step's GRES data structure
+ * IN node_inx - zero-origin index of the node within the job's allocation
+ *	for which data is desired. Note this can differ from the step's
+ *	node allocation index.
+ * IN data_type - type of data to get from the step's data
+ * OUT data - pointer to the data from step's GRES data structure
+ *            DO NOT FREE: This is a pointer into the step's data structure
+ * RET - SLURM_SUCCESS or error code
+ */
 extern int step_info(gres_step_state_t *step_gres_data, uint32_t node_inx,
 		     enum gres_step_data_type data_type, void *data)
 {
 	return EINVAL;
 }
 
+/*
+ * Return a list of devices of this type. The list elements are of type
+ * "gres_device_t" and the list should be freed using FREE_NULL_LIST().
+ */
 extern List get_devices(void)
 {
 	return gres_devices;
 }
+
+extern void step_hardware_init(bitstr_t *usable_gres, char *settings)
+{
+	return;
+}
+
+extern void step_hardware_fini(void)
+{
+	return;
+}
+
+/*
+ * Build record used to set environment variables as appropriate for a job's
+ * prolog or epilog based GRES allocated to the job.
+ */
+extern gres_epilog_info_t *epilog_build_env(gres_job_state_t *gres_job_ptr)
+{
+	return NULL;
+}
+
+/*
+ * Set environment variables as appropriate for a job's prolog or epilog based
+ * GRES allocated to the job.
+ */
+extern void epilog_set_env(char ***epilog_env_ptr,
+			   gres_epilog_info_t *epilog_info, int node_inx)
+{
+	return;
+}
