@@ -3,7 +3,7 @@
  *****************************************************************************
  *  Copyright (C) 2011 Bull.
  *  Written by Martin Perry, <martin.perry@bull.com>, who borrowed heavily
- *  from other parts of SLURM
+ *  from other parts of Slurm
  *  CODE-OCEC-09-009. All rights reserved.
  *
  *  This file is part of Slurm, a resource management program.
@@ -59,11 +59,9 @@
  * overwritten when linking with the slurmd.
  */
 #if defined (__APPLE__)
-slurmd_conf_t *conf __attribute__((weak_import));
-int bg_recover __attribute__((weak_import)) = NOT_FROM_CONTROLLER;
+extern slurmd_conf_t *conf __attribute__((weak_import));
 #else
 slurmd_conf_t *conf;
-int bg_recover = NOT_FROM_CONTROLLER;
 #endif
 
 
@@ -96,31 +94,60 @@ const char plugin_name[] = "Job accounting gather cgroup plugin";
 const char plugin_type[] = "jobacct_gather/cgroup";
 const uint32_t plugin_version = SLURM_VERSION_NUMBER;
 
-/* Other useful declarations */
-static slurm_cgroup_conf_t slurm_cgroup_conf;
-
-static void _prec_extra(jag_prec_t *prec)
+static void _prec_extra(jag_prec_t *prec, uint32_t taskid)
 {
 	unsigned long utime, stime, total_rss, total_pgpgin;
 	char *cpu_time = NULL, *memory_stat = NULL, *ptr;
 	size_t cpu_time_size = 0, memory_stat_size = 0;
+	xcgroup_t *task_cpuacct_cg = NULL;;
+	xcgroup_t *task_memory_cg = NULL;
+	bool exit_early = false;
+
+	/* Find which task cgroups to use */
+	task_memory_cg = list_find_first(task_memory_cg_list,
+					 find_task_cg_info,
+					 &taskid);
+	task_cpuacct_cg = list_find_first(task_cpuacct_cg_list,
+					  find_task_cg_info,
+					  &taskid);
+
+	/*
+	 * We should always find the task cgroups; if we don't for some reason,
+	 * just print an error and return.
+	 */
+	if (!task_cpuacct_cg) {
+		error("%s: Could not find task_cpuacct_cg, this should never happen",
+		      __func__);
+		exit_early = true;
+	}
+	if (!task_memory_cg) {
+		error("%s: Could not find task_memory_cg, this should never happen",
+		      __func__);
+		exit_early = true;
+	}
+	if (exit_early)
+		return;
 
 	//DEF_TIMERS;
 	//START_TIMER;
 	/* info("before"); */
 	/* print_jag_prec(prec); */
-	xcgroup_get_param(&task_cpuacct_cg, "cpuacct.stat",
+	xcgroup_get_param(task_cpuacct_cg, "cpuacct.stat",
 			  &cpu_time, &cpu_time_size);
 	if (cpu_time == NULL) {
 		debug2("%s: failed to collect cpuacct.stat pid %d ppid %d",
 		       __func__, prec->pid, prec->ppid);
 	} else {
 		sscanf(cpu_time, "%*s %lu %*s %lu", &utime, &stime);
+		/*
+		 * Store unnormalized times, we will normalize in when
+		 * transfering to a struct jobacctinfo in job_common_poll_data()
+		 */
 		prec->usec = utime;
 		prec->ssec = stime;
 	}
 
-	xcgroup_get_param(&task_memory_cg, "memory.stat",
+	xcgroup_get_param(task_memory_cg, "memory.stat",
 			  &memory_stat, &memory_stat_size);
 	if (memory_stat == NULL) {
 		debug2("%s: failed to collect memory.stat  pid %d ppid %d",
@@ -213,29 +240,20 @@ extern int init (void)
 	if (_run_in_daemon()) {
 		jag_common_init(0);
 
-		/* read cgroup configuration */
-		if (read_slurm_cgroup_conf(&slurm_cgroup_conf))
-			return SLURM_ERROR;
-
 		/* initialize cpuinfo internal data */
 		if (xcpuinfo_init() != XCPUINFO_SUCCESS) {
-			free_slurm_cgroup_conf(&slurm_cgroup_conf);
 			return SLURM_ERROR;
 		}
 
 		/* enable cpuacct cgroup subsystem */
-		if (jobacct_gather_cgroup_cpuacct_init(&slurm_cgroup_conf) !=
-		    SLURM_SUCCESS) {
+		if (jobacct_gather_cgroup_cpuacct_init() != SLURM_SUCCESS) {
 			xcpuinfo_fini();
-			free_slurm_cgroup_conf(&slurm_cgroup_conf);
 			return SLURM_ERROR;
 		}
 
 		/* enable memory cgroup subsystem */
-		if (jobacct_gather_cgroup_memory_init(&slurm_cgroup_conf) !=
-		    SLURM_SUCCESS) {
+		if (jobacct_gather_cgroup_memory_init() != SLURM_SUCCESS) {
 			xcpuinfo_fini();
-			free_slurm_cgroup_conf(&slurm_cgroup_conf);
 			return SLURM_ERROR;
 		}
 
@@ -243,10 +261,9 @@ extern int init (void)
 		 *
 		 * Enable blkio subsystem.
 		 */
-		/* if (jobacct_gather_cgroup_blkio_init(&slurm_cgroup_conf) */
+		/* if (jobacct_gather_cgroup_blkio_init() */
 		/*     != SLURM_SUCCESS) { */
 		/* 	xcpuinfo_fini(); */
-		/* 	free_slurm_cgroup_conf(&slurm_cgroup_conf); */
 		/* 	return SLURM_ERROR; */
 		/* } */
 	}
@@ -258,13 +275,10 @@ extern int init (void)
 extern int fini (void)
 {
 	if (_run_in_daemon()) {
-		jobacct_gather_cgroup_cpuacct_fini(&slurm_cgroup_conf);
-		jobacct_gather_cgroup_memory_fini(&slurm_cgroup_conf);
-		/* jobacct_gather_cgroup_blkio_fini(&slurm_cgroup_conf); */
+		jobacct_gather_cgroup_cpuacct_fini();
+		jobacct_gather_cgroup_memory_fini();
+		/* jobacct_gather_cgroup_blkio_fini(); */
 		acct_gather_energy_fini();
-
-		/* unload configuration */
-		free_slurm_cgroup_conf(&slurm_cgroup_conf);
 	}
 	return SLURM_SUCCESS;
 }
@@ -333,7 +347,16 @@ extern char* jobacct_cgroup_create_slurm_cg(xcgroup_ns_t* ns)
 	/* we do it here as we do not have access to the conf structure */
 	/* in libslurm (src/common/xcgroup.c) */
 	xcgroup_t slurm_cg;
-	char* pre = (char*) xstrdup(slurm_cgroup_conf.cgroup_prepend);
+	char *pre;
+	slurm_cgroup_conf_t *cg_conf;
+
+	/* read cgroup configuration */
+	slurm_mutex_lock(&xcgroup_config_read_mutex);
+	cg_conf = xcgroup_get_slurm_cgroup_conf();
+
+	pre = xstrdup(cg_conf->cgroup_prepend);
+
+	slurm_mutex_unlock(&xcgroup_config_read_mutex);
 
 #ifdef MULTIPLE_SLURMD
 	if (conf->node_name != NULL) {
@@ -363,3 +386,24 @@ extern char* jobacct_cgroup_create_slurm_cg(xcgroup_ns_t* ns)
 
 	return pre;
 }
+
+extern int find_task_cg_info(void *x, void *key)
+{
+	task_cg_info_t *task_cg = (task_cg_info_t*)x;
+	uint32_t taskid = *(uint32_t*)key;
+
+	if (task_cg->taskid == taskid)
+		return 1;
+
+	return 0;
+}
+
+extern void free_task_cg_info(void *object)
+{
+	task_cg_info_t *task_cg = (task_cg_info_t *)object;
+
+	if (task_cg) {
+		xcgroup_destroy(&task_cg->task_cg);
+		xfree(task_cg);
+	}
+}
