@@ -57,31 +57,36 @@ static xcgroup_ns_t cpuacct_ns;
 static xcgroup_t user_cpuacct_cg;
 static xcgroup_t job_cpuacct_cg;
 static xcgroup_t step_cpuacct_cg;
-xcgroup_t task_cpuacct_cg;
+
+List task_cpuacct_cg_list = NULL;
 
 static uint32_t max_task_id;
 
 extern int
-jobacct_gather_cgroup_cpuacct_init(slurm_cgroup_conf_t *slurm_cgroup_conf)
+jobacct_gather_cgroup_cpuacct_init(void)
 {
 	/* initialize user/job/jobstep cgroup relative paths */
 	user_cgroup_path[0]='\0';
 	job_cgroup_path[0]='\0';
 	jobstep_cgroup_path[0]='\0';
+	task_cgroup_path[0]='\0';
 
 	/* initialize cpuacct cgroup namespace */
-	if (xcgroup_ns_create(slurm_cgroup_conf, &cpuacct_ns,  "", "cpuacct")
+	if (xcgroup_ns_create(&cpuacct_ns,  "", "cpuacct")
 	    != XCGROUP_SUCCESS) {
 		error("jobacct_gather/cgroup: unable to create cpuacct "
 		      "namespace");
 		return SLURM_ERROR;
 	}
 
+	FREE_NULL_LIST(task_cpuacct_cg_list);
+	task_cpuacct_cg_list = list_create(free_task_cg_info);
+
 	return SLURM_SUCCESS;
 }
 
 extern int
-jobacct_gather_cgroup_cpuacct_fini(slurm_cgroup_conf_t *slurm_cgroup_conf)
+jobacct_gather_cgroup_cpuacct_fini(void)
 {
 	xcgroup_t cpuacct_cg;
 	bool lock_ok;
@@ -90,7 +95,7 @@ jobacct_gather_cgroup_cpuacct_fini(slurm_cgroup_conf_t *slurm_cgroup_conf)
 	if (user_cgroup_path[0] == '\0'
 	    || job_cgroup_path[0] == '\0'
 	    || jobstep_cgroup_path[0] == '\0'
-	    || task_cgroup_path[0] == 0)
+	    || task_cgroup_path[0] == '\0')
 		return SLURM_SUCCESS;
 
 	/*
@@ -151,16 +156,16 @@ jobacct_gather_cgroup_cpuacct_fini(slurm_cgroup_conf_t *slurm_cgroup_conf)
 	if (lock_ok == true)
 		xcgroup_unlock(&cpuacct_cg);
 
-	xcgroup_destroy(&task_cpuacct_cg);
 	xcgroup_destroy(&user_cpuacct_cg);
 	xcgroup_destroy(&job_cpuacct_cg);
 	xcgroup_destroy(&step_cpuacct_cg);
 	xcgroup_destroy(&cpuacct_cg);
+	FREE_NULL_LIST(task_cpuacct_cg_list);
 
 	user_cgroup_path[0]='\0';
 	job_cgroup_path[0]='\0';
 	jobstep_cgroup_path[0]='\0';
-	task_cgroup_path[0] = 0;
+	task_cgroup_path[0]='\0';
 
 	xcgroup_ns_destroy(&cpuacct_ns);
 
@@ -180,17 +185,24 @@ jobacct_gather_cgroup_cpuacct_attach_task(pid_t pid, jobacct_id_t *jobacct_id)
 	int fstatus = SLURM_SUCCESS;
 	int rc;
 	char* slurm_cgpath;
+	task_cg_info_t *task_cg_info;
+	bool need_to_add = false;
 
 	job = jobacct_id->job;
 	uid = job->uid;
 	gid = job->gid;
-	jobid = job->jobid;
 	stepid = job->stepid;
 	taskid = jobacct_id->taskid;
+	if (job->pack_jobid && (job->pack_jobid != NO_VAL))
+		jobid = job->pack_jobid;
+	else
+		jobid = job->jobid;
 
 	if (taskid >= max_task_id)
 		max_task_id = taskid;
 
+	xassert(task_cpuacct_cg_list);
+
 	debug("%s: jobid %u stepid %u taskid %u max_task_id %u",
 	      __func__, jobid, stepid, taskid, max_task_id);
 
@@ -210,6 +222,7 @@ jobacct_gather_cgroup_cpuacct_attach_task(pid_t pid, jobacct_id_t *jobacct_id)
 			return SLURM_ERROR;
 		}
 	}
+	xfree(slurm_cgpath);
 
 	/* build job cgroup relative path if not set (may not be) */
 	if (*job_cgroup_path == '\0') {
@@ -344,26 +357,40 @@ jobacct_gather_cgroup_cpuacct_attach_task(pid_t pid, jobacct_id_t *jobacct_id)
 		goto error;
 	}
 
+	if (!(task_cg_info = list_find_first(task_cpuacct_cg_list,
+					     find_task_cg_info,
+					     &taskid))) {
+		task_cg_info = xmalloc(sizeof(*task_cg_info));
+		task_cg_info->taskid = taskid;
+		need_to_add = true;
+	}
+
 	/*
 	 * Create task cgroup in the cpuacct ns
 	 */
-	if (xcgroup_create(&cpuacct_ns, &task_cpuacct_cg,
+	if (xcgroup_create(&cpuacct_ns, &task_cg_info->task_cg,
 			   task_cgroup_path,
 			   uid, gid) != XCGROUP_SUCCESS) {
 		/* do not delete user/job cgroup as they can exist for other
 		 * steps, but release cgroup structures */
 		xcgroup_destroy(&user_cpuacct_cg);
 		xcgroup_destroy(&job_cpuacct_cg);
+
+		/* Don't use free_task_cg_info as the task_cg isn't there */
+		xfree(task_cg_info);
+
 		error("jobacct_gather/cgroup: unable to create jobstep %u.%u "
 		      "task %u cpuacct cgroup", jobid, stepid, taskid);
 		fstatus = SLURM_ERROR;
 		goto error;
 	}
 
-	if (xcgroup_instantiate(&task_cpuacct_cg) != XCGROUP_SUCCESS) {
+	if (xcgroup_instantiate(&task_cg_info->task_cg)
+	    != XCGROUP_SUCCESS) {
 		xcgroup_destroy(&user_cpuacct_cg);
 		xcgroup_destroy(&job_cpuacct_cg);
 		xcgroup_destroy(&step_cpuacct_cg);
+		free_task_cg_info(task_cg_info);
 		error("jobacct_gather/cgroup: unable to instantiate jobstep "
 		      "%u.%u task %u cpuacct cgroup", jobid, stepid, taskid);
 		fstatus = SLURM_ERROR;
@@ -373,14 +400,18 @@ jobacct_gather_cgroup_cpuacct_attach_task(pid_t pid, jobacct_id_t *jobacct_id)
 	/*
 	 * Attach the slurmstepd to the task cpuacct cgroup
 	 */
-	rc = xcgroup_add_pids(&task_cpuacct_cg, &pid, 1);
+	rc = xcgroup_add_pids(&task_cg_info->task_cg, &pid, 1);
 	if (rc != XCGROUP_SUCCESS) {
-		error("jobacct_gather/cgroup: unable to add slurmstepd to "
-		      "cpuacct cg '%s'", task_cpuacct_cg.path);
+		error("jobacct_gather/cgroup: unable to add slurmstepd to cpuacct cg '%s'",
+		      task_cg_info->task_cg.path);
 		fstatus = SLURM_ERROR;
 	} else
 		fstatus = SLURM_SUCCESS;
 
+	/* Add the task cgroup to the list now that it is initialized. */
+	if (need_to_add)
+		list_append(task_cpuacct_cg_list , task_cg_info);
+
 error:
 	xcgroup_unlock(&cpuacct_cg);
 	xcgroup_destroy(&cpuacct_cg);
