@@ -62,8 +62,8 @@
  * overwritten when linking with the slurmstepd.
  */
 #if defined (__APPLE__)
-uint32_t g_tres_count __attribute__((weak_import));
-char **assoc_mgr_tres_name_array __attribute__((weak_import));
+extern uint32_t g_tres_count __attribute__((weak_import));
+extern char **assoc_mgr_tres_name_array __attribute__((weak_import));
 #else
 uint32_t g_tres_count;
 char **assoc_mgr_tres_name_array;
@@ -250,47 +250,58 @@ static int _get_sys_interface_freq_line(uint32_t cpu, char *filename,
 	return 0;
 }
 
-static int _is_a_lwp(uint32_t pid) {
+static int _is_a_lwp(uint32_t pid)
+{
+	char *filename = NULL;
+	char bf[4096];
+	int fd, attempts = 1;
+	ssize_t n;
+	char *tgids = NULL;
+	pid_t tgid = -1;
 
-	FILE		*status_fp = NULL;
-	char		proc_status_file[256];
-	uint32_t        tgid;
-	int             rc;
+	xstrfmtcat(filename, "/proc/%u/status", pid);
 
-	if (snprintf(proc_status_file, 256, "/proc/%d/status",pid) > 256) {
-		debug("jobacct_gather_linux: unable to build proc_status "
-		      "fpath");
-		return -1;
-	}
-	if (!(status_fp = fopen(proc_status_file, "r"))) {
-		debug3("jobacct_gather_linux: unable to open %s",
-		       proc_status_file);
+	fd = open(filename, O_RDONLY);
+	if (fd < 0) {
+		error("%s: open() %s failed: %m", __func__, filename);
+		xfree(filename);
 		return -1;
 	}
 
-
-	do {
-		rc = fscanf(status_fp,
-			    "Name:\t%*s\n%*[ \ta-zA-Z0-9:()]\nTgid:\t%d\n",
-			    &tgid);
-	} while (rc < 0 && errno == EINTR);
-	fclose(status_fp);
-
-	/* unable to read /proc/[pid]/status content */
-	if (rc != 1) {
-		debug3("jobacct_gather_linux: unable to read requested "
-		       "pattern in %s", proc_status_file);
+again:
+	n = read(fd, bf, sizeof(bf) - 1);
+	if (n == -1 && (errno == EINTR || errno == EAGAIN) && attempts < 100) {
+		attempts++;
+		goto again;
+	}
+	if (n <= 0) {
+		error("%s: %d read() attempts on %s failed: %m", __func__,
+		      attempts, filename);
+		close(fd);
+		xfree(filename);
 		return -1;
 	}
+	bf[n] = '\0';
+	close(fd);
+	xfree(filename);
 
-	/* if tgid differs from pid, this is a LWP (Thread POSIX) */
-	if ((uint32_t) tgid != (uint32_t) pid) {
-		debug3("jobacct_gather_linux: pid=%d is a lightweight process",
-		       tgid);
-		return 1;
+	tgids = xstrstr(bf, "Tgid:");
+
+	if (tgids) {
+		tgids += 5; /* strlen("Tgid:") */
+		tgid = atoi(tgids);
 	} else
-		return 0;
+		error("%s: Tgid: string not found for pid=%u", __func__, pid);
 
+	if (pid != (uint32_t)tgid) {
+		debug3("%s: pid=%u != tgid=%u is a lightweight process",
+		       __func__, pid, tgid);
+		return 1;
+	} else {
+		debug3("%s: pid=%u == tgid=%u is the leader LWP",
+		       __func__, pid, tgid);
+		return 0;
+	}
 }
 
 /* _get_process_data_line() - get line of data from /proc/<pid>/stat
@@ -518,11 +529,7 @@ static void _handle_stats(List prec_list, char *proc_stat_file,
 	if (fcntl(fd, F_SETFD, FD_CLOEXEC) == -1)
 		error("%s: fcntl(%s): %m", __func__, proc_stat_file);
 
-	prec = try_xmalloc(sizeof(jag_prec_t));
-	if (prec == NULL) {	/* Avoid killing slurmstepd on malloc failure */
-		fclose(stat_fp);
-		return;
-	}
+	prec = xmalloc(sizeof(jag_prec_t));
 
 	if (!tres_count) {
 		assoc_mgr_lock_t locks = {
@@ -931,7 +938,6 @@ extern void jag_common_poll_data(
 	time_t ct;
 	static int over_memory_kill = -1;
 	int i = 0;
-	char *tok, *save_ptr = NULL;
 
 	xassert(callbacks);
 
@@ -946,24 +952,6 @@ extern void jag_common_poll_data(
 	}
 	processing = 1;
 
-	if (over_memory_kill == -1) {
-		char *acct_params = slurm_get_jobacct_gather_params();
-
-		over_memory_kill = 0;
-
-		if (acct_params) {
-			tok = strtok_r(acct_params, ",", &save_ptr);
-			while (tok) {
-				if (xstrcasecmp(tok, "OverMemoryKill") == 0) {
-					over_memory_kill = 1;
-					break;
-				}
-				tok = strtok_r(NULL, ",", &save_ptr);
-			}
-			xfree(acct_params);
-		}
-	}
-
 	if (!callbacks->get_precs)
 		callbacks->get_precs = _get_precs;
 
@@ -1030,7 +1018,7 @@ extern void jag_common_poll_data(
 			       __func__,
 			       prec->tres_data[TRES_ARRAY_ENERGY].size_read,
 			       prec->tres_data[TRES_ARRAY_ENERGY].size_write,
-			       jobacct->energy.base_watts);
+			       jobacct->energy.ave_watts);
 			energy_counted = 1;
 		}
 
@@ -1129,8 +1117,12 @@ extern void jag_common_poll_data(
 	}
 	list_iterator_destroy(itr);
 
+	if (over_memory_kill == -1)
+		over_memory_kill = slurm_get_job_acct_oom_kill();
+
 	if (over_memory_kill)
-		jobacct_gather_handle_mem_limit(total_job_mem, total_job_vsize);
+		jobacct_gather_handle_mem_limit(total_job_mem,
+						total_job_vsize);
 
 finished:
 	FREE_NULL_LIST(prec_list);
