@@ -4,11 +4,11 @@
  *  Copyright (C) 2017      Mellanox Technologies. All rights reserved.
  *  Written by Artem Polyakov <artpol84@gmail.com, artemp@mellanox.com>.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -24,13 +24,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
  \*****************************************************************************/
 
@@ -162,7 +162,7 @@ static int _load_ucx_lib()
 	setenv("UCX_MEM_EVENTS", "no", 1);
 
 #ifdef PMIXP_UCX_LIBPATH
-	/* If this SLURM build doesn't allow RPATH's
+	/* If this Slurm build doesn't allow RPATH's
 	 * try to open library by it's full path that
 	 * we have from autoconf
 	 */
@@ -222,7 +222,7 @@ int pmixp_dconn_ucx_prepare(pmixp_dconn_handlers_t *handlers,
 	pmixp_rlist_init(&_rcv_complete, &_free_list, PMIXP_UCX_LIST_PREALLOC);
 
 
-	status = ucp_config_read(NULL, NULL, &config);
+	status = ucp_config_read("SLURM", NULL, &config);
 	if (status != UCS_OK) {
 		PMIXP_ERROR("Fail to read UCX config: %s",
 			    ucs_status_string(status));
