@@ -52,7 +52,7 @@ static bool _srv_use_direct_conn_ucx = true;
 #else
 static bool _srv_use_direct_conn_ucx = false;
 #endif
-static int _srv_fence_coll_type = PMIXP_COLL_CPERF_RING;
+static int _srv_fence_coll_type = PMIXP_COLL_TYPE_FENCE_MAX;
 static bool _srv_fence_coll_barrier = false;
 
 pmix_jobinfo_t _pmixp_job_info;
@@ -320,7 +320,7 @@ static int _resources_set(char ***env)
 	if (!p) {
 		p = getenvp(*env, PMIXP_JOB_NODES_ENV_DEP);
 		if (!p) {
-			/* shouldn't happen if we are under SLURM! */
+			/* shouldn't happen if we are under Slurm! */
 			PMIXP_ERROR_NO(ENOENT,
 				       "Neither of nodelist environment variables: %s OR %s was found!",
 				       PMIXP_JOB_NODES_ENV,
