@@ -500,19 +500,20 @@ static int _auth_cred_create(Buf buf)
 	char *auth_info = slurm_get_auth_info();
 	int rc = SLURM_SUCCESS;
 
-	auth_cred = g_slurm_auth_create(auth_info);
+	auth_cred = g_slurm_auth_create(AUTH_DEFAULT_INDEX, auth_info);
 	xfree(auth_info);
 	if (!auth_cred) {
-		rc = g_slurm_auth_errno(NULL);
-		PMIXP_ERROR("Creating authentication credential: %s",
-			    g_slurm_auth_errstr(rc));
-		return rc;
+		PMIXP_ERROR("Creating authentication credential: %m");
+		return errno;
 	}
 
-	rc = g_slurm_auth_pack(auth_cred, buf);
+	/*
+	 * We can use SLURM_PROTOCOL_VERSION here since there is no possibility
+	 * of protocol mismatch.
+	 */
+	rc = g_slurm_auth_pack(auth_cred, buf, SLURM_PROTOCOL_VERSION);
 	if (rc)
-		PMIXP_ERROR("Packing authentication credential: %s",
-			    g_slurm_auth_errstr(g_slurm_auth_errno(auth_cred)));
+		PMIXP_ERROR("Packing authentication credential: %m");
 
 	g_slurm_auth_destroy(auth_cred);
 
@@ -525,11 +526,14 @@ static int _auth_cred_verify(Buf buf)
 	char *auth_info = NULL;
 	int rc = SLURM_SUCCESS;
 
-	auth_cred = g_slurm_auth_unpack(buf);
+	/*
+	 * We can use SLURM_PROTOCOL_VERSION here since there is no possibility
+	 * of protocol mismatch.
+	 */
+	auth_cred = g_slurm_auth_unpack(buf, SLURM_PROTOCOL_VERSION);
 	if (!auth_cred) {
-		PMIXP_ERROR("Unpacking authentication credential: %s",
-			    g_slurm_auth_errstr(g_slurm_auth_errno(NULL)));
-		return SLURM_FAILURE;
+		PMIXP_ERROR("Unpacking authentication credential: %m");
+		return SLURM_ERROR;
 	}
 
 	auth_info = slurm_get_auth_info();
@@ -537,8 +541,7 @@ static int _auth_cred_verify(Buf buf)
 	xfree(auth_info);
 
 	if (rc)
-		PMIXP_ERROR("Verifying authentication credential: %s",
-			    g_slurm_auth_errstr(g_slurm_auth_errno(auth_cred)));
+		PMIXP_ERROR("Verifying authentication credential: %m");
 	g_slurm_auth_destroy(auth_cred);
 	return rc;
 }
@@ -1530,7 +1533,6 @@ static volatile int _pmixp_pp_count = 0;
 
 static volatile int _pmixp_pp_warmup = 0;
 static volatile int _pmixp_pp_iters = 0;
-static volatile int _pmixp_pp_iter_count = 0;
 static double _pmixp_pp_start = 0;
 
 int pmixp_server_pp_count(void)
