@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  backfill_wrapper.c - plugin for SLURM backfill scheduler.
+ *  backfill_wrapper.c - plugin for Slurm backfill scheduler.
  *  Operates like FIFO, but backfill scheduler daemon will explicitly modify
  *  the priority of jobs as needed to achieve backfill scheduling.
  *****************************************************************************
@@ -8,11 +8,11 @@
  *  Written by Jay Windley <jwindley@lnxi.com>, Morris Jette <jette1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -28,13 +28,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -51,7 +51,7 @@
 #include "src/slurmctld/slurmctld.h"
 #include "backfill.h"
 
-const char		plugin_name[]	= "SLURM Backfill Scheduler plugin";
+const char		plugin_name[]	= "Slurm Backfill Scheduler plugin";
 const char		plugin_type[]	= "sched/backfill";
 const uint32_t		plugin_version	= SLURM_VERSION_NUMBER;
 
@@ -63,7 +63,7 @@ int init( void )
 	if (slurmctld_config.scheduling_disabled)
 		return SLURM_SUCCESS;
 
-	verbose( "sched: Backfill scheduler plugin loaded" );
+	sched_verbose("Backfill scheduler plugin loaded");
 
 	slurm_mutex_lock( &thread_flag_mutex );
 	if ( backfill_thread ) {
