@@ -1,5 +1,5 @@
 /*****************************************************************************\
- *  builtin_wrapper.c - NO-OP plugin for SLURM's internal scheduler.
+ *  builtin_wrapper.c - NO-OP plugin for Slurm's internal scheduler.
  *****************************************************************************
  *  Copyright (C) 2002-2007 The Regents of the University of California.
  *  Copyright (C) 2008-2010 Lawrence Livermore National Security.
@@ -7,11 +7,11 @@
  *  Written by Kevin Tew <tew1@llnl.gov> et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -50,7 +50,7 @@
 #include "src/slurmctld/slurmctld.h"
 #include "src/plugins/sched/builtin/builtin.h"
 
-const char		plugin_name[]	= "SLURM Built-in Scheduler plugin";
+const char		plugin_name[]	= "Slurm Built-in Scheduler plugin";
 const char		plugin_type[]	= "sched/builtin";
 const uint32_t		plugin_version	= SLURM_VERSION_NUMBER;
 
@@ -59,7 +59,7 @@ static pthread_mutex_t thread_flag_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 int init(void)
 {
-	verbose( "sched: Built-in scheduler plugin loaded" );
+	sched_verbose("Built-in scheduler plugin loaded");
 
 	slurm_mutex_lock( &thread_flag_mutex );
 	if ( builtin_thread ) {
