@@ -1,17 +1,17 @@
 /*****************************************************************************\
  *  hold_wrapper.c - Hold all newly arriving jobs if there is a file
- *  "/etc/slurm.hold", otherwise use SLURM's internal scheduler.
+ *  "/etc/slurm.hold", otherwise use Slurm's internal scheduler.
  *****************************************************************************
  *  Copyright (C) 2002 The Regents of the University of California.
  *  Produced at Lawrence Livermore National Laboratory (cf, DISCLAIMER).
  *  Written by Morris Jette <jette1@llnl.gov> et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -49,13 +49,13 @@
 #include "src/slurmctld/slurmctld.h"
 #include "src/common/slurm_priority.h"
 
-const char		plugin_name[]	= "SLURM Hold Scheduler plugin";
+const char		plugin_name[]	= "Slurm Hold Scheduler plugin";
 const char		plugin_type[]	= "sched/hold";
 const uint32_t		plugin_version	= SLURM_VERSION_NUMBER;
 
 int init(void)
 {
-	verbose( "sched: Hold scheduler plugin loaded" );
+	sched_verbose("Hold scheduler plugin loaded");
 	return SLURM_SUCCESS;
 }
 
