@@ -3,7 +3,7 @@
  *
  *  NOTE: The node selection plugin itself is intimately tied to slurmctld
  *  functions and data structures. Some related functions (e.g. data structure
- *  un/packing, environment variable setting) are required by most SLURM
+ *  un/packing, environment variable setting) are required by most Slurm
  *  commands. Since some of these commands must be executed on the BlueGene
  *  front-end nodes, the functions they require are here rather than within
  *  the plugin. This is because functions required by the plugin can not be
@@ -71,7 +71,6 @@ const char *node_select_syms[] = {
 	"select_p_job_test",
 	"select_p_job_begin",
 	"select_p_job_ready",
-	"select_p_job_expand_allow",
 	"select_p_job_expand",
 	"select_p_job_resized",
 	"select_p_job_signal",
@@ -98,14 +97,11 @@ const char *node_select_syms[] = {
 	"select_p_select_jobinfo_unpack",
 	"select_p_select_jobinfo_sprint",
 	"select_p_select_jobinfo_xstrdup",
-	"select_p_update_basil",
 	"select_p_get_info_from_plugin",
 	"select_p_update_node_config",
 	"select_p_update_node_state",
 	"select_p_reconfigure",
 	"select_p_resv_test",
-	"select_p_ba_init",
-	"select_p_ba_get_dims",
 };
 
 static slurm_select_ops_t ops;
@@ -306,17 +302,6 @@ extern int other_job_ready(struct job_record *job_ptr)
 	return (*(ops.job_ready))(job_ptr);
 }
 
-/*
- * Test if expanding a job is permitted
- */
-extern bool other_job_expand_allow(void)
-{
-	if (other_select_init() < 0)
-		return false;
-
-	return (*(ops.job_expand_allow))();
-}
-
 /*
  * Move the resource allocated to one job into that of another job.
  *	All resources are removed from "from_job_ptr" and moved into
@@ -711,19 +696,3 @@ extern bitstr_t * other_resv_test(resv_desc_msg_t *resv_desc_ptr,
 	return (*(ops.resv_test))(resv_desc_ptr, node_cnt,
 				  avail_bitmap, core_bitmap);
 }
-
-extern void other_ba_init(node_info_msg_t *node_info_ptr, bool sanity_check)
-{
-	if (other_select_init() < 0)
-		return;
-
-	(*(ops.ba_init))(node_info_ptr, sanity_check);
-}
-
-extern int *other_ba_get_dims(void)
-{
-	if (other_select_init() < 0)
-		return NULL;
-
-	return (*(ops.ba_get_dims))();
-}
