@@ -37,12 +37,6 @@
 #  include "config.h"
 #endif
 
-#define _GNU_SOURCE
-
-#ifndef __USE_GNU
-#  define  __USE_GNU
-#endif
-
 #ifdef HAVE_NUMA
 #  include <numa.h>
 #endif
@@ -126,8 +120,6 @@ uint16_t slurm_get_numa_node(uint16_t cpuid);
 #endif
 
 /*** from schedutils.c ***/
-int	char_to_val(int c);
 int	str_to_cpuset(cpu_set_t *mask, const char* str);
 int	str_to_cnt(const char* str);
 char *	cpuset_to_str(const cpu_set_t *mask, char *str);
-int	val_to_char(int v);
