@@ -6,11 +6,11 @@
  *  Portions copyright (C) 2012,2015 Bull/Atos
  *  Written by Martin Perry <martin.perry@atos.net>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -141,19 +141,6 @@ static xcgroup_t step_cpuset_cg;
 
 static int _xcgroup_cpuset_init(xcgroup_t* cg);
 
-static inline int _char_to_val(int c)
-{
-	int cl;
-
-	cl = tolower(c);
-	if (c >= '0' && c <= '9')
-		return c - '0';
-	else if (cl >= 'a' && cl <= 'f')
-		return cl + (10 - 'a');
-	else
-		return -1;
-}
-
 /* when cgroups are configured with cpuset, at least
  * cpuset.cpus and cpuset.mems must be set or the cgroup
  * will not be available at all.
@@ -427,7 +414,7 @@ static int _get_sched_cpuset(hwloc_topology_t topology,
 		if (len > 1 && !memcmp(mstr, "0x", 2L))
 			curstr += 2;
 		while (ptr >= curstr) {
-			char val = _char_to_val(*ptr);
+			char val = slurm_char_to_hex(*ptr);
 			if (val == (char) -1)
 				return false;
 			if (val & 1)
@@ -558,8 +545,9 @@ static int _task_cgroup_cpuset_dist_cyclic(
 	 * hardware instead of whatever is possibly configured.  So we need to
 	 * look it up again.
 	 */
-	if (get_cpuinfo(&npus, &nboards, &nsockets, &ncores, &nthreads,
-			NULL, NULL, NULL) != SLURM_SUCCESS) {
+	if (xcpuinfo_hwloc_topo_get(
+		    &npus, &nboards, &nsockets, &ncores, &nthreads,
+		    NULL, NULL, NULL) != SLURM_SUCCESS) {
 		/*
 		 * Fall back to use allocated resources, but this may result
 		 * in incorrect layout due to a uneven task distribution
@@ -752,7 +740,7 @@ static int _task_cgroup_cpuset_dist_cyclic(
 			if (bit_test(spec_threads, i)) {
 				hwloc_bitmap_clr(cpuset, i);
 			}
-		};
+		}
 		FREE_NULL_BITMAP(spec_threads);
 	}
 
@@ -988,7 +976,7 @@ static void _validate_mask(uint32_t task_id, hwloc_obj_t obj, cpu_set_t *ts)
 
 #endif
 
-extern int task_cgroup_cpuset_init(slurm_cgroup_conf_t *slurm_cgroup_conf)
+extern int task_cgroup_cpuset_init(void)
 {
 	/* initialize user/job/jobstep cgroup relative paths */
 	user_cgroup_path[0]='\0';
@@ -996,7 +984,7 @@ extern int task_cgroup_cpuset_init(slurm_cgroup_conf_t *slurm_cgroup_conf)
 	jobstep_cgroup_path[0]='\0';
 
 	/* initialize cpuset cgroup namespace */
-	if (xcgroup_ns_create(slurm_cgroup_conf, &cpuset_ns, "", "cpuset")
+	if (xcgroup_ns_create(&cpuset_ns, "", "cpuset")
 	    != XCGROUP_SUCCESS) {
 		error("task/cgroup: unable to create cpuset namespace");
 		return SLURM_ERROR;
@@ -1005,7 +993,7 @@ extern int task_cgroup_cpuset_init(slurm_cgroup_conf_t *slurm_cgroup_conf)
 	return SLURM_SUCCESS;
 }
 
-extern int task_cgroup_cpuset_fini(slurm_cgroup_conf_t *slurm_cgroup_conf)
+extern int task_cgroup_cpuset_fini(void)
 {
 	xcgroup_t cpuset_cg;
 
@@ -1058,7 +1046,7 @@ extern int task_cgroup_cpuset_create(stepd_step_rec_t *job)
 	int rc;
 	int fstatus = SLURM_ERROR;
 	xcgroup_t cpuset_cg;
-	uint32_t jobid = job->jobid;
+	uint32_t jobid;
 	uint32_t stepid = job->stepid;
 	uid_t uid = job->uid;
 	uid_t gid = job->gid;
@@ -1068,10 +1056,8 @@ extern int task_cgroup_cpuset_create(stepd_step_rec_t *job)
 	char cpuset_meta[PATH_MAX];
 	char *cpus = NULL;
 	size_t cpus_size;
-
-	char* slurm_cgpath;
+	char *slurm_cgpath;
 	xcgroup_t slurm_cg;
-
 #ifdef HAVE_NATIVE_CRAY
 	char expected_usage[32];
 #endif
@@ -1122,11 +1108,15 @@ again:
 	xfree(slurm_cgpath);
 
 	/* build job cgroup relative path if no set (should not be) */
+	if (job->pack_jobid && (job->pack_jobid != NO_VAL))
+		jobid = job->pack_jobid;
+	else
+		jobid = job->jobid;
 	if (*job_cgroup_path == '\0') {
 		if (snprintf(job_cgroup_path,PATH_MAX,"%s/job_%u",
-			     user_cgroup_path,jobid) >= PATH_MAX) {
+			     user_cgroup_path, jobid) >= PATH_MAX) {
 			error("task/cgroup: unable to build job %u cpuset "
-			      "cg relative path : %m",jobid);
+			      "cg relative path : %m", jobid);
 			return SLURM_ERROR;
 		}
 	}
@@ -1160,7 +1150,7 @@ again:
 	 * setting it up. As soon as the step cgroup is created, we can release
 	 * the lock.
 	 * Indeed, consecutive slurm steps could result in cg being removed
-	 * between the next EEXIST instanciation and the first addition of
+	 * between the next EEXIST instantiation and the first addition of
 	 * a task. The release_agent will have to lock the root cpuset cgroup
 	 * to avoid this scenario.
 	 */
@@ -1250,7 +1240,6 @@ again:
 		goto error;
 	}
 	xcgroup_set_param(&job_cpuset_cg, cpuset_meta, job_alloc_cores);
-
 	/*
 	 * create step cgroup in the cpuset ns (it should not exists)
 	 * use job's user uid/gid to enable tasks cgroups creation by
@@ -1303,7 +1292,6 @@ again:
 
 	/* validate the requested cpu frequency and set it */
 	cpu_freq_cgroup_validate(job, step_alloc_cores);
-
 error:
 	xcgroup_unlock(&cpuset_cg);
 	xcgroup_destroy(&cpuset_cg);
@@ -1363,7 +1351,10 @@ extern int task_cgroup_cpuset_set_task_affinity(stepd_step_rec_t *job)
 
 	/* Allocate and initialize hwloc objects */
 	hwloc_topology_init(&topology);
-	hwloc_topology_load(topology);
+
+	xassert(conf->hwloc_xml);
+	xcpuinfo_hwloc_topo_load(&topology, conf->hwloc_xml, false);
+
 	cpuset = hwloc_bitmap_alloc();
 #if HWLOC_API_VERSION >= 0x00020000
 	global_allowed_cpuset = hwloc_bitmap_alloc();
