@@ -4,11 +4,11 @@
  *  Copyright (C) 2009 CEA/DAM/DIF
  *  Written by Matthieu Hautreux <matthieu.hautreux@cea.fr>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -24,17 +24,17 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
-#define _GNU_SOURCE		/* For POLLRDHUP */
+#define _GNU_SOURCE		/* For POLLRDHUP, O_CLOEXEC on older glibc */
 #include <limits.h>
 #include <poll.h>
 #include <signal.h>
@@ -51,7 +51,7 @@
 
 #include "task_cgroup.h"
 
-#if defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__NetBSD__)
 #define POLLRDHUP POLLHUP
 #else
 #include <sys/eventfd.h>
@@ -117,10 +117,11 @@ static uint64_t percent_in_bytes (uint64_t mb, float percent)
 	return ((mb * 1024 * 1024) * (percent / 100.0));
 }
 
-extern int task_cgroup_memory_init(slurm_cgroup_conf_t *slurm_cgroup_conf)
+extern int task_cgroup_memory_init(void)
 {
 	xcgroup_t memory_cg;
 	bool set_swappiness;
+	slurm_cgroup_conf_t *slurm_cgroup_conf;
 
 	/* initialize user/job/jobstep cgroup relative paths */
 	user_cgroup_path[0]='\0';
@@ -128,8 +129,7 @@ extern int task_cgroup_memory_init(slurm_cgroup_conf_t *slurm_cgroup_conf)
 	jobstep_cgroup_path[0]='\0';
 
 	/* initialize memory cgroup namespace */
-	if (xcgroup_ns_create(slurm_cgroup_conf, &memory_ns, "", "memory")
-	    != XCGROUP_SUCCESS) {
+	if (xcgroup_ns_create(&memory_ns, "", "memory") != XCGROUP_SUCCESS) {
 		error("task/cgroup: unable to create memory namespace. "
 			"You may need to set the Linux kernel option "
 			"cgroup_enable=memory (and reboot), or disable "
@@ -146,6 +146,10 @@ extern int task_cgroup_memory_init(slurm_cgroup_conf_t *slurm_cgroup_conf)
 	}
 	xcgroup_set_param(&memory_cg, "memory.use_hierarchy","1");
 
+	/* read cgroup configuration */
+	slurm_mutex_lock(&xcgroup_config_read_mutex);
+	slurm_cgroup_conf = xcgroup_get_slurm_cgroup_conf();
+
 	set_swappiness = (slurm_cgroup_conf->memory_swappiness != NO_VAL64);
 	if (set_swappiness)
 		xcgroup_set_uint64_param(&memory_cg, "memory.swappiness",
@@ -222,6 +226,7 @@ extern int task_cgroup_memory_init(slurm_cgroup_conf_t *slurm_cgroup_conf)
          *  in /etc/sysconfig/slurm would be the same
          */
         setenv("SLURMSTEPD_OOM_ADJ", "-1000", 0);
+	slurm_mutex_unlock(&xcgroup_config_read_mutex);
 
 	return SLURM_SUCCESS;
 }
@@ -291,7 +296,7 @@ extern int task_cgroup_memory_fini(slurm_cgroup_conf_t *slurm_cgroup_conf)
 static uint64_t mem_limit_in_bytes (uint64_t mem, bool with_allowed)
 {
 	/*
-	 *  If mem == 0 then assume there was no SLURM limit imposed
+	 *  If mem == 0 then assume there was no Slurm limit imposed
 	 *   on the amount of memory for job or step. Use the total
 	 *   amount of available RAM instead.
 	 */
@@ -362,6 +367,16 @@ static int memcg_initialize (xcgroup_ns_t *ns, xcgroup_t *cg,
 	uint64_t mlb_soft = mem_limit_in_bytes(mem_limit, false);
 	uint64_t mls = swap_limit_in_bytes  (mem_limit);
 
+	if (mlb_soft > mlb) {
+		/*
+		 * NOTE: It is recommended to set the soft limit always below
+		 * the hard limit, otherwise the hard one will take precedence.
+		 */
+		debug2("%s: Setting memory.soft_limit_in_bytes (%"PRIu64" bytes) to the same value as memory.limit_in_bytes (%"PRIu64" bytes) for cgroup: %s",
+		       __func__, mlb_soft, mlb, path);
+		mlb_soft = mlb;
+	}
+
 	if (xcgroup_create (ns, cg, path, uid, gid) != XCGROUP_SUCCESS)
 		return -1;
 
@@ -409,11 +424,11 @@ static int memcg_initialize (xcgroup_ns_t *ns, xcgroup_t *cg,
 	return 0;
 }
 
-#if defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__) || defined(__NetBSD__)
 
 static int _register_oom_notifications(char *ignored)
 {
-	error("OOM notification does not work on FreeBSD or NetBSD");
+	error("OOM notification does not work on FreeBSD, NetBSD, or macOS");
 
 	return SLURM_ERROR;
 }
@@ -572,7 +587,7 @@ static int _register_oom_notifications(char * cgpath)
 		goto fini;
 	}
 
-	if ((cfd = open(control_file, O_RDONLY)) == -1) {
+	if ((cfd = open(control_file, O_RDONLY | O_CLOEXEC)) == -1) {
 		error("%s: Cannot open %s: %m", __func__, control_file);
 		rc = SLURM_ERROR;
 		goto fini;
@@ -586,13 +601,13 @@ static int _register_oom_notifications(char * cgpath)
 		goto fini;
 	}
 
-	if ((efd = open(event_file, O_WRONLY)) == -1) {
+	if ((efd = open(event_file, O_WRONLY | O_CLOEXEC)) == -1) {
 		error("%s: Cannot open %s: %m", __func__, event_file);
 		rc = SLURM_ERROR;
 		goto fini;
 	}
 
-	if ((event_fd = eventfd(0, 0)) == -1) {
+	if ((event_fd = eventfd(0, EFD_CLOEXEC)) == -1) {
 		error("%s: eventfd: %m", __func__);
 		rc = SLURM_ERROR;
 		goto fini;
@@ -614,7 +629,7 @@ static int _register_oom_notifications(char * cgpath)
 		goto fini;
 	}
 
-	if (pipe(oom_pipe) == -1) {
+	if (pipe2(oom_pipe, O_CLOEXEC) == -1) {
 		error("%s: pipe(): %m", __func__);
 		rc = SLURM_ERROR;
 		goto fini;
@@ -658,7 +673,7 @@ extern int task_cgroup_memory_create(stepd_step_rec_t *job)
 {
 	int fstatus = SLURM_ERROR;
 	xcgroup_t memory_cg;
-	uint32_t jobid = job->jobid;
+	uint32_t jobid;
 	uint32_t stepid = job->stepid;
 	uid_t uid = job->uid;
 	gid_t gid = job->gid;
@@ -683,9 +698,13 @@ extern int task_cgroup_memory_create(stepd_step_rec_t *job)
 	xfree(slurm_cgpath);
 
 	/* build job cgroup relative path if no set (should not be) */
+	if (job->pack_jobid && (job->pack_jobid != NO_VAL))
+		jobid = job->pack_jobid;
+	else
+		jobid = job->jobid;
 	if (*job_cgroup_path == '\0') {
 		if (snprintf(job_cgroup_path,PATH_MAX,"%s/job_%u",
-			      user_cgroup_path,jobid) >= PATH_MAX) {
+			      user_cgroup_path, jobid) >= PATH_MAX) {
 			error("task/cgroup: unable to build job %u memory "
 			      "cg relative path : %m", jobid);
 			return SLURM_ERROR;
@@ -721,7 +740,7 @@ extern int task_cgroup_memory_create(stepd_step_rec_t *job)
 	 * setting it up. As soon as the step cgroup is created, we can release
 	 * the lock.
 	 * Indeed, consecutive slurm steps could result in cg being removed
-	 * between the next EEXIST instanciation and the first addition of
+	 * between the next EEXIST instantiation and the first addition of
 	 * a task. The release_agent will have to lock the root memory cgroup
 	 * to avoid this scenario.
 	 */
@@ -833,6 +852,7 @@ extern int task_cgroup_memory_check_oom(stepd_step_rec_t *job)
 	char step_str[20];
 	uint64_t stop_msg;
 	ssize_t ret;
+	uint32_t jobid;
 
 	if (xcgroup_create(&memory_ns, &memory_cg, "", 0, 0)
 	    != XCGROUP_SUCCESS) {
@@ -845,15 +865,17 @@ extern int task_cgroup_memory_check_oom(stepd_step_rec_t *job)
 		goto fail_xcgroup_lock;
 	}
 
+	if (job->pack_jobid && (job->pack_jobid != NO_VAL))
+		jobid = job->pack_jobid;
+	else
+		jobid = job->jobid;
 	if (job->stepid == SLURM_BATCH_SCRIPT)
-		snprintf(step_str, sizeof(step_str), "%u.batch",
-			 job->jobid);
+		snprintf(step_str, sizeof(step_str), "%u.batch", jobid);
 	else if (job->stepid == SLURM_EXTERN_CONT)
-		snprintf(step_str, sizeof(step_str), "%u.extern",
-			 job->jobid);
+		snprintf(step_str, sizeof(step_str), "%u.extern", jobid);
 	else
 		snprintf(step_str, sizeof(step_str), "%u.%u",
-			 job->jobid, job->stepid);
+			 jobid, job->stepid);
 
 	if (failcnt_non_zero(&step_memory_cg, "memory.memsw.failcnt")) {
 		/*
@@ -873,10 +895,10 @@ extern int task_cgroup_memory_check_oom(stepd_step_rec_t *job)
 
 	if (failcnt_non_zero(&job_memory_cg, "memory.memsw.failcnt")) {
 		info("Job %u hit memory+swap limit at least once during execution. This may or may not result in some failure.",
-		     job->jobid);
+		     jobid);
 	} else if (failcnt_non_zero(&job_memory_cg, "memory.failcnt")) {
 		info("Job %u hit memory limit at least once during execution. This may or may not result in some failure.",
-		     job->jobid);
+		     jobid);
 	}
 
 	if (!oom_thread_created) {
@@ -912,7 +934,7 @@ extern int task_cgroup_memory_check_oom(stepd_step_rec_t *job)
 
 	slurm_mutex_lock(&oom_mutex);
 	if (oom_kill_count) {
-		error("Detected %"PRIu64" oom-kill event(s) in step %s cgroup.",
+		error("Detected %"PRIu64" oom-kill event(s) in step %s cgroup. Some of your processes may have been killed by the cgroup out-of-memory handler.",
 		      oom_kill_count, step_str);
 		rc = ENOMEM;
 	}
