@@ -81,7 +81,7 @@ static List _build_cluster_list(slurmdb_federation_rec_t *fed)
 
 	cluster_list = list_create(slurm_destroy_char);
 	iter = list_iterator_create(fed->cluster_list);
-	while ((cluster = (slurmdb_cluster_rec_t *) list_next(iter)))
+	while ((cluster = list_next(iter)))
 		(void) slurm_addto_char_list(cluster_list, cluster->name);
 	list_iterator_destroy(iter);
 
@@ -207,6 +207,125 @@ static int _addto_id_char_list(List char_list, char *names, bool gid)
 }
 
 /* returns number of objects added to list */
+static int _addto_reason_char_list(List char_list, char *names)
+{
+	int i = 0, start = 0;
+	uint32_t c;
+	char *name = NULL, *tmp_char = NULL;
+	ListIterator itr = NULL;
+	char quote_c = '\0';
+	int quote = 0;
+	int count = 0;
+
+	if (!char_list) {
+		error("No list was given to fill in");
+		return 0;
+	}
+
+	itr = list_iterator_create(char_list);
+	if (names) {
+		if (names[i] == '\"' || names[i] == '\'') {
+			quote_c = names[i];
+			quote = 1;
+			i++;
+		}
+		start = i;
+		while (names[i]) {
+			//info("got %d - %d = %d", i, start, i-start);
+			if (quote && names[i] == quote_c)
+				break;
+			else if (names[i] == '\"' || names[i] == '\'')
+				names[i] = '`';
+			else if (names[i] == ',') {
+				if ((i-start) > 0) {
+					name = xmalloc((i-start+1));
+					memcpy(name, names+start, (i-start));
+					c = job_reason_num(name);
+					if (c == NO_VAL)
+						fatal("unrecognized job reason value %s",
+						      name);
+					xfree(name);
+					name = xstrdup_printf("%u", c);
+
+					while ((tmp_char = list_next(itr))) {
+						if (!xstrcasecmp(tmp_char,
+								 name))
+							break;
+					}
+
+					if (!tmp_char) {
+						list_append(char_list, name);
+						count++;
+					} else
+						xfree(name);
+					list_iterator_reset(itr);
+				}
+				i++;
+				start = i;
+				if (!names[i]) {
+					info("There is a problem with "
+					     "your request.  It appears you "
+					     "have spaces inside your list.");
+					break;
+				}
+			}
+			i++;
+		}
+		if ((i-start) > 0) {
+			name = xmalloc((i-start)+1);
+			memcpy(name, names+start, (i-start));
+			c = job_reason_num(name);
+			if (c == NO_VAL)
+				fatal("unrecognized job reason value '%s'",
+				      name);
+			xfree(name);
+			name = xstrdup_printf("%u", c);
+
+			while ((tmp_char = list_next(itr))) {
+				if (!xstrcasecmp(tmp_char, name))
+					break;
+			}
+
+			if (!tmp_char) {
+				list_append(char_list, name);
+				count++;
+			} else
+				xfree(name);
+		}
+	}
+	list_iterator_destroy(itr);
+	return count;
+}
+
+static bool _supported_state(uint32_t state_num)
+{
+	/* Not all state and state flags are accounted */
+	switch(state_num) {
+	case JOB_PENDING:
+	case JOB_RUNNING:
+	case JOB_SUSPENDED:
+	case JOB_COMPLETE:
+	case JOB_CANCELLED:
+	case JOB_FAILED:
+	case JOB_TIMEOUT:
+	case JOB_NODE_FAIL:
+	case JOB_PREEMPTED:
+	case JOB_BOOT_FAIL:
+	case JOB_DEADLINE:
+	case JOB_OOM:
+	case JOB_REQUEUE:
+	case JOB_RESIZING:
+	case JOB_REVOKED:
+		return true;
+		break;
+	default:
+		return false;
+		break;
+	}
+}
+
+/* returns number of objects added to list */
+/* also checks if states are supported by sacct and fatals if not */
 static int _addto_state_char_list(List char_list, char *names)
 {
 	int i = 0, start = 0;
@@ -243,6 +362,8 @@ static int _addto_state_char_list(List char_list, char *names)
 					c = job_state_num(name);
 					if (c == NO_VAL)
 						fatal("unrecognized job state value %s", name);
+					if (!_supported_state(c))
+						fatal("job state %s is not supported / accounted", name);
 					xfree(name);
 					name = xstrdup_printf("%d", c);
 
@@ -277,6 +398,8 @@ static int _addto_state_char_list(List char_list, char *names)
 			if (c == NO_VAL)
 				fatal("unrecognized job state value '%s'",
 				      name);
+			if (!_supported_state(c))
+				fatal("job state %s is not supported / accounted", name);
 			xfree(name);
 			name = xstrdup_printf("%d", c);
 
@@ -455,6 +578,7 @@ static void _init_params(void)
 {
 	memset(&params, 0, sizeof(sacct_parameters_t));
 	params.job_cond = xmalloc(sizeof(slurmdb_job_cond_t));
+	params.job_cond->db_flags = SLURMDB_JOB_FLAG_NOTSET;
 	params.job_cond->flags |= JOBCOND_FLAG_NO_TRUNC;
 	params.convert_flags = CONVERT_NUM_UNIT_EXACT;
 	params.units = NO_VAL;
@@ -470,6 +594,21 @@ static int _sort_desc_submit_time(void *x, void *y)
 	else if (j1->submit > j2->submit)
 		return 1;
 
+	if (j1->array_job_id < j2->array_job_id)
+		return -1;
+	else if (j1->array_job_id > j2->array_job_id)
+		return 1;
+
+	if (j1->array_task_id < j2->array_task_id)
+		return -1;
+	else if (j1->array_task_id > j2->array_task_id)
+		return 1;
+
+	if (j1->jobid < j2->jobid)
+		return -1;
+	else if (j1->jobid > j2->jobid)
+		return 1;
+
 	return 0;
 }
 
@@ -578,9 +717,13 @@ extern int get_data(void)
 	 * one cluster but not when jobs for multiple clusters are requested.
 	 * Remove the current job if there were jobs with the same id submitted
 	 * in the future.
+	 * Else sort the jobs to order the jobs so the last task of arrays don't
+	 * appear to run before any of the other tasks.
 	 */
 	if (params.cluster_name && !(job_cond->flags & JOBCOND_FLAG_DUP))
 		_remove_duplicate_fed_jobs(jobs);
+	else
+		list_sort(jobs, _sort_desc_submit_time);
 
 	itr = list_iterator_create(jobs);
 	while ((job = list_next(itr))) {
@@ -595,7 +738,7 @@ extern int get_data(void)
 			continue;
 
 		itr_step = list_iterator_create(job->steps);
-		while ((step = list_next(itr_step)) != NULL) {
+		while ((step = list_next(itr_step))) {
 			/* now aggregate the aggregatable */
 
 			if (step->state < JOB_COMPLETE)
@@ -656,6 +799,7 @@ extern void parse_command_line(int argc, char **argv)
                 {"allocations",    no_argument,       0,    'X'},
                 {"brief",          no_argument,       0,    'b'},
                 {"completion",     no_argument,       0,    'c'},
+                {"constraints",    required_argument, 0,    'C'},
                 {"delimiter",      required_argument, 0,    OPT_LONG_DELIMITER},
                 {"duplicates",     no_argument,       0,    'D'},
                 {"federation",     no_argument,       0,    OPT_LONG_FEDR},
@@ -663,6 +807,7 @@ extern void parse_command_line(int argc, char **argv)
                 {"help-fields",    no_argument,       0,    'e'},
                 {"endtime",        required_argument, 0,    'E'},
                 {"file",           required_argument, 0,    'f'},
+                {"flags",          required_argument, 0,    'F'},
                 {"gid",            required_argument, 0,    'g'},
                 {"group",          required_argument, 0,    'g'},
                 {"help",           no_argument,       0,    'h'},
@@ -687,6 +832,7 @@ extern void parse_command_line(int argc, char **argv)
                 {"parsable2",      no_argument,       0,    'P'},
                 {"qos",            required_argument, 0,    'q'},
                 {"partition",      required_argument, 0,    'r'},
+                {"reason",         required_argument, 0,    'R'},
                 {"state",          required_argument, 0,    's'},
                 {"starttime",      required_argument, 0,    'S'},
                 {"truncate",       no_argument,       0,    'T'},
@@ -718,7 +864,7 @@ extern void parse_command_line(int argc, char **argv)
 
 	while (1) {		/* now cycle through the command line */
 		c = getopt_long(argc, argv,
-				"aA:bcC:DeE:f:g:hi:I:j:k:K:lLM:nN:o:pPq:r:s:S:Ttu:UvVW:x:X",
+				"aA:bcC:DeE:f:F:g:hi:I:j:k:K:lLM:nN:o:pPq:r:s:S:Ttu:UvVW:x:X",
 				long_options, &optionIndex);
 		if (c == -1)
 			break;
@@ -742,9 +888,12 @@ extern void parse_command_line(int argc, char **argv)
 			fields_delimiter = optarg;
 			break;
 		case 'C':
-			/* 'C' is deprecated since 'M' is cluster on
-			   everything else.
-			*/
+			if (!job_cond->constraint_list)
+				job_cond->constraint_list =
+					list_create(slurm_destroy_char);
+			slurm_addto_char_list(job_cond->constraint_list,
+					      optarg);
+			break;
 		case 'M':
 			if (!xstrcasecmp(optarg, "all") ||
 			    !xstrcasecmp(optarg, "-1")) {	/* vestigial */
@@ -773,6 +922,11 @@ extern void parse_command_line(int argc, char **argv)
 			xfree(params.opt_filein);
 			params.opt_filein = xstrdup(optarg);
 			break;
+		case 'F':
+			job_cond->db_flags = str_2_job_flags(optarg);
+			if (job_cond->db_flags == SLURMDB_JOB_FLAG_NOTSET)
+				exit(1);
+			break;
 		case 'g':
 			if (!job_cond->groupid_list)
 				job_cond->groupid_list =
@@ -909,6 +1063,13 @@ extern void parse_command_line(int argc, char **argv)
 			slurm_addto_char_list(job_cond->partition_list,
 					      optarg);
 			break;
+		case 'R':
+			if (!job_cond->reason_list)
+				job_cond->reason_list =
+					list_create(slurm_destroy_char);
+
+			_addto_reason_char_list(job_cond->reason_list, optarg);
+			break;
 		case 's':
 			if (!job_cond->state_list)
 				job_cond->state_list =
@@ -982,6 +1143,9 @@ extern void parse_command_line(int argc, char **argv)
 		}
 	}
 
+	if (long_output && params.opt_field_list)
+		fatal("Options -o(--format) and -l(--long) are mutually exclusive. Please remove one and retry.");
+
 	if (verbosity) {
 		opts.stderr_level += verbosity;
 		opts.prefix_level = 1;
