@@ -7,11 +7,11 @@
  *  Written by Danny Auble <da@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -67,7 +67,6 @@
 
 #define CKPT_WAIT	10
 #define	MAX_INPUT_FIELDS 128
-#define BUFFER_SIZE 4096
 #define FORMAT_STRING_SIZE 34
 
 typedef enum {
@@ -95,6 +94,7 @@ typedef enum {
 	PRINT_GRPTRM,
 	PRINT_GRPT,
 	PRINT_GRPJ,
+	PRINT_GRPJA,
 	PRINT_GRPMEM,
 	PRINT_GRPN,
 	PRINT_GRPS,
@@ -112,12 +112,16 @@ typedef enum {
 	PRINT_MAXTU,
 	PRINT_MAXJ,
 	PRINT_MAXJA,
+	PRINT_MAXJAA,
+	PRINT_MAXJAU,
+	PRINT_MAXJPA,
 	PRINT_MAXN,
 	PRINT_MAXNU,
 	PRINT_MAXS,
 	PRINT_MAXSA,
 	PRINT_MAXW,
 	PRINT_MINC,
+	PRINT_MINPT,
 	PRINT_MINT,
 
 	/* ASSOCIATION */
@@ -155,6 +159,7 @@ typedef enum {
 	PRINT_PREE,
 	PRINT_PREEM,
 	PRINT_PRIO,
+	PRINT_PRXMPT,
 	PRINT_UF,
 	PRINT_UT,
 
@@ -179,6 +184,8 @@ typedef enum {
 	PRINT_TIMESTART,
 	PRINT_STATERAW,
 	PRINT_STATE,
+	PRINT_TIMESUBMIT,
+	PRINT_TIMEELIGIBLE,
 
 	/* RESOURCE */
 	PRINT_COUNT = 9000,
@@ -212,6 +219,7 @@ extern List g_qos_list;
 extern List g_res_list;
 extern List g_tres_list;
 
+extern bool user_case_norm;
 extern bool tree_display;
 
 extern bool sacctmgr_check_default_qos(uint32_t qos_id,
