@@ -7,11 +7,11 @@
  *  Written by Morris Jette <jette1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,16 +27,17 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 #include <arpa/inet.h>
+#include <grp.h>
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -45,7 +46,6 @@
 #include "src/common/bitstring.h"
 #include "src/common/slurm_time.h"
 #include "src/common/stepd_api.h"
-#include "src/plugins/select/bluegene/bg_enums.h"
 
 #define POLL_SLEEP	3	/* retry interval in seconds  */
 
@@ -61,11 +61,8 @@ scontrol_load_job(job_info_msg_t ** job_buffer_pptr, uint32_t job_id)
 	if (all_flag)
 		show_flags |= SHOW_ALL;
 
-	if (detail_flag) {
+	if (detail_flag)
 		show_flags |= SHOW_DETAIL;
-		if (detail_flag > 1)
-			show_flags |= SHOW_DETAIL2;
-	}
 	if (federation_flag)
 		show_flags |= SHOW_FEDERATION;
 	if (local_flag)
@@ -199,6 +196,8 @@ scontrol_print_completing_job(job_info_t *job_ptr,
 	node_info_t *node_info;
 	hostlist_t comp_nodes, down_nodes;
 	char *node_buf;
+	char time_str[32];
+	time_t completing_time = 0;
 
 	comp_nodes = hostlist_create(NULL);
 	down_nodes = hostlist_create(NULL);
@@ -223,6 +222,13 @@ scontrol_print_completing_job(job_info_t *job_ptr,
 
 	fprintf(stdout, "JobId=%u ", job_ptr->job_id);
 
+	slurm_make_time_str(&job_ptr->end_time, time_str, sizeof(time_str));
+	fprintf(stdout, "EndTime=%s ", time_str);
+
+	completing_time = time(NULL) - job_ptr->end_time;
+	secs2time_str(completing_time, time_str, sizeof(time_str));
+	fprintf(stdout, "CompletingTime=%s ", time_str);
+
 	node_buf = hostlist_ranged_string_xmalloc(comp_nodes);
 	if (node_buf && node_buf[0])
 		fprintf(stdout, "Nodes(COMPLETING)=%s ", node_buf);
@@ -643,7 +649,7 @@ _list_pids_all_steps(const char *node_name, uint32_t jobid)
 	}
 
 	itr = list_iterator_create(steps);
-	while((stepd = list_next(itr))) {
+	while ((stepd = list_next(itr))) {
 		if (jobid == stepd->jobid) {
 			_list_pids_one_step(stepd->nodename, stepd->jobid,
 					    stepd->stepid);
@@ -720,6 +726,72 @@ scontrol_list_pids(const char *jobid_str, const char *node_name)
 	}
 }
 
+extern void scontrol_getent(const char *node_name)
+{
+	List steps = NULL;
+	ListIterator itr = NULL;
+	step_loc_t *stepd;
+	int fd;
+	struct passwd *pwd = NULL;
+	struct group **grps = NULL;
+
+	if (!(steps = stepd_available(NULL, node_name))) {
+		fprintf(stderr, "No steps found on this node\n");
+		return;
+	}
+
+	itr = list_iterator_create(steps);
+	while ((stepd = list_next(itr))) {
+		fd = stepd_connect(NULL, node_name, stepd->jobid,
+				   stepd->stepid,
+				   &stepd->protocol_version);
+
+		if (fd < 0)
+			continue;
+		pwd = stepd_getpw(fd, stepd->protocol_version,
+				  GETPW_MATCH_ALWAYS, 0, NULL);
+
+		if (!pwd) {
+			close(fd);
+			continue;
+		}
+
+		if (stepd->stepid == SLURM_EXTERN_CONT)
+			printf("JobId=%u.Extern:\nUser:\n", stepd->jobid);
+		else if (stepd->stepid == SLURM_BATCH_SCRIPT)
+			printf("JobId=%u.Batch:\nUser:\n", stepd->jobid);
+		else
+			printf("JobId=%u.%u:\nUser:\n",
+			       stepd->jobid, stepd->stepid);
+
+		printf("%s:%s:%u:%u:%s:%s:%s\nGroups:\n",
+		       pwd->pw_name, pwd->pw_passwd, pwd->pw_uid, pwd->pw_gid,
+		       pwd->pw_gecos, pwd->pw_dir, pwd->pw_shell);
+
+		xfree_struct_passwd(pwd);
+
+		grps = stepd_getgr(fd, stepd->protocol_version,
+				   GETGR_MATCH_ALWAYS, 0, NULL);
+		if (!grps) {
+			close(fd);
+			printf("\n");
+			continue;
+		}
+
+		for (int i = 0; grps[i]; i++) {
+			printf("%s:%s:%u:%s\n",
+			       grps[i]->gr_name, grps[i]->gr_passwd,
+			       grps[i]->gr_gid,
+			       (grps[i]->gr_mem) ? grps[i]->gr_mem[0] : "");
+		}
+		close(fd);
+		xfree_struct_group_array(grps);
+		printf("\n");
+	}
+	list_iterator_destroy(itr);
+	FREE_NULL_LIST(steps);
+}
+
 /*
  * scontrol_print_hosts - given a node list expression, return
  *	a list of nodes, one per line
@@ -820,100 +892,6 @@ scontrol_encode_hostlist(char *hostlist, bool sorted)
 	return SLURM_SUCCESS;
 }
 
-/*
- * Test if any BG blocks are in deallocating state since they are
- * probably related to this job we will want to sleep longer
- * RET	1:  deallocate in progress
- *	0:  no deallocate in progress
- *     -1: error occurred
- */
-static int _blocks_dealloc(void)
-{
-	static block_info_msg_t *bg_info_ptr = NULL, *new_bg_ptr = NULL;
-	int rc = 0, error_code = 0, i;
-	uint16_t show_flags = 0;
-
-	if (all_flag)
-		show_flags |= SHOW_ALL;
-	if (bg_info_ptr) {
-		error_code = slurm_load_block_info(bg_info_ptr->last_update,
-						   &new_bg_ptr, show_flags);
-		if (error_code == SLURM_SUCCESS)
-			slurm_free_block_info_msg(bg_info_ptr);
-		else if (slurm_get_errno() == SLURM_NO_CHANGE_IN_DATA) {
-			error_code = SLURM_SUCCESS;
-			new_bg_ptr = bg_info_ptr;
-		}
-	} else {
-		error_code = slurm_load_block_info((time_t) NULL,
-						   &new_bg_ptr, show_flags);
-	}
-
-	if (error_code) {
-		error("slurm_load_block_info: %s",
-		      slurm_strerror(slurm_get_errno()));
-		return -1;
-	}
-	for (i=0; i<new_bg_ptr->record_count; i++) {
-		if (new_bg_ptr->block_array[i].state == BG_BLOCK_TERM) {
-			rc = 1;
-			break;
-		}
-	}
-	bg_info_ptr = new_bg_ptr;
-	return rc;
-}
-
-static int _wait_bluegene_block_ready(resource_allocation_response_msg_t *alloc)
-{
-	int is_ready = SLURM_ERROR, i, rc = 0;
-	char *block_id = NULL;
-	int cur_delay = 0;
-	int max_delay = BG_FREE_PREVIOUS_BLOCK + BG_MIN_BLOCK_BOOT +
-		(BG_INCR_BLOCK_BOOT * alloc->node_cnt);
-
-	select_g_select_jobinfo_get(alloc->select_jobinfo,
-				    SELECT_JOBDATA_BLOCK_ID,
-				    &block_id);
-
-	for (i=0; (cur_delay < max_delay); i++) {
-		if (i) {
-			if (i == 1) {
-				info("Waiting for block %s to become ready for "
-				     "job", block_id);
-			} else
-				debug("still waiting");
-			sleep(POLL_SLEEP);
-			rc = _blocks_dealloc();
-			if ((rc == 0) || (rc == -1))
-				cur_delay += POLL_SLEEP;
-		}
-
-		rc = slurm_job_node_ready(alloc->job_id);
-
-		if (rc == READY_JOB_FATAL)
-			break;				/* fatal error */
-		if ((rc == READY_JOB_ERROR) || (rc == EAGAIN))
-			continue;			/* retry */
-		if ((rc & READY_JOB_STATE) == 0)	/* job killed */
-			break;
-		if (rc & READY_NODE_STATE) {		/* job and node ready */
-			is_ready = SLURM_SUCCESS;
-			break;
-		}
-	}
-
-	if (is_ready == SLURM_SUCCESS)
-     		info("Block %s is ready for job %u", block_id, alloc->job_id);
-	else if ((rc & READY_JOB_STATE) == 0)
-		info("Job %u no longer running", alloc->job_id);
-	else
-		info("Problem running job %u", alloc->job_id);
-	xfree(block_id);
-
-	return is_ready;
-}
-
 static int _wait_nodes_ready(uint32_t job_id)
 {
 	int is_ready = SLURM_ERROR, i, rc = 0;
@@ -965,7 +943,6 @@ static int _wait_nodes_ready(uint32_t job_id)
  */
 extern int scontrol_job_ready(char *job_id_str)
 {
-	int rc;
 	uint32_t job_id;
 
 	job_id = atoi(job_id_str);
@@ -974,20 +951,7 @@ extern int scontrol_job_ready(char *job_id_str)
 		return SLURM_ERROR;
 	}
 
-	if (cluster_flags & CLUSTER_FLAG_BG) {
-		resource_allocation_response_msg_t *alloc;
-		rc = slurm_allocation_lookup(job_id, &alloc);
-		if (rc == SLURM_SUCCESS) {
-			rc = _wait_bluegene_block_ready(alloc);
-			slurm_free_resource_allocation_response_msg(alloc);
-		} else {
-			error("slurm_allocation_lookup: %m");
-			rc = SLURM_ERROR;
-		}
-	} else
-		rc = _wait_nodes_ready(job_id);
-
-	return rc;
+	return _wait_nodes_ready(job_id);
 }
 
 extern int scontrol_callerid(int argc, char **argv)
@@ -1045,11 +1009,11 @@ extern int scontrol_callerid(int argc, char **argv)
 			!= SLURM_SUCCESS) {
 		fprintf(stderr,
 			"slurm_network_callerid: unable to retrieve callerid data from remote slurmd\n");
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	} else if (job_id == NO_VAL) {
 		fprintf(stderr,
 			"slurm_network_callerid: remote job id indeterminate\n");
-		return SLURM_FAILURE;
+		return SLURM_ERROR;
 	} else {
 		printf("%u %s\n", job_id, node_name);
 		return SLURM_SUCCESS;
@@ -1073,22 +1037,31 @@ extern int scontrol_batch_script(int argc, char **argv)
 	else
 		filename = xstrdup_printf("slurm-%u.sh", jobid);
 
-	if (!(out = fopen(filename, "w"))) {
-		fprintf(stderr, "failed to open file `%s`: %m\n", filename);
-		xfree(filename);
-		return errno;
+	if (!xstrcmp(filename, "-")) {
+		out = stdout;
+	} else {
+		if (!(out = fopen(filename, "w"))) {
+			fprintf(stderr, "failed to open file `%s`: %m\n",
+				filename);
+			xfree(filename);
+			return errno;
+		}
 	}
 
 	exit_code = slurm_job_batch_script(out, jobid);
-	fclose(out);
+
+	if (out != stdout)
+		fclose(out);
+
 	if (exit_code != SLURM_SUCCESS) {
-		unlink(filename);
+		if (out != stdout)
+			unlink(filename);
 		slurm_perror("job script retrieval failed");
-	} else if (quiet_flag != 1) {
+	} else if ((out != stdout) && (quiet_flag != 1)) {
 		printf("batch script for job %u written to %s\n",
 		       jobid, filename);
 	}
-	xfree(filename);
 
+	xfree(filename);
 	return exit_code;
 }
