@@ -41,7 +41,6 @@
 
 /* needed for getgrent_r */
 #define _GNU_SOURCE
-#define   __USE_GNU
 
 #include <grp.h>
 #include <pthread.h>
@@ -260,7 +259,7 @@ static uid_t *_get_group_cache(char *group_name)
 		if (xstrcmp(group_name, cache_rec->group_name))
 			continue;
 		sz = sizeof(uid_t) * (cache_rec->uid_cnt + 1);
-		group_uids = (uid_t *) xmalloc(sz);
+		group_uids = xmalloc(sz);
 		memcpy(group_uids, cache_rec->group_uids, sz);
 		break;
 	}
@@ -295,7 +294,7 @@ static void _put_group_cache(char *group_name, void *group_uids, int uid_cnt)
 	cache_rec = xmalloc(sizeof(struct group_cache_rec));
 	cache_rec->group_name = xstrdup(group_name);
 	cache_rec->uid_cnt    = uid_cnt;
-	cache_rec->group_uids = (uid_t *) xmalloc(sizeof(uid_t) + sz);
+	cache_rec->group_uids = xmalloc(sizeof(uid_t) + sz);
 	if (uid_cnt > 0)
 		memcpy(cache_rec->group_uids, group_uids, sz);
 	list_append(group_cache_list, cache_rec);
