@@ -87,7 +87,7 @@ static bool init_run = false;
 extern int job_submit_plugin_init(void)
 {
 	int rc = SLURM_SUCCESS;
-	char *last = NULL, *names;
+	char *last = NULL, *tmp_plugin_list, *names;
 	char *plugin_type = "job_submit";
 	char *type;
 
@@ -103,12 +103,12 @@ extern int job_submit_plugin_init(void)
 	if ((submit_plugin_list == NULL) || (submit_plugin_list[0] == '\0'))
 		goto fini;
 
-	names = submit_plugin_list;
+	tmp_plugin_list = xstrdup(submit_plugin_list);
+	names = tmp_plugin_list;
 	while ((type = strtok_r(names, ",", &last))) {
-		xrealloc(ops,
-			 (sizeof(slurm_submit_ops_t) * (g_context_cnt + 1)));
-		xrealloc(g_context,
-			 (sizeof(plugin_context_t *) * (g_context_cnt + 1)));
+		xrecalloc(ops, g_context_cnt + 1, sizeof(slurm_submit_ops_t));
+		xrecalloc(g_context, g_context_cnt + 1,
+			  sizeof(plugin_context_t *));
 		if (xstrncmp(type, "job_submit/", 11) == 0)
 			type += 11; /* backward compatibility */
 		type = xstrdup_printf("job_submit/%s", type);
@@ -128,6 +128,7 @@ extern int job_submit_plugin_init(void)
 		names = NULL; /* for next strtok_r() iteration */
 	}
 	init_run = true;
+	xfree(tmp_plugin_list);
 
 fini:
 	slurm_mutex_unlock(&g_context_lock);
@@ -187,8 +188,7 @@ extern int job_submit_plugin_reconfig(void)
 		return rc;
 
 	slurm_mutex_lock(&g_context_lock);
-	if (plugin_names && submit_plugin_list &&
-	    xstrcmp(plugin_names, submit_plugin_list))
+	if (xstrcmp(plugin_names, submit_plugin_list))
 		plugin_change = true;
 	else
 		plugin_change = false;
@@ -225,6 +225,10 @@ extern int job_submit_plugin_submit(struct job_descriptor *job_desc,
 	xassert(verify_lock(PART_LOCK, READ_LOCK));
 
 	START_TIMER;
+
+	/* Set to NO_VAL so that it can only be set by the job submit plugin. */
+	job_desc->site_factor = NO_VAL;
+
 	rc = job_submit_plugin_init();
 	slurm_mutex_lock(&g_context_lock);
 	/* NOTE: On function entry read locks are set on config, job, node and
@@ -257,6 +261,10 @@ extern int job_submit_plugin_modify(struct job_descriptor *job_desc,
 	xassert(verify_lock(PART_LOCK, READ_LOCK));
 
 	START_TIMER;
+
+	/* Set to NO_VAL so that it can only be set by the job submit plugin. */
+	job_desc->site_factor = NO_VAL;
+
 	rc = job_submit_plugin_init();
 	slurm_mutex_lock(&g_context_lock);
 	for (i = 0; ((i < g_context_cnt) && (rc == SLURM_SUCCESS)); i++)
