@@ -6,11 +6,11 @@
  *  Written by Morris Jette <jette@llnl.gov>, Randy Sanchez <rsancez@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -102,24 +102,15 @@ typedef enum {
 
 /* slurmctld specific data structures to lock via APIs */
 typedef struct {
-	lock_level_t	config;
-	lock_level_t	job;
-	lock_level_t	node;
-	lock_level_t	partition;
-	lock_level_t	federation;
+	lock_level_t conf;
+	lock_level_t job;
+	lock_level_t node;
+	lock_level_t part;
+	lock_level_t fed;
 }	slurmctld_lock_t;
 
-/* Interval lock structure
- * we actually use the count for each data type, see macros below
- *	(lock_datatype_t * 4 + 0) = read_lock		read locks in use
- *	(lock_datatype_t * 4 + 1) = write_lock		write locks in use
- *	(lock_datatype_t * 4 + 2) = write_wait_lock	write locks pending
- *	(lock_datatype_t * 4 + 3) = write_cnt_lock	write lock count
- * NOTE: If changing the number of functions (array size), then also change
- * the size of "entity" in src/common/assoc_mgr.h
- */
 typedef enum {
-	CONFIG_LOCK,
+	CONF_LOCK,
 	JOB_LOCK,
 	NODE_LOCK,
 	PART_LOCK,
@@ -131,20 +122,6 @@ typedef enum {
 extern bool verify_lock(lock_datatype_t datatype, lock_level_t level);
 #endif
 
-#define read_lock(data_type)		(data_type * 4 + 0)
-#define write_lock(data_type)		(data_type * 4 + 1)
-#define write_wait_lock(data_type)	(data_type * 4 + 2)
-#define write_cnt_lock(data_type)	(data_type * 4 + 3)
-
-typedef struct {
-	int entity[ENTITY_COUNT * 4];
-}	slurmctld_lock_flags_t;
-
-
-/* get_lock_values - Get the current value of all locks
- * OUT lock_flags - a copy of the current lock values */
-extern void get_lock_values (slurmctld_lock_flags_t *lock_flags);
-
 /* init_locks - create locks used for slurmctld data structure access
  *	control */
 extern void init_locks ( void );
@@ -156,6 +133,8 @@ extern void lock_slurmctld (slurmctld_lock_t lock_levels);
  *	defined order */
 extern void unlock_slurmctld (slurmctld_lock_t lock_levels);
 
+extern int report_locks_set(void);
+
 /* un/lock semaphore used for saving state of slurmctld */
 extern void lock_state_files ( void );
 extern void unlock_state_files ( void );
