@@ -82,7 +82,7 @@ List part_list = NULL;			/* partition list */
 char *default_part_name = NULL;		/* name of default partition */
 struct part_record *default_part_loc = NULL; /* default partition location */
 time_t last_part_update = (time_t) 0;	/* time of last update to partition records */
-uint16_t part_max_priority = 0;         /* max priority_job_factor in all parts */
+uint16_t part_max_priority = DEF_PART_MAX_PRIORITY;
 
 static int    _delete_part_record(char *name);
 static int    _dump_part_state(void *x, void *arg);
@@ -1570,7 +1570,7 @@ extern int update_part(update_part_msg_t * part_desc, bool create_flag)
 			struct part_record *part2 = NULL;
 
 			if (redo_prio == 2) {
-				part_max_priority = 1;
+				part_max_priority = DEF_PART_MAX_PRIORITY;
 				while ((part2 = list_next(itr))) {
 					if (part2->priority_job_factor >
 					    part_max_priority)
