@@ -60,6 +60,13 @@ extern void free_rpc_stats(void);
  */
 void slurmctld_req(slurm_msg_t * msg, connection_arg_t *);
 
+/*
+ * Initialize a response slurm_msg_t to an inbound msg,
+ * first by calling slurm_msg_t_init(), then by copying
+ * fields needed to communicate with the remote correctly.
+ */
+extern void response_init(slurm_msg_t *resp, slurm_msg_t *msg);
+
 /*
  * slurm_drain_nodes - process a request to drain a list of nodes,
  *	no-op for nodes already drained or draining
