@@ -82,6 +82,7 @@ extern void pack_slurmd_conf_lite(slurmd_conf_t *conf, Buf buffer)
 	pack64(conf->msg_aggr_window_msgs, buffer);
 	packstr(conf->tmpfs, buffer);
 	packstr(conf->x11_params, buffer);
+	packstr(conf->gres, buffer);
 }
 
 extern int unpack_slurmd_conf_lite_no_alloc(slurmd_conf_t *conf, Buf buffer)
@@ -133,6 +134,7 @@ extern int unpack_slurmd_conf_lite_no_alloc(slurmd_conf_t *conf, Buf buffer)
 		safe_unpack64(&conf->msg_aggr_window_msgs, buffer);
 		safe_unpackstr_xmalloc(&conf->tmpfs, &uint32_tmp, buffer);
 		safe_unpackstr_xmalloc(&conf->x11_params, &uint32_tmp, buffer);
+		safe_unpackstr_xmalloc(&conf->gres, &uint32_tmp, buffer);
 	}
 
 	return SLURM_SUCCESS;
@@ -151,5 +153,6 @@ unpack_error:
 	xfree(conf->node_topo_pattern);
 	xfree(conf->tmpfs);
 	xfree(conf->x11_params);
+	xfree(conf->gres);
 	return SLURM_ERROR;
 }
