@@ -4,11 +4,11 @@
  *  Copyright (C) 2009 CEA/DAM/DIF
  *  Written by Matthieu Hautreux <matthieu.hautreux@cea.fr>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -24,13 +24,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -80,17 +80,23 @@ int _file_write_content(char* file_path, char* content, size_t csize);
  *  - XCGROUP_ERROR
  *  - XCGROUP_SUCCESS
  */
-int xcgroup_ns_create(slurm_cgroup_conf_t *conf,
-		      xcgroup_ns_t *cgns, char *mnt_args, char *subsys) {
+int xcgroup_ns_create(xcgroup_ns_t *cgns, char *mnt_args, char *subsys)
+{
+	slurm_cgroup_conf_t *cg_conf;
+
+	/* read cgroup configuration */
+	slurm_mutex_lock(&xcgroup_config_read_mutex);
+	cg_conf = xcgroup_get_slurm_cgroup_conf();
 
 	cgns->mnt_point = xstrdup_printf("%s/%s",
-					 conf->cgroup_mountpoint, subsys);
+					 cg_conf->cgroup_mountpoint,
+					 subsys);
 	cgns->mnt_args = xstrdup(mnt_args);
 	cgns->subsystems = xstrdup(subsys);
 
 	/* check that freezer cgroup namespace is available */
 	if (!xcgroup_ns_is_available(cgns)) {
-		if (conf->cgroup_automount) {
+		if (cg_conf->cgroup_automount) {
 			if (xcgroup_ns_mount(cgns)) {
 				error("unable to mount %s cgroup "
 				      "namespace: %s",
@@ -105,8 +111,10 @@ int xcgroup_ns_create(slurm_cgroup_conf_t *conf,
 		}
 	}
 
+	slurm_mutex_unlock(&xcgroup_config_read_mutex);
 	return XCGROUP_SUCCESS;
 clean:
+	slurm_mutex_unlock(&xcgroup_config_read_mutex);
 	xcgroup_ns_destroy(cgns);
 	return XCGROUP_ERROR;
 }
@@ -192,7 +200,7 @@ int xcgroup_ns_mount(xcgroup_ns_t* cgns)
 		options = opt_combined;
 	}
 
-#if defined(__FreeBSD__)
+#if defined(__APPLE__) || defined(__FreeBSD__)
 	if (mount("cgroup", cgns->mnt_point,
 		  MS_NOSUID|MS_NOEXEC|MS_NODEV, options))
 #else
@@ -315,10 +323,19 @@ int xcgroup_ns_find_by_pid(xcgroup_ns_t* cgns, xcgroup_t* cg, pid_t pid)
 	return fstatus;
 }
 
-int xcgroup_ns_load(slurm_cgroup_conf_t *conf, xcgroup_ns_t *cgns, char *subsys)
+int xcgroup_ns_load(xcgroup_ns_t *cgns, char *subsys)
 {
+	slurm_cgroup_conf_t *cg_conf;
+
+	/* read cgroup configuration */
+	slurm_mutex_lock(&xcgroup_config_read_mutex);
+	cg_conf = xcgroup_get_slurm_cgroup_conf();
+
 	cgns->mnt_point = xstrdup_printf("%s/%s",
-					 conf->cgroup_mountpoint, subsys);
+					 cg_conf->cgroup_mountpoint,
+					 subsys);
+	slurm_mutex_unlock(&xcgroup_config_read_mutex);
+
 	cgns->mnt_args = NULL;
 	cgns->subsystems = xstrdup(subsys);
 	return XCGROUP_SUCCESS;
@@ -898,7 +915,7 @@ int _file_read_uint64s(char* file_path, uint64_t** pvalues, int* pnb)
 	}
 
 	/* read file contents */
-	buf = (char*) xmalloc((fsize+1)*sizeof(char));
+	buf = xmalloc(fsize + 1);
 	do {
 		rc = read(fd, buf, fsize);
 	} while (rc < 0 && errno == EINTR);
@@ -1020,7 +1037,7 @@ int _file_read_uint32s(char* file_path, uint32_t** pvalues, int* pnb)
 	}
 
 	/* read file contents */
-	buf = (char*) xmalloc((fsize+1)*sizeof(char));
+	buf = xmalloc(fsize + 1);
 	do {
 		rc = read(fd, buf, fsize);
 	} while (rc < 0 && errno == EINTR);
@@ -1122,7 +1139,7 @@ int _file_read_content(char* file_path, char** content, size_t *csize)
 	}
 
 	/* read file contents */
-	buf = xmalloc((fsize+1)*sizeof(char));
+	buf = xmalloc(fsize + 1);
 	buf[fsize]='\0';
 	do {
 		rc = read(fd, buf, fsize);
