@@ -241,7 +241,7 @@ handle_write:
 	if (hwloc_topology_load(*topology)) {
 		/* error in load hardware topology */
 		debug("hwloc_topology_load() failed.");
-		ret = SLURM_FAILURE;
+		ret = SLURM_ERROR;
 	} else if (!conf->def_config) {
 		debug2("hwloc_topology_export_xml");
 		if (_internal_hwloc_topology_export_xml(*topology, topo_file)) {
@@ -299,8 +299,9 @@ extern int xcpuinfo_hwloc_topo_get(
 		hwloc_xml_whole = xstrdup_printf("%s/hwloc_topo_whole.xml",
 						 conf->spooldir);
 	if (xcpuinfo_hwloc_topo_load(&topology, hwloc_xml_whole, true)
-	    == SLURM_FAILURE) {
+	    == SLURM_ERROR) {
 		hwloc_topology_destroy(topology);
+		xfree(hwloc_xml_whole);
 		return 2;
 	}
 #if _DEBUG
@@ -323,8 +324,7 @@ extern int xcpuinfo_hwloc_topo_get(
 	if (hwloc_get_type_depth(topology, HWLOC_OBJ_NODE) >
 	    hwloc_get_type_depth(topology, HWLOC_OBJ_SOCKET)) {
 		char *sched_params = slurm_get_sched_params();
-		if (sched_params &&
-		    strcasestr(sched_params, "Ignore_NUMA")) {
+		if (xstrcasestr(sched_params, "Ignore_NUMA")) {
 			info("Ignoring NUMA nodes within a socket");
 		} else {
 			info("Considering each NUMA node as a socket");
