@@ -4,11 +4,11 @@
  *  Copyright (C) 2009 CEA/DAM/DIF
  *  Written by Matthieu Hautreux <matthieu.hautreux@cea.fr>
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -24,13 +24,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -42,6 +42,10 @@
 
 extern int get_procs(uint16_t *procs);
 
+/* read or load topology and write if needed
+ * init and destroy topology must be outside this function */
+extern int xcpuinfo_hwloc_topo_load(
+	void *topology_in, char *topo_file, bool full);
 /*
  * Get the node's cpu info.
  *
@@ -56,10 +60,11 @@ extern int get_procs(uint16_t *procs);
  *
  * RET SLURM_SUCCESS on success and 1 or 2 on failure.
  */
-extern int get_cpuinfo(uint16_t *cpus, uint16_t *boards,
-		       uint16_t *sockets, uint16_t *cores, uint16_t *threads,
-		       uint16_t *block_map_size,
-		       uint16_t **block_map, uint16_t **block_map_inv);
+extern int xcpuinfo_hwloc_topo_get(
+	uint16_t *cpus, uint16_t *boards,
+	uint16_t *sockets, uint16_t *cores, uint16_t *threads,
+	uint16_t *block_map_size,
+	uint16_t **block_map, uint16_t **block_map_inv);
 
 /*
  * Initialize xcpuinfo internal data
