@@ -9,11 +9,11 @@
  *  Written by Morris Jette <jette1@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -29,13 +29,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -49,13 +49,6 @@
 # include <sys/dr.h>
 #endif
 
-#ifdef HAVE_SYS_SYSCTL_H
-#if defined(__FreeBSD__)
-#include <sys/types.h>
-#endif
-# include <sys/sysctl.h>
-#endif
-
 #include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -70,7 +63,7 @@
 #  include <sys/times.h> /* for times(3) */
 #else
 /* NOTE: Getting the system uptime on AIX uses completely different logic.
- * sys/sysinfo.h on AIX defines structures that conflict with SLURM code. */
+ * sys/sysinfo.h on AIX defines structures that conflict with Slurm code. */
 #  include <sys/sysinfo.h>
 #endif
 
