@@ -7,11 +7,11 @@
  *  Written by Morris Jette <jette1@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -64,7 +64,6 @@
 
 /* Global variables */
 pthread_mutex_t conf_mutex = PTHREAD_MUTEX_INITIALIZER;
-//slurm_dbd_conf_t *slurmdbd_conf = NULL;
 
 /* Local functions */
 static void _clear_slurmdbd_conf(void);
@@ -96,10 +95,11 @@ static void _clear_slurmdbd_conf(void)
 		xfree(slurmdbd_conf->dbd_host);
 		slurmdbd_conf->dbd_port = 0;
 		slurmdbd_conf->debug_flags = 0;
-		slurmdbd_conf->debug_level = LOG_LEVEL_QUIET;
+		slurmdbd_conf->debug_level = LOG_LEVEL_INFO;
 		xfree(slurmdbd_conf->default_qos);
 		xfree(slurmdbd_conf->log_file);
-		slurmdbd_conf->syslog_debug = LOG_LEVEL_QUIET;
+		slurmdbd_conf->syslog_debug = LOG_LEVEL_END;
+		xfree(slurmdbd_conf->parameters);
 		xfree(slurmdbd_conf->pid_file);
 		xfree(slurmdbd_conf->plugindir);
 		slurmdbd_conf->private_data = 0;
@@ -142,6 +142,7 @@ extern int read_slurmdbd_conf(void)
 		{"ArchiveSuspend", S_P_BOOLEAN},
 		{"ArchiveTXN", S_P_BOOLEAN},
 		{"ArchiveUsage", S_P_BOOLEAN},
+		{"AuthAltTypes", S_P_STRING},
 		{"AuthInfo", S_P_STRING},
 		{"AuthType", S_P_STRING},
 		{"CommitDelay", S_P_UINT16},
@@ -158,6 +159,7 @@ extern int read_slurmdbd_conf(void)
 		{"LogTimeFormat", S_P_STRING},
 		{"MaxQueryTimeRange", S_P_STRING},
 		{"MessageTimeout", S_P_UINT16},
+		{"Parameters", S_P_STRING},
 		{"PidFile", S_P_STRING},
 		{"PluginDir", S_P_STRING},
 		{"PrivateData", S_P_STRING},
@@ -195,10 +197,9 @@ extern int read_slurmdbd_conf(void)
 	/* Set initial values */
 	slurm_mutex_lock(&conf_mutex);
 	if (slurmdbd_conf == NULL) {
-		slurmdbd_conf = xmalloc(sizeof(slurm_dbd_conf_t));
+		slurmdbd_conf = xmalloc(sizeof(*slurmdbd_conf));
 		boot_time = time(NULL);
 	}
-	slurmdbd_conf->debug_level = LOG_LEVEL_INFO;
 	_clear_slurmdbd_conf();
 
 	/* Get the slurmdbd.conf path and validate the file */
@@ -231,6 +232,8 @@ extern int read_slurmdbd_conf(void)
 		s_p_get_boolean(&a_suspend, "ArchiveSuspend", tbl);
 		s_p_get_boolean(&a_txn, "ArchiveTXN", tbl);
 		s_p_get_boolean(&a_usage, "ArchiveUsage", tbl);
+		s_p_get_string(&slurmdbd_conf->auth_alt_types, "AuthAltTypes",
+			       tbl);
 		s_p_get_string(&slurmdbd_conf->auth_info, "AuthInfo", tbl);
 		s_p_get_string(&slurmdbd_conf->auth_type, "AuthType", tbl);
 		s_p_get_uint16(&slurmdbd_conf->commit_delay,
@@ -309,6 +312,15 @@ extern int read_slurmdbd_conf(void)
 			info("WARNING: MessageTimeout is too high for "
 			     "effective fault-tolerance");
 		}
+
+		s_p_get_string(&slurmdbd_conf->parameters, "Parameters", tbl);
+		if (slurmdbd_conf->parameters) {
+			if (xstrcasestr(slurmdbd_conf->parameters,
+					"PreserveCaseUser"))
+				slurmdbd_conf->persist_conn_rc_flags |=
+					PERSIST_FLAG_P_USER_CASE;
+		}
+
 		s_p_get_string(&slurmdbd_conf->pid_file, "PidFile", tbl);
 		s_p_get_string(&slurmdbd_conf->plugindir, "PluginDir", tbl);
 
@@ -628,6 +640,7 @@ extern void log_config(void)
 
 	debug2("ArchiveDir        = %s", slurmdbd_conf->archive_dir);
 	debug2("ArchiveScript     = %s", slurmdbd_conf->archive_script);
+	debug2("AuthAltTypes      = %s", slurmdbd_conf->auth_alt_types);
 	debug2("AuthInfo          = %s", slurmdbd_conf->auth_info);
 	debug2("AuthType          = %s", slurmdbd_conf->auth_type);
 	debug2("CommitDelay       = %u", slurmdbd_conf->commit_delay);
@@ -644,6 +657,7 @@ extern void log_config(void)
 
 	debug2("LogFile           = %s", slurmdbd_conf->log_file);
 	debug2("MessageTimeout    = %u", slurmdbd_conf->msg_timeout);
+	debug2("Parameters        = %s", slurmdbd_conf->parameters);
 	debug2("PidFile           = %s", slurmdbd_conf->pid_file);
 	debug2("PluginDir         = %s", slurmdbd_conf->plugindir);
 
@@ -785,6 +799,11 @@ extern List dump_config(void)
 			slurmdbd_conf->purge_usage) ? "Yes" : "No");
 	list_append(my_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("AuthAltTypes");
+	key_pair->value = xstrdup(slurmdbd_conf->auth_alt_types);
+	list_append(my_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("AuthInfo");
 	key_pair->value = xstrdup(slurmdbd_conf->auth_info);
@@ -863,6 +882,11 @@ extern List dump_config(void)
 	key_pair->value = xstrdup_printf("%u secs", slurmdbd_conf->msg_timeout);
 	list_append(my_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("Parameters");
+	key_pair->value = xstrdup(slurmdbd_conf->parameters);
+	list_append(my_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("PidFile");
 	key_pair->value = xstrdup(slurmdbd_conf->pid_file);
