@@ -45,12 +45,13 @@
 #include "src/common/list.h"
 #include "src/common/macros.h"
 #include "src/slurmctld/slurmctld.h"
-#include "src/sprio/print.h"
-#include "src/sprio/sprio.h"
 #include "src/common/uid.h"
 #include "src/common/xmalloc.h"
 #include "src/common/xstring.h"
 
+#include "src/sprio/print.h"
+#include "src/sprio/sprio.h"
+
 static int	_print_str(char *str, int width, bool right, bool cut_output);
 
 /*****************************************************************************
@@ -69,6 +70,7 @@ int print_jobs_array(List jobs, List format)
 
 	/* Print the jobs of interest */
 	if (jobs) {
+		sort_job_list(jobs);
 		list_for_each (jobs, (ListForF) print_job_from_format,
 			       (void *) format);
 	}
@@ -76,14 +78,16 @@ int print_jobs_array(List jobs, List format)
 	return SLURM_SUCCESS;
 }
 
-static double _get_priority(priority_factors_object_t *prio_factors)
+double get_priority_from_factors(priority_factors_object_t *prio_factors)
 {
 	int i = 0;
 	double priority = prio_factors->priority_age
+		+ prio_factors->priority_assoc
 		+ prio_factors->priority_fs
 		+ prio_factors->priority_js
 		+ prio_factors->priority_part
 		+ prio_factors->priority_qos
+		+ (double)((int64_t)prio_factors->priority_site - NICE_OFFSET)
 		- (double)((int64_t)prio_factors->nice - NICE_OFFSET);
 
 	for (i = 0; i < prio_factors->tres_cnt; i++) {
@@ -156,7 +160,7 @@ int print_job_from_format(priority_factors_object_t * job, List list)
 	job_format_t *current;
 	int total_width = 0;
 
-	while ((current = (job_format_t *) list_next(i)) != NULL) {
+	while ((current = list_next(i))) {
 		if (current->
 		    function(job, current->width, current->right_justify,
 			     current->suffix)
@@ -183,11 +187,8 @@ int job_format_add_function(List list, int width, bool right, char *suffix,
 	tmp->width = width;
 	tmp->right_justify = right;
 	tmp->suffix = suffix;
+	list_append(list, tmp);
 
-	if (list_append(list, tmp) == NULL) {
-		fprintf(stderr, "Memory exhausted\n");
-		exit(1);
-	}
 	return SLURM_SUCCESS;
 }
 
@@ -249,6 +250,39 @@ int _print_age_priority_weighted(priority_factors_object_t * job, int width,
 	return SLURM_SUCCESS;
 }
 
+int _print_assoc_priority_normalized(priority_factors_object_t * job, int width,
+				     bool right, char* suffix)
+{
+	if (job == NULL)	/* Print the Header instead */
+		_print_str("ASSOC", width, right, true);
+	else if (job == (priority_factors_object_t *) -1)
+		_print_int(weight_assoc, width, right, true);
+	else {
+		double num = 0;
+		if (weight_qos)
+			num = job->priority_assoc / weight_assoc;
+		_print_norm(num, width, right, true);
+	}
+
+	if (suffix)
+		printf("%s", suffix);
+	return SLURM_SUCCESS;
+}
+
+int _print_assoc_priority_weighted(priority_factors_object_t * job, int width,
+				   bool right, char* suffix)
+{
+	if (job == NULL)	/* Print the Header instead */
+		_print_str("ASSOC", width, right, true);
+	else if (job == (priority_factors_object_t *) -1)
+		_print_int(weight_assoc, width, right, true);
+	else
+		_print_int(job->priority_assoc, width, right, true);
+	if (suffix)
+		printf("%s", suffix);
+	return SLURM_SUCCESS;
+}
+
 int _print_cluster_name(priority_factors_object_t *job, int width,
 			bool right, char *suffix)
 {
@@ -303,7 +337,7 @@ int _print_job_priority_normalized(priority_factors_object_t * job, int width,
 	else if (job == (priority_factors_object_t *) -1)
 		_print_str("", width, right, true);
 	else {
-		double priority = _get_priority(job);
+		double priority = get_priority_from_factors(job);
 		double prio = priority / (double) ((uint32_t) 0xffffffff);
 
 		sprintf(temp, "%16.14f", prio);
@@ -323,7 +357,7 @@ int _print_job_priority_weighted(priority_factors_object_t * job, int width,
 	else if (job == (priority_factors_object_t *) -1)
 		_print_str("", width, right, true);
 	else {
-		sprintf(temp, "%lld", (long long)_get_priority(job));
+		sprintf(temp, "%lld", (long long)get_priority_from_factors(job));
 		_print_str(temp, width, right, true);
 	}
 	if (suffix)
@@ -447,6 +481,21 @@ int _print_qos_priority_weighted(priority_factors_object_t * job, int width,
 	return SLURM_SUCCESS;
 }
 
+int _print_site_priority(priority_factors_object_t * job, int width,
+			 bool right, char* suffix)
+{
+	if (job == NULL)	/* Print the Header instead */
+		_print_str("SITE", width, right, true);
+	else if (job == (priority_factors_object_t *) -1)
+		_print_int(1, width, right, true);
+	else
+		_print_int((int64_t)job->priority_site - NICE_OFFSET, width,
+			   right, true);
+	if (suffix)
+		printf("%s", suffix);
+	return SLURM_SUCCESS;
+}
+
 int _print_job_nice(priority_factors_object_t * job, int width,
 				bool right, char* suffix)
 {
