@@ -7,11 +7,11 @@
  *  Written by Morris Jette <jette1@llnl.gov>, et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -56,7 +56,6 @@ static void _get_job_info_from_void(job_info_t **j1, job_info_t **j2, void *v1,
 static void _get_step_info_from_void(job_step_info_t **j1, job_step_info_t **j2, void *v1, void *v2);
 static int _sort_job_by_batch_host(void *void1, void *void2);
 static int _sort_job_by_cluster_name(void *void1, void *void2);
-static int _sort_job_by_gres(void *void1, void *void2);
 static int _sort_job_by_group_id(void *void1, void *void2);
 static int _sort_job_by_group_name(void *void1, void *void2);
 static int _sort_job_by_id(void *void1, void *void2);
@@ -85,7 +84,6 @@ static int _sort_job_by_user_name(void *void1, void *void2);
 static int _sort_job_by_reservation(void *void1, void *void2);
 
 static int _sort_step_by_cluster_name(void *void1, void *void2);
-static int _sort_step_by_gres(void *void1, void *void2);
 static int _sort_step_by_id(void *void1, void *void2);
 static int _sort_step_by_node_list(void *void1, void *void2);
 static int _sort_step_by_partition(void *void1, void *void2);
@@ -129,8 +127,8 @@ void sort_job_list(List job_list)
 			i -= CLUSTER_NAME_LEN - 1;
 		} else if (params.sort[i] == 'B')
 			list_sort(job_list, _sort_job_by_batch_host);
-		else if (params.sort[i] == 'b')
-			list_sort(job_list, _sort_job_by_gres);
+		else if (params.sort[i] == 'b')	/* Vestigial gres sort */
+			info("Invalid sort specification: b");
 		else if (params.sort[i] == 'c')
 			;	/* sort_job_by_min_cpus_per_node */
 		else if (params.sort[i] == 'C')
@@ -234,8 +232,9 @@ void sort_step_list(List step_list)
 
 			list_sort(step_list, _sort_step_by_cluster_name);
 			i -= CLUSTER_NAME_LEN - 1;
-		} else if (params.sort[i] == 'b')
-			list_sort(step_list, _sort_step_by_gres);
+		}
+		else if (params.sort[i] == 'b')	/* Vestigial gres sort */
+			info("Invalid sort specification: b");
 		else if (params.sort[i] == 'i')
 			list_sort(step_list, _sort_step_by_id);
 		else if (params.sort[i] == 'N')
@@ -349,26 +348,6 @@ static int _sort_job_by_cluster_name(void *void1, void *void2)
 	return diff;
 }
 
-static int _sort_job_by_gres(void *void1, void *void2)
-{
-	int diff;
-	job_info_t *job1;
-	job_info_t *job2;
-	char *val1 = "", *val2 = "";
-
-	_get_job_info_from_void(&job1, &job2, void1, void2);
-
-	if (job1->gres)
-		val1 = job1->gres;
-	if (job2->gres)
-		val2 = job2->gres;
-	diff = xstrcmp(val1, val2);
-
-	if (reverse_order)
-		diff = -diff;
-	return diff;
-}
-
 static int _sort_job_by_group_id(void *void1, void *void2)
 {
 	int diff;
@@ -911,26 +890,6 @@ static int _sort_step_by_cluster_name(void *void1, void *void2)
 	return diff;
 }
 
-static int _sort_step_by_gres(void *void1, void *void2)
-{
-	int diff;
-	job_step_info_t *step1;
-	job_step_info_t *step2;
-	char *val1 = "", *val2 = "";
-
-	_get_step_info_from_void(&step1, &step2, void1, void2);
-
-	if (step1->gres)
-		val1 = step1->gres;
-	if (step2->gres)
-		val2 = step2->gres;
-	diff = xstrcmp(val1, val2);
-
-	if (reverse_order)
-		diff = -diff;
-	return diff;
-}
-
 static int _sort_step_by_id(void *void1, void *void2)
 {
 	int diff;
