@@ -8,11 +8,11 @@
  *  Written by Danny Auble <da@llnl.gov>
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -28,13 +28,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -54,15 +54,16 @@ enum {
 };
 
 enum {
-	GROUPED_TOP_ACCT,
+	GROUPED_ACCT,
 	GROUPED_WCKEY,
-	GROUPED_TOP_ACCT_AND_WCKEY,
+	GROUPED_ACCT_AND_WCKEY,
 };
 
 static List print_fields_list = NULL; /* types are of print_field_t */
 static List grouping_print_fields_list = NULL; /* types are of print_field_t */
 static int print_job_count = 0;
 static bool flat_view = false;
+static bool acct_as_parent = false;
 static bool individual_grouping = 0;
 
 /*
@@ -267,6 +268,10 @@ static int _set_cond(int *start, int argc, char **argv,
 					  MAX(command_len, 1))) {
 			local_cluster_flag = 1;
 			continue;
+		} else if (!end && !xstrncasecmp(argv[i], "AcctAsParent",
+						 MAX(command_len, 2))) {
+			acct_as_parent = true;
+			continue;
 		} else if (!end && !xstrncasecmp(argv[i], "PrintJobCount",
 						 MAX(command_len, 2))) {
 			print_job_count = 1;
@@ -789,10 +794,11 @@ static int _run_report(int type, int argc, char **argv)
 		slurm_addto_char_list(grouping_list, "50,250,500,1000");
 
 	switch (type) {
-	case GROUPED_TOP_ACCT:
+	case GROUPED_ACCT:
 		if (!(slurmdb_report_cluster_grouping_list =
-		      slurmdb_report_job_sizes_grouped_by_top_account(
-			      db_conn, job_cond, grouping_list, flat_view))) {
+		      slurmdb_report_job_sizes_grouped_by_account(
+			      db_conn, job_cond, grouping_list, flat_view,
+			      acct_as_parent))) {
 			exit_code = 1;
 			goto end_it;
 		}
@@ -810,10 +816,11 @@ static int _run_report(int type, int argc, char **argv)
 			slurm_addto_char_list(format_list, "Cl,wc");
 		object_str = "by Wckey ";
 		break;
-	case GROUPED_TOP_ACCT_AND_WCKEY:
+	case GROUPED_ACCT_AND_WCKEY:
 		if (!(slurmdb_report_cluster_grouping_list =
-		      slurmdb_report_job_sizes_grouped_by_top_account_then_wckey(
-			      db_conn, job_cond, grouping_list, flat_view))) {
+		      slurmdb_report_job_sizes_grouped_by_account_then_wckey(
+			      db_conn, job_cond, grouping_list, flat_view,
+			      acct_as_parent))) {
 			exit_code = 1;
 			goto end_it;
 		}
@@ -838,7 +845,7 @@ static int _run_report(int type, int argc, char **argv)
 	list_iterator_destroy(itr2);
 	if (tres_cnt > 1) {
 		fprintf(stderr,
-		        " Job report only support a single --tres type.\n"
+		        " Job report only supports a single --tres type.\n"
 			" Generate a separate report for each TRES type.\n");
 		exit_code = 1;
 		goto end_it;
@@ -1015,9 +1022,9 @@ end_it:
 	return rc;
 }
 
-extern int job_sizes_grouped_by_top_acct(int argc, char **argv)
+extern int job_sizes_grouped_by_acct(int argc, char **argv)
 {
-	return _run_report(GROUPED_TOP_ACCT, argc, argv);
+	return _run_report(GROUPED_ACCT, argc, argv);
 }
 
 extern int job_sizes_grouped_by_wckey(int argc, char **argv)
@@ -1025,8 +1032,7 @@ extern int job_sizes_grouped_by_wckey(int argc, char **argv)
 	return _run_report(GROUPED_WCKEY, argc, argv);
 }
 
-extern int job_sizes_grouped_by_top_acct_and_wckey(int argc, char **argv)
+extern int job_sizes_grouped_by_acct_and_wckey(int argc, char **argv)
 {
-	return _run_report(GROUPED_TOP_ACCT_AND_WCKEY, argc, argv);
+	return _run_report(GROUPED_ACCT_AND_WCKEY, argc, argv);
 }
-
