@@ -7,11 +7,11 @@
  *  Written by Mark Grondona <grondona1@llnl.gov>, et. al.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -27,13 +27,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -53,18 +53,14 @@
 #include "src/common/slurm_opt.h"
 
 #define DEFAULT_IMMEDIATE	1
-#define MAX_THREADS		60
 #define MAX_PACK_COUNT		128
 
 /* global variables relating to user options */
-extern int _verbose;
 
 extern enum modes mode;
 
 extern int	error_exit;	/* exit code for slurm errors */
-extern resource_allocation_response_msg_t *global_resp;
 extern int	immediate_exit;	/* exit code for --imediate option & busy */
-extern char *	mpi_type;
 extern slurm_opt_t opt;
 extern srun_opt_t sropt;
 extern List	opt_list;
@@ -72,6 +68,8 @@ extern int	sig_array[];
 extern time_t	srun_begin_time; /* begin time of srun process */
 extern bool	srun_max_timer;
 extern bool	srun_shutdown;
+extern bool	tres_bind_err_log;
+extern bool	tres_freq_err_log;
 
 /*
  * process options:
@@ -87,7 +85,7 @@ extern bool	srun_shutdown;
 extern int initialize_and_process_args(int argc, char **argv, int *argc_off);
 
 /* external functions available for SPANK plugins to modify the environment
- * exported to the SLURM Prolog and Epilog programs */
+ * exported to the Slurm Prolog and Epilog programs */
 extern char *spank_get_job_env(const char *name);
 extern int   spank_set_job_env(const char *name, const char *value,
 			       int overwrite);
