@@ -6,11 +6,11 @@
  *  Written by Danny Auble <da@llnl.gov>.
  *  CODE-OCEC-09-009. All rights reserved.
  *
- *  This file is part of SLURM, a resource management program.
+ *  This file is part of Slurm, a resource management program.
  *  For details, see <https://slurm.schedmd.com/>.
  *  Please also read the included file: DISCLAIMER.
  *
- *  SLURM is free software; you can redistribute it and/or modify it under
+ *  Slurm is free software; you can redistribute it and/or modify it under
  *  the terms of the GNU General Public License as published by the Free
  *  Software Foundation; either version 2 of the License, or (at your option)
  *  any later version.
@@ -26,13 +26,13 @@
  *  version.  If you delete this exception statement from all source files in
  *  the program, then also delete it here.
  *
- *  SLURM is distributed in the hope that it will be useful, but WITHOUT ANY
+ *  Slurm is distributed in the hope that it will be useful, but WITHOUT ANY
  *  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  *  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  *  details.
  *
  *  You should have received a copy of the GNU General Public License along
- *  with SLURM; if not, write to the Free Software Foundation, Inc.,
+ *  with Slurm; if not, write to the Free Software Foundation, Inc.,
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA.
 \*****************************************************************************/
 
@@ -42,6 +42,10 @@
 #include "slurm.h"
 #define FORMAT_STRING_SIZE 34
 
+print_field_t *field = NULL;
+int curr_inx = 1;
+char outbuf[FORMAT_STRING_SIZE];
+
 char *_elapsed_time(long secs, long usecs);
 
 char *_elapsed_time(long secs, long usecs)
@@ -94,21 +98,42 @@ static void _print_small_double(
 		snprintf(outbuf, buf_size, "0");
 }
 
+static void _print_tres_field(char *tres_in, char *nodes, bool convert)
+{
+	char *tmp_char = slurmdb_make_tres_string_from_simple(
+		tres_in, assoc_mgr_tres_list,
+		convert ? params.units : NO_VAL,
+		convert ? params.convert_flags : CONVERT_NUM_UNIT_RAW,
+		TRES_STR_FLAG_BYTES,
+		nodes);
+
+	field->print_routine(field, tmp_char, (curr_inx == field_count));
+	xfree(tmp_char);
+	return;
+}
+
 void print_fields(slurmdb_step_rec_t *step)
 {
-	print_field_t *field = NULL;
-	int curr_inx = 1;
-	char outbuf[FORMAT_STRING_SIZE];
+//	print_field_t *field = NULL;
+//	int curr_inx = 1;
+//	char outbuf[FORMAT_STRING_SIZE];
 
+	curr_inx = 1;
 	list_iterator_reset(print_fields_itr);
 	while ((field = list_next(print_fields_itr))) {
 		char *tmp_char = NULL;
+		uint64_t tmp_uint64 = NO_VAL64;
 
 		memset(&outbuf, 0, sizeof(outbuf));
 		switch(field->type) {
 		case PRINT_AVECPU:
+			tmp_uint64 = slurmdb_find_tres_count_in_string(
+				step->stats.tres_usage_in_ave, TRES_CPU);
 
-			tmp_char = _elapsed_time((long)step->stats.cpu_ave, 0);
+			if (tmp_uint64 != NO_VAL64) {
+				tmp_uint64 /= CPU_TIME_ADJ;
+				tmp_char = _elapsed_time((long)tmp_uint64, 0);
+			}
 
 			field->print_routine(field,
 					     tmp_char,
@@ -146,26 +171,44 @@ void print_fields(slurmdb_step_rec_t *step)
 					     (curr_inx == field_count));
 			break;
 		case PRINT_AVEDISKREAD:
-			_print_small_double(outbuf, sizeof(outbuf),
-					    step->stats.disk_read_ave,
-					    UNIT_MEGA);
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_ave,
+				     TRES_FS_DISK)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				_print_small_double(outbuf, sizeof(outbuf),
+						    (double)tmp_uint64,
+						    UNIT_NONE);
 
 			field->print_routine(field,
 					     outbuf,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_AVEDISKWRITE:
-			_print_small_double(outbuf, sizeof(outbuf),
-					    step->stats.disk_write_ave,
-					    UNIT_MEGA);
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_out_ave,
+				     TRES_FS_DISK)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				_print_small_double(outbuf, sizeof(outbuf),
+						    (double)tmp_uint64,
+						    UNIT_NONE);
 
 			field->print_routine(field,
 					     outbuf,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_AVEPAGES:
-			convert_num_unit((double)step->stats.pages_ave, outbuf,
-					 sizeof(outbuf), UNIT_KILO, NO_VAL,
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_ave,
+				     TRES_PAGES)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				convert_num_unit((double)tmp_uint64, outbuf,
+					 sizeof(outbuf), UNIT_NONE, NO_VAL,
 					 params.convert_flags);
 
 			field->print_routine(field,
@@ -173,8 +216,14 @@ void print_fields(slurmdb_step_rec_t *step)
 					     (curr_inx == field_count));
 			break;
 		case PRINT_AVERSS:
-			convert_num_unit((double)step->stats.rss_ave, outbuf,
-					 sizeof(outbuf), UNIT_KILO, NO_VAL,
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_ave,
+				     TRES_MEM)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				convert_num_unit((double)tmp_uint64, outbuf,
+					 sizeof(outbuf), UNIT_NONE, NO_VAL,
 					 params.convert_flags);
 
 			field->print_routine(field,
@@ -182,8 +231,14 @@ void print_fields(slurmdb_step_rec_t *step)
 					     (curr_inx == field_count));
 			break;
 		case PRINT_AVEVSIZE:
-			convert_num_unit((double)step->stats.vsize_ave, outbuf,
-					 sizeof(outbuf), UNIT_KILO, NO_VAL,
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_ave,
+				     TRES_VMEM)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				convert_num_unit((double)tmp_uint64, outbuf,
+					 sizeof(outbuf), UNIT_NONE, NO_VAL,
 					 params.convert_flags);
 
 			field->print_routine(field,
@@ -207,9 +262,15 @@ void print_fields(slurmdb_step_rec_t *step)
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MAXDISKREAD:
-			_print_small_double(outbuf, sizeof(outbuf),
-					    step->stats.disk_read_max,
-					    UNIT_MEGA);
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_max,
+				     TRES_FS_DISK)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				_print_small_double(outbuf, sizeof(outbuf),
+						    (double)tmp_uint64,
+						    UNIT_NONE);
 
 			field->print_routine(field,
 					     outbuf,
@@ -217,22 +278,38 @@ void print_fields(slurmdb_step_rec_t *step)
 			break;
 		case PRINT_MAXDISKREADNODE:
 			tmp_char = find_hostname(
-					step->stats.disk_read_max_nodeid,
-					step->nodes);
+				slurmdb_find_tres_count_in_string(
+					step->stats.
+					tres_usage_in_max_nodeid,
+					TRES_FS_DISK),
+				step->nodes);
+
 			field->print_routine(field,
 					     tmp_char,
 					     (curr_inx == field_count));
 			xfree(tmp_char);
 			break;
 		case PRINT_MAXDISKREADTASK:
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.
+				     tres_usage_in_max_taskid,
+				     TRES_FS_DISK)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
 			field->print_routine(field,
-					     step->stats.disk_read_max_taskid,
+					     tmp_uint64,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MAXDISKWRITE:
-			_print_small_double(outbuf, sizeof(outbuf),
-					    step->stats.disk_write_max,
-					    UNIT_MEGA);
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_out_max,
+				     TRES_FS_DISK)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				_print_small_double(outbuf, sizeof(outbuf),
+						    (double)tmp_uint64,
+						    UNIT_NONE);
 
 			field->print_routine(field,
 					     outbuf,
@@ -240,21 +317,37 @@ void print_fields(slurmdb_step_rec_t *step)
 			break;
 		case PRINT_MAXDISKWRITENODE:
 			tmp_char = find_hostname(
-					step->stats.disk_write_max_nodeid,
-					step->nodes);
+				slurmdb_find_tres_count_in_string(
+					step->stats.
+					tres_usage_out_max_nodeid,
+					TRES_FS_DISK),
+				step->nodes);
+
 			field->print_routine(field,
 					     tmp_char,
 					     (curr_inx == field_count));
 			xfree(tmp_char);
 			break;
 		case PRINT_MAXDISKWRITETASK:
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.
+				     tres_usage_out_max_taskid,
+				     TRES_FS_DISK)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
 			field->print_routine(field,
-					     step->stats.disk_write_max_taskid,
+					     tmp_uint64,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MAXPAGES:
-			convert_num_unit((double)step->stats.pages_max, outbuf,
-					 sizeof(outbuf), UNIT_KILO, NO_VAL,
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_max,
+				     TRES_PAGES)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				convert_num_unit((double)tmp_uint64, outbuf,
+					 sizeof(outbuf), UNIT_NONE, NO_VAL,
 					 params.convert_flags);
 
 			field->print_routine(field,
@@ -263,21 +356,37 @@ void print_fields(slurmdb_step_rec_t *step)
 			break;
 		case PRINT_MAXPAGESNODE:
 			tmp_char = find_hostname(
-					step->stats.pages_max_nodeid,
-					step->nodes);
+				slurmdb_find_tres_count_in_string(
+					step->stats.
+					tres_usage_in_max_nodeid,
+					TRES_PAGES),
+				step->nodes);
+
 			field->print_routine(field,
 					     tmp_char,
 					     (curr_inx == field_count));
 			xfree(tmp_char);
 			break;
 		case PRINT_MAXPAGESTASK:
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.
+				     tres_usage_in_max_taskid,
+				     TRES_PAGES)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
 			field->print_routine(field,
-					     step->stats.pages_max_taskid,
+					     tmp_uint64,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MAXRSS:
-			convert_num_unit((double)step->stats.rss_max, outbuf,
-					 sizeof(outbuf), UNIT_KILO, NO_VAL,
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_max,
+				     TRES_MEM)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				convert_num_unit((double)tmp_uint64, outbuf,
+					 sizeof(outbuf), UNIT_NONE, NO_VAL,
 					 params.convert_flags);
 
 			field->print_routine(field,
@@ -286,21 +395,37 @@ void print_fields(slurmdb_step_rec_t *step)
 			break;
 		case PRINT_MAXRSSNODE:
 			tmp_char = find_hostname(
-					step->stats.rss_max_nodeid,
-					step->nodes);
+				slurmdb_find_tres_count_in_string(
+					step->stats.
+					tres_usage_in_max_nodeid,
+					TRES_MEM),
+				step->nodes);
+
 			field->print_routine(field,
 					     tmp_char,
 					     (curr_inx == field_count));
 			xfree(tmp_char);
 			break;
 		case PRINT_MAXRSSTASK:
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.
+				     tres_usage_in_max_taskid,
+				     TRES_MEM)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
 			field->print_routine(field,
-					     step->stats.rss_max_taskid,
+					     tmp_uint64,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MAXVSIZE:
-			convert_num_unit((double)step->stats.vsize_max, outbuf,
-					 sizeof(outbuf), UNIT_KILO, NO_VAL,
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_max,
+				     TRES_VMEM)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64)
+				convert_num_unit((double)tmp_uint64, outbuf,
+					 sizeof(outbuf), UNIT_NONE, NO_VAL,
 					 params.convert_flags);
 
 			field->print_routine(field,
@@ -309,20 +434,38 @@ void print_fields(slurmdb_step_rec_t *step)
 			break;
 		case PRINT_MAXVSIZENODE:
 			tmp_char = find_hostname(
-					step->stats.vsize_max_nodeid,
-					step->nodes);
+				slurmdb_find_tres_count_in_string(
+					step->stats.
+					tres_usage_in_max_nodeid,
+					TRES_VMEM),
+				step->nodes);
+
 			field->print_routine(field,
 					     tmp_char,
 					     (curr_inx == field_count));
 			xfree(tmp_char);
 			break;
 		case PRINT_MAXVSIZETASK:
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.
+				     tres_usage_in_max_taskid,
+				     TRES_VMEM)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
 			field->print_routine(field,
-					     step->stats.vsize_max_taskid,
+					     tmp_uint64,
 					     (curr_inx == field_count));
 			break;
 		case PRINT_MINCPU:
-			tmp_char = _elapsed_time((long)step->stats.cpu_min, 0);
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.tres_usage_in_min,
+				     TRES_CPU)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
+			if (tmp_uint64 != NO_VAL64) {
+				tmp_uint64 /= CPU_TIME_ADJ;
+				tmp_char = _elapsed_time((long)tmp_uint64, 0);
+			}
 
 			field->print_routine(field,
 					     tmp_char,
@@ -331,18 +474,92 @@ void print_fields(slurmdb_step_rec_t *step)
 			break;
 		case PRINT_MINCPUNODE:
 			tmp_char = find_hostname(
-					step->stats.cpu_min_nodeid,
-					step->nodes);
+				slurmdb_find_tres_count_in_string(
+					step->stats.
+					tres_usage_in_min_nodeid,
+					TRES_CPU),
+				step->nodes);
+
 			field->print_routine(field,
 					     tmp_char,
 					     (curr_inx == field_count));
 			xfree(tmp_char);
 			break;
 		case PRINT_MINCPUTASK:
+			if ((tmp_uint64 = slurmdb_find_tres_count_in_string(
+				     step->stats.
+				     tres_usage_in_min_taskid,
+				     TRES_CPU)) == INFINITE64)
+				tmp_uint64 = NO_VAL64;
+
 			field->print_routine(field,
-					     step->stats.cpu_min_taskid,
+					     tmp_uint64,
 					     (curr_inx == field_count));
 			break;
+		case PRINT_TRESUIA:
+			_print_tres_field(step->stats.tres_usage_in_ave,
+					  NULL, 1);
+			break;
+		case PRINT_TRESUIM:
+			_print_tres_field(step->stats.tres_usage_in_max,
+					  NULL, 1);
+			break;
+		case PRINT_TRESUIMN:
+			_print_tres_field(step->stats.tres_usage_in_max_nodeid,
+					  step->nodes, 0);
+			break;
+		case PRINT_TRESUIMT:
+			_print_tres_field(step->stats.tres_usage_in_max_taskid,
+					  NULL, 0);
+			break;
+		case PRINT_TRESUIMI:
+			_print_tres_field(step->stats.tres_usage_in_min,
+					  NULL, 1);
+			break;
+		case PRINT_TRESUIMIN:
+			_print_tres_field(step->stats.tres_usage_in_min_nodeid,
+					  step->nodes, 0);
+			break;
+		case PRINT_TRESUIMIT:
+			_print_tres_field(step->stats.tres_usage_in_min_taskid,
+					  NULL, 0);
+			break;
+		case PRINT_TRESUIT:
+			_print_tres_field(step->stats.tres_usage_in_tot,
+					  NULL, 1);
+			break;
+		case PRINT_TRESUOA:
+			_print_tres_field(step->stats.tres_usage_out_ave,
+					  NULL, 1);
+			break;
+		case PRINT_TRESUOM:
+			_print_tres_field(step->stats.tres_usage_out_max,
+					  NULL, 1);
+			break;
+		case PRINT_TRESUOMN:
+			_print_tres_field(step->stats.tres_usage_out_max_nodeid,
+					  step->nodes, 0);
+			break;
+		case PRINT_TRESUOMT:
+			_print_tres_field(step->stats.tres_usage_out_max_taskid,
+					  NULL, 0);
+			break;
+		case PRINT_TRESUOMI:
+			_print_tres_field(step->stats.tres_usage_out_min,
+					  NULL, 1);
+			break;
+		case PRINT_TRESUOMIN:
+			_print_tres_field(step->stats.tres_usage_out_min_nodeid,
+					  step->nodes, 0);
+			break;
+		case PRINT_TRESUOMIT:
+			_print_tres_field(step->stats.tres_usage_out_min_taskid,
+					  NULL, 0);
+			break;
+		case PRINT_TRESUOT:
+			_print_tres_field(step->stats.tres_usage_out_tot,
+					  NULL, 1);
+			break;
 		case PRINT_NODELIST:
 			field->print_routine(field,
 					     step->nodes,
@@ -386,4 +603,3 @@ void print_fields(slurmdb_step_rec_t *step)
 	}
 	printf("\n");
 }
-
