@@ -1926,7 +1926,7 @@ need_refresh:
 		treeview = create_treeview_2cols_attach_to_table(
 			popup_win->table);
 		spec_info->display_widget =
-			gtk_widget_ref(GTK_WIDGET(treeview));
+			g_object_ref(GTK_WIDGET(treeview));
 	} else {
 		treeview = GTK_TREE_VIEW(spec_info->display_widget);
 		update = 1;
@@ -2508,7 +2508,7 @@ extern void get_info_part(GtkTable *table, display_data_t *display_data)
 		snprintf(error_char, 100, "slurm_load_partitions: %s",
 			 slurm_strerror(slurm_get_errno()));
 		label = gtk_label_new(error_char);
-		display_widget = gtk_widget_ref(GTK_WIDGET(label));
+		display_widget = g_object_ref(GTK_WIDGET(label));
 		gtk_table_attach_defaults(table, label, 0, 1, 0, 1);
 		gtk_widget_show(label);
 		goto end_it;
@@ -2528,7 +2528,7 @@ extern void get_info_part(GtkTable *table, display_data_t *display_data)
 		snprintf(error_char, 100, "slurm_load_node: %s",
 			 slurm_strerror(slurm_get_errno()));
 		label = gtk_label_new(error_char);
-		display_widget = gtk_widget_ref(GTK_WIDGET(label));
+		display_widget = g_object_ref(GTK_WIDGET(label));
 		gtk_table_attach_defaults(table, label, 0, 1, 0, 1);
 		gtk_widget_show(label);
 		goto end_it;
@@ -2594,7 +2594,7 @@ display_it:
 		gtk_tree_selection_set_mode(
 			gtk_tree_view_get_selection(tree_view),
 			GTK_SELECTION_MULTIPLE);
-		display_widget = gtk_widget_ref(GTK_WIDGET(tree_view));
+		display_widget = g_object_ref(GTK_WIDGET(tree_view));
 		gtk_table_attach_defaults(table,
 					  GTK_WIDGET(tree_view),
 					  0, 1, 0, 1);
@@ -2660,7 +2660,7 @@ extern void specific_info_part(popup_info_t *popup_win)
 		snprintf(error_char, 100, "slurm_load_partitions: %s",
 			 slurm_strerror(slurm_get_errno()));
 		label = gtk_label_new(error_char);
-		spec_info->display_widget = gtk_widget_ref(GTK_WIDGET(label));
+		spec_info->display_widget = g_object_ref(GTK_WIDGET(label));
 		gtk_table_attach_defaults(popup_win->table, label, 0, 1, 0, 1);
 		gtk_widget_show(label);
 		goto end_it;
@@ -2682,7 +2682,7 @@ extern void specific_info_part(popup_info_t *popup_win)
 		snprintf(error_char, 100, "slurm_load_node: %s",
 			 slurm_strerror(slurm_get_errno()));
 		label = gtk_label_new(error_char);
-		spec_info->display_widget = gtk_widget_ref(GTK_WIDGET(label));
+		spec_info->display_widget = g_object_ref(GTK_WIDGET(label));
 		gtk_table_attach_defaults(popup_win->table, label, 0, 1, 0, 1);
 		gtk_widget_show(label);
 		goto end_it;
@@ -2709,7 +2709,7 @@ display_it:
 			GTK_SELECTION_MULTIPLE);
 
 		spec_info->display_widget =
-			gtk_widget_ref(GTK_WIDGET(tree_view));
+			g_object_ref(GTK_WIDGET(tree_view));
 		gtk_table_attach_defaults(popup_win->table,
 					  GTK_WIDGET(tree_view),
 					  0, 1, 0, 1);
