@@ -26,6 +26,7 @@
 
 """This script makes it easier to run the Slurm expect test scripts."""
 
+from __future__ import print_function
 import os
 import re
 import sys
@@ -44,6 +45,7 @@ def main(argv=None):
     tests = []
     failed_tests = []
     passed_tests = []
+    begin = (1,1)
 
     # Handle command line parameters
     if argv is None:
@@ -60,19 +62,23 @@ def main(argv=None):
                       help='comma or space separated string of tests to include')
     parser.add_option('-k', '--keep-logs', action='store_true', default=False)
     parser.add_option('-s', '--stop-on-first-fail', action='store_true', default=False)
+    parser.add_option('-b', '--begin-from-test', type='string',
+                      dest='begin_from_test', action='callback',
+                      callback=test_parser)
+
     (options, args) = parser.parse_args(args=argv)
 
     # Sanity check
     if not os.path.isfile('globals'):
-        print >>sys.stderr, 'ERROR: "globals" not here as needed'
+        print('ERROR: "globals" not here as needed', file=sys.stderr)
         return -1
 
-	# Clear any environment variables that could break the tests.
-	# Cray sets some squeue format options that break tests
-	del os.environ['SQUEUE_ALL']
-	del os.environ['SQUEUE_SORT']
-	del os.environ['SQUEUE_FORMAT']
-	del os.environ['SQUEUE_FORMAT2']
+        # Clear any environment variables that could break the tests.
+        # Cray sets some squeue format options that break tests
+        del os.environ['SQUEUE_ALL']
+        del os.environ['SQUEUE_SORT']
+        del os.environ['SQUEUE_FORMAT']
+        del os.environ['SQUEUE_FORMAT2']
 
     # Read the current working directory and build a sorted list
     # of the available tests.
@@ -87,15 +93,22 @@ def main(argv=None):
                         or test_in_list(major, minor, options.include_tests)):
                 tests.append((major, minor, filename))
     if not tests:
-        print >>sys.stderr, 'ERROR: no test files found in current working directory'
+        print('ERROR: no test files found in current working directory', file=sys.stderr)
         return -1
-    tests.sort(test_cmp)
+    # sory by major, minor
+    tests.sort(key=lambda t: (t[0],t[1]))
+
+    # Set begin value
+    if options.begin_from_test is not None:
+        begin  = options.begin_from_test[0]
 
     # Now run the tests
     start_time = time.time()
-    print >>sys.stdout, 'Started:', time.asctime(time.localtime(start_time))
+    print('Started:', time.asctime(time.localtime(start_time)), file=sys.stdout)
     sys.stdout.flush()
     for test in tests:
+        if begin[0] > test[0] or (begin[0] == test[0] and begin[1] > test[1]):
+            continue
         sys.stdout.write('Running test %d.%d ' % (test[0],test[1]))
         sys.stdout.flush()
         testlog_name = 'test%d.%d.log' % (test[0],test[1])
@@ -103,7 +116,7 @@ def main(argv=None):
             os.remove(testlog_name+'.failed')
         except:
             pass
-        testlog = file(testlog_name, 'w+')
+        testlog = open(testlog_name, 'w+')
 
         if options.time_individual:
             t1 = time.time()
@@ -125,8 +138,8 @@ def main(argv=None):
                 try:
                     os.remove(testlog_name)
                 except IOError as e:
-                    print >> sys.stderr, 'ERROR failed to close %s %s' \
-                        % (testlog_name, e)
+                    print('ERROR failed to close %s %s' % (testlog_name, e),
+                            file=sys.stederr);
         else:
             failed_tests.append(test)
             os.rename(testlog_name, testlog_name+'.failed')
@@ -136,14 +149,13 @@ def main(argv=None):
         sys.stdout.flush()
 
     end_time = time.time()
-    print >>sys.stdout, 'Ended:', time.asctime(time.localtime(end_time))
-    print >>sys.stdout, '\nTestsuite ran for %d minutes %d seconds'\
-          %((end_time-start_time)/60,(end_time-start_time)%60)
-    print >>sys.stdout
-    print >>sys.stdout, 'Completions  :', len(passed_tests)
-    print >>sys.stdout, 'Failures     :', len(failed_tests)
+    print('Ended:', time.asctime(time.localtime(end_time)), file=sys.stdout)
+    print('\nTestsuite ran for %d minutes %d seconds'\
+          %((end_time-start_time)/60,(end_time-start_time)%60), file=sys.stdout)
+    print('Completions  :', len(passed_tests), file=sys.stdout)
+    print('Failures     :', len(failed_tests), file=sys.stdout)
     if len(failed_tests) > 0:
-        print >>sys.stdout, 'Failed tests : ',
+        print('Failed tests : ', file=sys.stdout)
         first = True
         for test in failed_tests:
             if first:
@@ -155,12 +167,6 @@ def main(argv=None):
         sys.stdout.flush()
         return 1
 
-def test_cmp(testA, testB):
-    rc = cmp(testA[0], testB[0])
-    if rc != 0:
-        return rc
-    return cmp(testA[1], testB[1])
-
 def test_in_list(major, minor, test_list):
     '''Test for whether a test numbered major.minor is in test_list.
 
