@@ -33,7 +33,7 @@ START_TEST(pack_null_req)
 END_TEST
 #endif
 
-START_TEST(pack_1702_req_null_ptrs)
+START_TEST(pack_back2_req_null_ptrs)
 {
 	int rc;
 	Buf buf = init_buf(1024);
@@ -43,7 +43,7 @@ START_TEST(pack_1702_req_null_ptrs)
 	pack_req.job_id = 12345;
 
 	msg.msg_type         = REQUEST_JOB_ALLOCATION_INFO;
-	msg.protocol_version = SLURM_17_02_PROTOCOL_VERSION;
+	msg.protocol_version = SLURM_MIN_PROTOCOL_VERSION;
 	msg.data             = &pack_req;
 
 	rc = pack_msg(&msg, buf);
@@ -59,7 +59,7 @@ START_TEST(pack_1702_req_null_ptrs)
 	unpack_req = (job_alloc_info_msg_t *)msg.data;
 	ck_assert_int_eq(rc, SLURM_SUCCESS);
 	ck_assert(unpack_req);
-	ck_assert(!unpack_req->req_cluster); /* >= 17.11 */
+	ck_assert(!unpack_req->req_cluster);
 	ck_assert_uint_eq(unpack_req->job_id, pack_req.job_id);
 
 	free_buf(buf);
@@ -67,7 +67,7 @@ START_TEST(pack_1702_req_null_ptrs)
 }
 END_TEST
 
-START_TEST(pack_1702_req)
+START_TEST(pack_back2_req)
 {
 	int rc;
 	Buf buf = init_buf(1024);
@@ -78,7 +78,7 @@ START_TEST(pack_1702_req)
 	pack_req.req_cluster = xstrdup("blah");
 
 	msg.msg_type         = REQUEST_JOB_ALLOCATION_INFO;
-	msg.protocol_version = SLURM_17_02_PROTOCOL_VERSION;
+	msg.protocol_version = SLURM_MIN_PROTOCOL_VERSION;
 	msg.data             = &pack_req;
 
 	rc = pack_msg(&msg, buf);
@@ -94,7 +94,7 @@ START_TEST(pack_1702_req)
 	unpack_req = (job_alloc_info_msg_t *)msg.data;
 	ck_assert_int_eq(rc, SLURM_SUCCESS);
 	ck_assert(unpack_req);
-	ck_assert(!unpack_req->req_cluster); /* >= 17.11 */
+	//ck_assert(!unpack_req->req_cluster); /* >= 17.11 */
 	ck_assert_uint_eq(unpack_req->job_id, pack_req.job_id);
 
 	free_buf(buf);
@@ -103,7 +103,7 @@ START_TEST(pack_1702_req)
 }
 END_TEST
 
-START_TEST(pack_1711_req_null_ptrs)
+START_TEST(pack_back1_req_null_ptrs)
 {
 	int rc;
 	Buf buf = init_buf(1024);
@@ -113,7 +113,7 @@ START_TEST(pack_1711_req_null_ptrs)
 	pack_req.job_id = 12345;
 
 	msg.msg_type         = REQUEST_JOB_ALLOCATION_INFO;
-	msg.protocol_version = SLURM_17_11_PROTOCOL_VERSION;
+	msg.protocol_version = SLURM_ONE_BACK_PROTOCOL_VERSION;
 	msg.data             = &pack_req;
 
 	rc = pack_msg(&msg, buf);
@@ -136,7 +136,7 @@ START_TEST(pack_1711_req_null_ptrs)
 }
 END_TEST
 
-START_TEST(pack_1711_req)
+START_TEST(pack_back1_req)
 {
 	int rc;
 	Buf buf = init_buf(1024);
@@ -147,7 +147,7 @@ START_TEST(pack_1711_req)
 	pack_req.req_cluster = xstrdup("blah");
 
 	msg.msg_type         = REQUEST_JOB_ALLOCATION_INFO;
-	msg.protocol_version = SLURM_17_11_PROTOCOL_VERSION;
+	msg.protocol_version = SLURM_ONE_BACK_PROTOCOL_VERSION;
 	msg.data             = &pack_req;
 
 	rc = pack_msg(&msg, buf);
@@ -188,10 +188,10 @@ Suite* suite(SRunner *sr)
        if (srunner_fork_status(sr) != CK_NOFORK)
                tcase_add_test_raise_signal(tc_core, pack_null_req, SIGABRT);
 #endif
-	tcase_add_test(tc_core, pack_1702_req_null_ptrs);
-	tcase_add_test(tc_core, pack_1702_req);
-	tcase_add_test(tc_core, pack_1711_req_null_ptrs);
-	tcase_add_test(tc_core, pack_1711_req);
+	tcase_add_test(tc_core, pack_back2_req_null_ptrs);
+	tcase_add_test(tc_core, pack_back2_req);
+	tcase_add_test(tc_core, pack_back1_req_null_ptrs);
+	tcase_add_test(tc_core, pack_back1_req);
 	suite_add_tcase(s, tc_core);
 	return s;
 }
@@ -214,4 +214,3 @@ int main(void)
 
 	return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
 }
-
